@@ -130,6 +130,7 @@ namespace Magick
   using MagickLib::BlackChannel;
   using MagickLib::MatteChannel;
   using MagickLib::DefaultChannels;
+  using MagickLib::AllChannels;
   
   // Color-space types
   using MagickLib::CMYKColorspace;
@@ -489,7 +490,6 @@ namespace Magick
   using MagickLib::CoderError;
   using MagickLib::CoderFatalError;
   using MagickLib::CoderWarning;
-  using MagickLib::ColorFloodfillImage;
   using MagickLib::ColorizeImage;
   using MagickLib::ColorPacket;
   using MagickLib::CompositeImage;
@@ -654,6 +654,7 @@ namespace Magick
   using MagickLib::GetIndexes;
   using MagickLib::GetMagickInfo;
   using MagickLib::GetMagickRegistry;
+  using MagickLib::GetMagickPixelPacket;
   using MagickLib::GetNumberColors;
   using MagickLib::GetPageGeometry;
   using MagickLib::GetPixels;
@@ -690,7 +691,6 @@ namespace Magick
   using MagickLib::MagickWand;
   using MagickLib::MagnifyImage;
   using MagickLib::MapImage;
-  using MagickLib::MatteFloodfillImage;
   using MagickLib::MedianFilterImage;
   using MagickLib::MinifyImage;
   using MagickLib::MissingDelegateError;
@@ -715,6 +715,7 @@ namespace Magick
   using MagickLib::OptionError;
   using MagickLib::OptionFatalError;
   using MagickLib::OptionWarning;
+  using MagickLib::PaintFloodfillImage;
   using MagickLib::ParseMetaGeometry;
   using MagickLib::PercentValue;
   using MagickLib::PaintOpaqueImage;
