@@ -560,9 +560,6 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
   QuantumType
     quantum_type;
 
-  register const unsigned char
-    *p;
-
   register long
     i;
 
@@ -1011,6 +1008,7 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     Convert DPX raster image to pixel packets.
   */
   GetQuantumInfo(image_info,&quantum_info);
+  quantum_info.quantum=32;
   quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
     MagickFalse;
   samples_per_pixel=1;
@@ -1069,10 +1067,10 @@ static Image *ReadDPXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     q=SetImagePixels(image,0,y,image->columns,1);
     if (q == (PixelPacket *) NULL)
       break;
-    p=ReadBlobStream(image,length,pixels,&count);
+    count=ReadBlob(image,length,pixels);
     if ((size_t) count != length)
       break;
-    status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+    status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
     if (status == MagickFalse)
       break;
     if (SyncImagePixels(image) == MagickFalse)
@@ -1663,6 +1661,7 @@ static MagickBooleanType WriteDPXImage(const ImageInfo *image_info,Image *image)
     Convert pixel packets to DPX raster image.
   */
   GetQuantumInfo(image_info,&quantum_info);
+  quantum_info.quantum=32;
   quantum_info.pack=dpx.image.image_element[0].packing == 0 ? MagickTrue :
     MagickFalse;
   quantum_type=RGBQuantum;
