@@ -521,7 +521,6 @@ static MagickBooleanType DecodeImage(Image *image,const Quantum opacity)
 %
 %    o data_size:  The number of bits in the compressed packet.
 %
-%
 */
 static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
   const unsigned long data_size)
@@ -838,7 +837,6 @@ static MagickBooleanType EncodeImage(const ImageInfo *image_info,Image *image,
 %
 %    o length: Specifies the length of the magick string.
 %
-%
 */
 static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 {
@@ -875,7 +873,6 @@ static MagickBooleanType IsGIF(const unsigned char *magick,const size_t length)
 %    o data:  Specifies an area to place the information requested from
 %      the file.
 %
-%
 */
 static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
 {
@@ -919,7 +916,6 @@ static ssize_t ReadBlobBlock(Image *image,unsigned char *data)
 %
 %    o exception: return any errors or warnings in this structure.
 %
-%
 */
 
 static inline size_t MagickMax(const size_t x,const size_t y)
@@ -971,6 +967,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   Image
     *image;
 
+  int
+    num_app_exts=0;
+
   long
     opacity;
 
@@ -1057,8 +1056,6 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         /*
           GIF Extension block.
         */
-        int
-          num_app_exts=0;
 
         count=ReadBlob(image,1,&c);
         if (count != 1)
@@ -1127,7 +1124,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
             {
               /* store GIF application extension as a generic profile */
               char
-                name[10];
+                name[MaxTextExtent];
 
               StringInfo
                 *profile;
@@ -1156,20 +1153,9 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                   "    Reading GIF application extension");
 
-              if (icc == MagickTrue || iptc == MagickTrue ||
-                  i8bim == MagickTrue)
-              {
-                info=(unsigned char *) AcquireMagickMemory(255);
-                info_length=0;
-                reserved_length=255;
-              }
-              else
-              {
-                info=(unsigned char *) AcquireMagickMemory(266);
-                (void) CopyMagickMemory(info ,header, 11);
-                info_length=11;
-                reserved_length=266;
-              }
+              info=(unsigned char *) AcquireMagickMemory(255);
+              info_length=0;
+              reserved_length=255;
               for (;;)
               {
                 block_length=(int) ReadBlobBlock(image,&info[info_length]);
@@ -1185,7 +1171,6 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               }
               info=(unsigned char *) ResizeMagickMemory(info,(size_t)
                 info_length);
-
               profile=AcquireStringInfo((size_t) info_length);
               SetStringInfoDatum(profile,(const unsigned char *) info);
               if (i8bim == MagickTrue)
@@ -1195,8 +1180,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
               else if (iptc == MagickTrue)
                 (void) CopyMagickString(name,"iptc",sizeof(name));
               else
-                (void) FormatMagickString(name,sizeof(name),"GIFAP%03d000",
-                  num_app_exts);
+                (void) FormatMagickString(name,sizeof(name),"gif:%.11s",header);
               (void) SetImageProfile(image,name,profile);
               profile=DestroyStringInfo(profile);
               (void) LogMagickEvent(CoderEvent,GetMagickModule(),
@@ -1247,7 +1231,7 @@ static Image *ReadGIFImage(const ImageInfo *image_info,ExceptionInfo *exception)
     image->rows=ReadBlobLSBShort(image);
     image->depth=8;
     flag=(unsigned char) ReadBlobByte(image);
-    image->interlace=BitSet((int) flag,0x40) != 0 ? PlaneInterlace :
+    image->interlace=BitSet((int) flag,0x40) != 0 ? GIFInterlace :
       NoInterlace;
     image->colors=BitSet((int) flag,0x80) == 0 ? global_colors :
       1UL << ((unsigned long) (flag & 0x07)+1);
@@ -1753,7 +1737,7 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                 (LocaleCompare(name,"ICM") == 0) ||
                 (LocaleCompare(name,"IPTC") == 0) ||
                 (LocaleCompare(name,"8BIM") == 0) ||
-                (LocaleNCompare(name,"GIFAP",5) == 0))
+                (LocaleNCompare(name,"gif:",4) == 0))
             {
                int
                  profile_length,
@@ -1793,8 +1777,12 @@ static MagickBooleanType WriteGIFImage(const ImageInfo *image_info,Image *image)
                }
                else
                {
+                 char
+                   extension[MaxTextExtent];
+
                  /* write generic extension */
-                 (void) WriteBlob(image,11,(unsigned char *) name);
+                 (void) CopyMagickString(extension,name+4,sizeof(extension));
+                 (void) WriteBlob(image,11,(unsigned char *) extension);
                  (void) LogMagickEvent(CoderEvent,GetMagickModule(),
                      "  Writing GIF Extension %s",name);
                }
