@@ -61,7 +61,6 @@
 #include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
-#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
@@ -176,7 +175,38 @@ static inline size_t MagickMin(const size_t x,const size_t y)
   return(y);
 }
 
-static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
+static void PushRunlengthPacket(Image *image,const unsigned char *pixels,
   size_t *length,PixelPacket *pixel,IndexPacket *index)
 {
   const unsigned char
@@ -233,7 +263,7 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushShortPixel(MSBEndian,&p);
+              quantum=PushShortPixel(&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -245,7 +275,7 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
 
           if (image->matte != MagickFalse)
             {
-              quantum=PushLongPixel(MSBEndian,&p);
+              quantum=PushLongPixel(&p);
               pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
             }
           break;
@@ -287,20 +317,20 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned short
         quantum;
 
-      quantum=PushShortPixel(MSBEndian,&p);
+      quantum=PushShortPixel(&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushShortPixel(MSBEndian,&p);
+      quantum=PushShortPixel(&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushShortPixel(MSBEndian,&p);
+      quantum=PushShortPixel(&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          quantum=PushShortPixel(MSBEndian,&p);
+          quantum=PushShortPixel(&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushShortPixel(MSBEndian,&p);
+          quantum=PushShortPixel(&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -310,20 +340,20 @@ static inline void PushRunlengthPacket(Image *image,const unsigned char *pixels,
       unsigned long
         quantum;
 
-      quantum=PushLongPixel(MSBEndian,&p);
+      quantum=PushLongPixel(&p);
       pixel->red=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushLongPixel(MSBEndian,&p);
+      quantum=PushLongPixel(&p);
       pixel->green=(Quantum) (quantum >> (image->depth-QuantumDepth));
-      quantum=PushLongPixel(MSBEndian,&p);
+      quantum=PushLongPixel(&p);
       pixel->blue=(Quantum) (quantum >> (image->depth-QuantumDepth));
       if (image->matte != MagickFalse)
         {
-          quantum=PushLongPixel(MSBEndian,&p);
+          quantum=PushLongPixel(&p);
           pixel->opacity=(Quantum) (quantum >> (image->depth-QuantumDepth));
         }
       if (image->colorspace == CMYKColorspace)
         {
-          quantum=PushLongPixel(MSBEndian,&p);
+          quantum=PushLongPixel(&p);
           *index=(IndexPacket) (quantum >> (image->depth-QuantumDepth));
         }
       break;
@@ -1036,11 +1066,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].red=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].green=ScaleShortToQuantum(pixel);
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&p);
                   image->colormap[i].blue=ScaleShortToQuantum(pixel);
                 }
                 break;
@@ -1052,11 +1082,11 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
 
                 for (i=0; i < (long) image->colors; i++)
                 {
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].red=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].green=ScaleLongToQuantum(pixel);
-                  pixel=PushLongPixel(MSBEndian,&p);
+                  pixel=PushLongPixel(&p);
                   image->colormap[i].blue=ScaleLongToQuantum(pixel);
                 }
                 break;
@@ -1219,8 +1249,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
           {
             if (length == 0)
               {
-                p=ReadBlobStream(image,packet_size,pixels,&count);
-                PushRunlengthPacket(image,p,&length,&pixel,&index);
+                count=ReadBlob(image,packet_size,pixels);
+                PushRunlengthPacket(image,pixels,&length,&pixel,&index);
               }
             length--;
             if ((image->storage_class == PseudoClass) ||
@@ -1232,8 +1262,8 @@ static Image *ReadMIFFImage(const ImageInfo *image_info,
         }
         default:
         {
-          p=ReadBlobStream(image,packet_size*image->columns,pixels,&count);
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+          count=ReadBlob(image,packet_size*image->columns,pixels);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           break;
         }
       }
@@ -1392,7 +1422,29 @@ ModuleExport void UnregisterMIFFImage(void)
 %
 */
 
-static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
+static inline void PopCharPixel(const unsigned char pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopShortPixel(const unsigned short pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopLongPixel(const unsigned long pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 24);
+  *(*pixels)++=(unsigned char) ((pixel) >> 16);
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
   size_t length,PixelPacket pixel,IndexPacket index)
 {
   unsigned char
@@ -1429,7 +1481,7 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToLong(pixel.opacity);
-              PopLongPixel(MSBEndian,value,&q);
+              PopLongPixel(value,&q);
             }
           break;
         }
@@ -1441,7 +1493,7 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
           if (image->matte != MagickFalse)
             {
               value=ScaleQuantumToShort(pixel.opacity);
-              PopShortPixel(MSBEndian,value,&q);
+              PopShortPixel(value,&q);
             }
           break;
         }
@@ -1472,20 +1524,20 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
         value;
 
       value=ScaleQuantumToLong(pixel.red);
-      PopLongPixel(MSBEndian,value,&q);
+      PopLongPixel(value,&q);
       value=ScaleQuantumToLong(pixel.green);
-      PopLongPixel(MSBEndian,value,&q);
+      PopLongPixel(value,&q);
       value=ScaleQuantumToLong(pixel.blue);
-      PopLongPixel(MSBEndian,value,&q);
+      PopLongPixel(value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToLong(pixel.opacity);
-          PopLongPixel(MSBEndian,value,&q);
+          PopLongPixel(value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToLong(index);
-          PopLongPixel(MSBEndian,value,&q);
+          PopLongPixel(value,&q);
         }
       break;
     }
@@ -1495,20 +1547,20 @@ static inline size_t PopRunlengthPacket(Image *image,unsigned char *pixels,
         value;
 
       value=ScaleQuantumToShort(pixel.red);
-      PopShortPixel(MSBEndian,value,&q);
+      PopShortPixel(value,&q);
       value=ScaleQuantumToShort(pixel.green);
-      PopShortPixel(MSBEndian,value,&q);
+      PopShortPixel(value,&q);
       value=ScaleQuantumToShort(pixel.blue);
-      PopShortPixel(MSBEndian,value,&q);
+      PopShortPixel(value,&q);
       if (image->matte != MagickFalse)
         {
           value=ScaleQuantumToShort(pixel.opacity);
-          PopShortPixel(MSBEndian,value,&q);
+          PopShortPixel(value,&q);
         }
       if (image->colorspace == CMYKColorspace)
         {
           value=ScaleQuantumToShort(index);
-          PopShortPixel(MSBEndian,value,&q);
+          PopShortPixel(value,&q);
         }
       break;
     }
@@ -1936,11 +1988,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToLong(image->colormap[i].red);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].green);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(pixel,&q);
               pixel=ScaleQuantumToLong(image->colormap[i].blue);
-              PopLongPixel(MSBEndian,pixel,&q);
+              PopLongPixel(pixel,&q);
               break;
             }
             case 16:
@@ -1949,11 +2001,11 @@ static MagickBooleanType WriteMIFFImage(const ImageInfo *image_info,
                 pixel;
 
               pixel=ScaleQuantumToShort(image->colormap[i].red);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].green);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(pixel,&q);
               pixel=ScaleQuantumToShort(image->colormap[i].blue);
-              PopShortPixel(MSBEndian,pixel,&q);
+              PopShortPixel(pixel,&q);
               break;
             }
             case 8:
