@@ -359,8 +359,8 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if ((pcx_info.bits_per_pixel != 8) || (pcx_info.planes == 1))
       if ((pcx_info.version == 3) || (pcx_info.version == 5) ||
           ((pcx_info.bits_per_pixel*pcx_info.planes) == 1))
-        image->colors=(unsigned long) MagickMin(1UL << (pcx_info.bits_per_pixel*
-          pcx_info.planes),256UL);
+        image->colors=(unsigned long) MagickMin(1UL << (1UL*
+          pcx_info.bits_per_pixel*pcx_info.planes),256UL);
     if (AllocateImageColormap(image,image->colors) == MagickFalse)
       ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
     if ((pcx_info.bits_per_pixel >= 8) && (pcx_info.planes != 1))
@@ -444,12 +444,12 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
               /*
                 Monochrome colormap.
               */
-              image->colormap[0].red=0;
-              image->colormap[0].green=0;
-              image->colormap[0].blue=0;
-              image->colormap[1].red=(Quantum) QuantumRange;
-              image->colormap[1].green=(Quantum) QuantumRange;
-              image->colormap[1].blue=(Quantum) QuantumRange;
+              image->colormap[0].red=(Quantum) 0;
+              image->colormap[0].green=(Quantum) 0;
+              image->colormap[0].blue=(Quantum) 0;
+              image->colormap[1].red=QuantumRange;
+              image->colormap[1].green=QuantumRange;
+              image->colormap[1].blue=QuantumRange;
             }
           else
             if (image->colors > 16)
@@ -600,7 +600,7 @@ static Image *ReadPCXImage(const ImageInfo *image_info,ExceptionInfo *exception)
       for (x=0; x < (long) image->columns; x++)
       {
         if (image->storage_class == PseudoClass)
-          indexes[x]=(*r++);
+          indexes[x]=(IndexPacket) (*r++);
         else
           {
             q->red=ScaleCharToQuantum(*r++);
@@ -1088,7 +1088,7 @@ static MagickBooleanType WritePCXImage(const ImageInfo *image_info,Image *image)
             Convert PseudoClass image to a PCX monochrome image.
           */
           polarity=(IndexPacket) (PixelIntensityToQuantum(&image->colormap[0]) <
-            ((Quantum) QuantumRange/2) ? 1 : 0);
+            (QuantumRange/2) ? 1 : 0);
           if (image->colors == 2)
             polarity=(IndexPacket) (
               PixelIntensityToQuantum(&image->colormap[0]) <
