@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -164,7 +164,7 @@ static MagickBooleanType InvokePostscriptDelegate(
   NTGhostscriptUnLoadDLL();
 #endif
   for (i=0; i < (long) argc; i++)
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]);
+    argv[i]=DestroyString(argv[i]);
   argv=(char **) RelinquishMagickMemory(argv);
   if ((status == 0) || (status <= -100))
     {
@@ -416,7 +416,7 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
         value=AcquireString(name);
         (void) SubstituteString(&value,"#20"," ");
         (void) SetImageProperty(image,property,value);
-        value=(char *) RelinquishMagickMemory(value);
+        value=DestroyString(value);
         continue;
       }
     if (LocaleNCompare(PDFVersion,command,strlen(PDFVersion)) == 0)
@@ -465,7 +465,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
           }
     if (count != 4)
       continue;
-    if ((bounds.x2 > hires_bounds.x2) && (bounds.y2 > hires_bounds.y2))
+    if (((unsigned long) (bounds.x2-bounds.x1+0.5) > page.width) ||
+        ((unsigned long) (bounds.y2-bounds.y1+0.5) > page.height))
       {
         /*
           Set PDF render geometry.
@@ -520,6 +521,8 @@ static Image *ReadPDFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       return((Image *) NULL);
     }
   *options='\0';
+  if (cmyk != MagickFalse)
+    (void) ConcatenateMagickString(options,"-dUseCIEColor ",MaxTextExtent);
   if (cropbox != MagickFalse)
     (void) ConcatenateMagickString(options,"-dUseCropBox ",MaxTextExtent);
   if (trimbox != MagickFalse)
@@ -732,7 +735,7 @@ static char *EscapeParenthesis(const char *text)
 static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
 {
 #define CFormat  "/Filter [ /%s ]\n"
-#define ObjectsPerImage  14
+#define ObjectsPerImage  13
 
   char
     buffer[MaxTextExtent],
@@ -1103,7 +1106,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
             labels[i]);
           (void) WriteBlobString(image,buffer);
           (void) WriteBlobString(image,"ET\n");
-          labels[i]=(char *) RelinquishMagickMemory(labels[i]);
+          labels[i]=DestroyString(labels[i]);
         }
         labels=(char **) RelinquishMagickMemory(labels);
       }
@@ -1668,7 +1671,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
         (void) WriteBlobString(image,buffer);
         (void) FormatMagickString(buffer,MaxTextExtent,
           "/DecodeParms [ << /K %s /Columns %lu /Rows %lu >> ]\n",
-          CCITTParam,image->columns,image->rows);
+          CCITTParam,tile_image->columns,tile_image->rows);
         break;
       }
       default:
@@ -1915,7 +1918,7 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
               /*
                 Allocate pixel array.
               */
-              length=(size_t) number_pixels;
+              length=(size_t) number_pixels*sizeof(*pixels);
               pixels=(unsigned char *) AcquireMagickMemory(length);
               if (pixels == (unsigned char *) NULL)
                 {
@@ -1989,13 +1992,13 @@ static MagickBooleanType WritePDFImage(const ImageInfo *image_info,Image *image)
       (unsigned long) offset);
     (void) WriteBlobString(image,buffer);
     (void) WriteBlobString(image,"endobj\n");
-    xref[object++]=TellBlob(image);
     if ((image->storage_class != DirectClass) && (image->colors <= 256) &&
         (compression != FaxCompression) && (compression != Group4Compression))
       {
         /*
           Write Colormap object.
         */
+        xref[object++]=TellBlob(image);
         (void) FormatMagickString(buffer,MaxTextExtent,"%lu 0 obj\n",object);
         (void) WriteBlobString(image,buffer);
         (void) WriteBlobString(image,"<<\n");
