@@ -161,10 +161,10 @@ static Image *ReadPIXImage(const ImageInfo *image_info,ExceptionInfo *exception)
     /*
       Convert PIX raster image to pixel packets.
     */
-    red=0;
-    green=0;
-    blue=0;
-    index=0;
+    red=(Quantum) 0;
+    green=(Quantum) 0;
+    blue=(Quantum) 0;
+    index=(IndexPacket) 0;
     length=0;
     for (y=0; y < (long) image->rows; y++)
     {
