@@ -55,7 +55,6 @@
 #include "magick/monitor.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
-#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/statistic.h"
 #include "magick/string_.h"
@@ -221,6 +220,37 @@ static unsigned long PNMInteger(Image *image,const unsigned int base)
   return(value);
 }
 
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
 static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
 {
   char
@@ -418,7 +448,8 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (image->storage_class == PseudoClass)
       if (AllocateImageColormap(image,image->colors) == MagickFalse)
         ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
-    if ((image->storage_class != PseudoClass) || (max_value > QuantumRange))
+    if ((image->storage_class != PseudoClass) ||
+        (max_value > (1U*QuantumRange)))
       {
         /*
           Compute pixel scaling table.
@@ -649,7 +680,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              index=(long) PushShortPixel(MSBEndian,&p);
+              index=(long) PushShortPixel(&p);
               if (index >= (long) image->colors)
                 {
                   (void) ThrowMagickException(&image->exception,
@@ -726,9 +757,9 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           else
             for (x=0; x < (long) image->columns; x++)
             {
-              pixel.red=(MagickRealType) PushShortPixel(MSBEndian,&p);
-              pixel.green=(MagickRealType) PushShortPixel(MSBEndian,&p);
-              pixel.blue=(MagickRealType) PushShortPixel(MSBEndian,&p);
+              pixel.red=(MagickRealType) PushShortPixel(&p);
+              pixel.green=(MagickRealType) PushShortPixel(&p);
+              pixel.blue=(MagickRealType) PushShortPixel(&p);
               if (scale != (Quantum *) NULL)
                 {
                   pixel.red=(MagickRealType) scale[ConstrainPixel(image,(long)
@@ -813,7 +844,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   if (image->matte != MagickFalse)
                     {
                       pixel=PushCharPixel(&p);
-                      q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                         (1UL << image->depth)-1);
                     }
                   q++;
@@ -821,20 +852,20 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
               else
                 for (x=0; x < (long) image->columns; x++)
                 {
-                  pixel=PushShortPixel(MSBEndian,&p);
+                  pixel=PushShortPixel(&p);
                   q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
                   q->green=q->red;
                   q->blue=q->red;
                   if (image->colorspace == CMYKColorspace)
                     {
-                      pixel=PushShortPixel(MSBEndian,&p);
+                      pixel=PushShortPixel(&p);
                       indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
                         (1UL << image->depth)-1);
                     }
                   if (image->matte != MagickFalse)
                     {
-                      pixel=PushShortPixel(MSBEndian,&p);
-                      q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                      pixel=PushShortPixel(&p);
+                      q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                         (1UL << image->depth)-1);
                     }
                   q++;
@@ -859,7 +890,7 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
                 if (image->matte != MagickFalse)
                   {
                     pixel=PushCharPixel(&p);
-                    q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                       (1UL << image->depth)-1);
                   }
                 q++;
@@ -867,22 +898,22 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
             else
               for (x=0; x < (long) image->columns; x++)
               {
-                pixel=PushShortPixel(MSBEndian,&p);
+                pixel=PushShortPixel(&p);
                 q->red=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                pixel=PushShortPixel(MSBEndian,&p);
+                pixel=PushShortPixel(&p);
                 q->green=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
-                pixel=PushShortPixel(MSBEndian,&p);
+                pixel=PushShortPixel(&p);
                 q->blue=ScaleAnyToQuantum(pixel,(1UL << image->depth)-1);
                 if (image->colorspace == CMYKColorspace)
                   {
-                    pixel=PushShortPixel(MSBEndian,&p);
+                    pixel=PushShortPixel(&p);
                     indexes[x]=(IndexPacket) ScaleAnyToQuantum(pixel,
                       (1UL << image->depth)-1);
                   }
                 if (image->matte != MagickFalse)
                   {
-                    pixel=PushShortPixel(MSBEndian,&p);
-                    q->opacity=(Quantum) QuantumRange-ScaleAnyToQuantum(pixel,
+                    pixel=PushShortPixel(&p);
+                    q->opacity=QuantumRange-ScaleAnyToQuantum(pixel,
                       (1UL << image->depth)-1);
                   }
                 q++;
@@ -911,9 +942,6 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         QuantumType
           quantum_type;
 
-        register const unsigned char
-          *p;
-
         ssize_t
           count;
 
@@ -930,10 +958,10 @@ static Image *ReadPNMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           q=SetImagePixels(image,0,y,image->columns,1);
           if (q == (PixelPacket *) NULL)
             break;
-          p=ReadBlobStream(image,length,pixels,&count);
+          count=ReadBlob(image,length,pixels);
           if ((size_t) count != length)
             break;
-          status=ExportQuantumPixels(image,&quantum_info,quantum_type,p);
+          status=ExportQuantumPixels(image,&quantum_info,quantum_type,pixels);
           if (SyncImagePixels(image) == MagickFalse)
             break;
           if (image->previous == (Image *) NULL)
@@ -1121,6 +1149,29 @@ ModuleExport void UnregisterPNMImage(void)
 %    o image:  The image.
 %
 */
+
+static inline void PopCharPixel(const unsigned char pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopShortPixel(const unsigned short pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
+static inline void PopLongPixel(const unsigned long pixel,
+  unsigned char **pixels)
+{
+  *(*pixels)++=(unsigned char) ((pixel) >> 24);
+  *(*pixels)++=(unsigned char) ((pixel) >> 16);
+  *(*pixels)++=(unsigned char) ((pixel) >> 8);
+  *(*pixels)++=(unsigned char) (pixel);
+}
+
 static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
 {
   char
@@ -1646,12 +1697,12 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
 
                   pixel=(unsigned short) ScaleQuantumToAny(
                     PixelIntensityToQuantum(p),(1UL << depth)-1);
-                  PopShortPixel(MSBEndian,pixel,&q);
+                  PopShortPixel(pixel,&q);
                   if (image->matte != MagickFalse)
                     {
                       pixel=(unsigned short) ScaleQuantumToAny((Quantum)
                         (QuantumRange-p->opacity),(1UL << depth)-1UL);
-                      PopShortPixel(MSBEndian,pixel,&q);
+                      PopShortPixel(pixel,&q);
                     }
                   p++;
                 }
@@ -1688,18 +1739,18 @@ static MagickBooleanType WritePNMImage(const ImageInfo *image_info,Image *image)
 
                 pixel=(unsigned short) ScaleQuantumToAny(p->red,
                   (1UL << depth)-1);
-                PopShortPixel(MSBEndian,pixel,&q);
+                PopShortPixel(pixel,&q);
                 pixel=(unsigned short) ScaleQuantumToAny(p->green,
                   (1UL << depth)-1);
-                PopShortPixel(MSBEndian,pixel,&q);
+                PopShortPixel(pixel,&q);
                 pixel=(unsigned short) ScaleQuantumToAny(p->blue,
                   (1UL << depth)-1);
-                PopShortPixel(MSBEndian,pixel,&q);
+                PopShortPixel(pixel,&q);
                 if (image->matte != MagickFalse)
                   {
                     pixel=(unsigned short) ScaleQuantumToAny((Quantum)
                       (QuantumRange-p->opacity),(1UL << depth)-1UL);
-                    PopShortPixel(MSBEndian,pixel,&q);
+                    PopShortPixel(pixel,&q);
                   }
                 p++;
               }
