@@ -1575,7 +1575,7 @@ static MagickBooleanType WritePSImage(const ImageInfo *image_info,Image *image)
     (void) ResetMagickMemory(&pixel,0,sizeof(pixel));
     pixel.opacity=TransparentOpacity;
     i=0;
-    index=0;
+    index=(IndexPacket) 0;
     x=0;
     type=GetImageType(image,&image->exception);
     if ((image_info->type != TrueColorType) &&
