@@ -57,7 +57,6 @@
 #include "magick/profile.h"
 #include "magick/property.h"
 #include "magick/quantum.h"
-#include "magick/quantum-private.h"
 #include "magick/static.h"
 #include "magick/string_.h"
 
@@ -440,6 +439,37 @@ static char *ModeToString( PSDImageType inType )
   }
 }
 
+static inline unsigned char PushCharPixel(const unsigned char **pixels)
+{
+  unsigned char
+    pixel;
+
+  pixel=(unsigned char) *(*pixels)++;
+  return(pixel);
+}
+
+static inline unsigned long PushLongPixel(const unsigned char **pixels)
+{
+  unsigned long
+    pixel;
+
+  pixel=(unsigned long) (*(*pixels)++ << 24);
+  pixel|=(unsigned long) (*(*pixels)++ << 16);
+  pixel|=(unsigned long) (*(*pixels)++ << 8);
+  pixel|=(unsigned long) (*(*pixels)++);
+  return(pixel);
+}
+
+static inline unsigned short PushShortPixel(const unsigned char **pixels)
+{
+  unsigned short
+    pixel;
+
+  pixel=(unsigned short) (*(*pixels)++ << 8);
+  pixel|=(unsigned short) (*(*pixels)++);
+  return(pixel);
+}
+
 static MagickBooleanType ParseImageResourceBlocks(Image *image,
   const unsigned char *blocks,size_t length)
 {
@@ -464,10 +494,10 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
   {
     if (LocaleNCompare((char *) p,"8BIM",4) != 0)
       break;
-    sans=PushLongPixel(MSBEndian,&p);
-    id=PushShortPixel(MSBEndian,&p);
-    sans=PushShortPixel(MSBEndian,&p);
-    count=PushLongPixel(MSBEndian,&p);
+    sans=PushLongPixel(&p);
+    id=PushShortPixel(&p);
+    sans=PushShortPixel(&p);
+    count=PushLongPixel(&p);
     switch (id)
     {
       case 0x03ed:
@@ -478,16 +508,16 @@ static MagickBooleanType ParseImageResourceBlocks(Image *image,
         /*
           Resolution info.
         */
-        resolution=PushShortPixel(MSBEndian,&p);
+        resolution=PushShortPixel(&p);
         image->x_resolution=(double) resolution;
-        sans=PushShortPixel(MSBEndian,&p);
-        sans=PushShortPixel(MSBEndian,&p);
-        sans=PushShortPixel(MSBEndian,&p);
-        resolution=PushShortPixel(MSBEndian,&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        resolution=PushShortPixel(&p);
         image->y_resolution=(double) resolution;
-        sans=PushShortPixel(MSBEndian,&p);
-        sans=PushShortPixel(MSBEndian,&p);
-        sans=PushShortPixel(MSBEndian,&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
+        sans=PushShortPixel(&p);
         break;
       }
       default:
@@ -1198,7 +1228,7 @@ static Image *ReadPSDImage(const ImageInfo *image_info,ExceptionInfo *exception)
                   indexes=GetIndexes(layer_info[i].image);
                   for (x=0; x < (long) layer_info[i].image->columns; x++)
                   {
-                    q->opacity=(Quantum) QuantumRange-(Quantum)
+                    q->opacity=QuantumRange-(Quantum)
                       (QuantumScale*(q->opacity*layer_info[i].opacity));
                     q++;
                   }
