@@ -866,7 +866,7 @@ static MagickBooleanType WriteSUNImage(const ImageInfo *image_info,Image *image)
             for (x=0; x < (long) image->columns; x++)
             {
               byte<<=1;
-              if (PixelIntensity(p) < ((Quantum) QuantumRange/2.0))
+              if (PixelIntensity(p) < (QuantumRange/2.0))
                 byte|=0x01;
               bit++;
               if (bit == 8)
