@@ -367,7 +367,7 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
     flag=0;
     skip=MagickFalse;
     real=0;
-    index=0;
+    index=(IndexPacket) 0;
     runlength=0;
     offset=0;
     for (y=0; y < (long) image->rows; y++)
@@ -413,7 +413,8 @@ static Image *ReadTGAImage(const ImageInfo *image_info,ExceptionInfo *exception)
               */
               index=(IndexPacket) ReadBlobByte(image);
               if (tga_info.colormap_type != 0)
-                pixel=image->colormap[(long) ConstrainColormapIndex(image,index)];
+                pixel=image->colormap[(long) ConstrainColormapIndex(image,
+                  1UL*index)];
               else
                 {
                   pixel.red=ScaleCharToQuantum((unsigned char) index);
