@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -169,7 +169,7 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
     if (tim_info.id != 0x00000010)
       ThrowReaderException(CorruptImageError,"ImproperImageHeader");
     tim_info.flag=ReadBlobLSBLong(image);
-    has_clut=!!(tim_info.flag & (1 << 3));
+    has_clut=tim_info.flag & (1 << 3) ? 1 : 0;
     pixel_mode=tim_info.flag & 0x07;
     switch ((int) pixel_mode)
     {
@@ -192,7 +192,9 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         (void)ReadBlobLSBShort(image);
         width=ReadBlobLSBShort(image);
         height=ReadBlobLSBShort(image);
-        if (AllocateImageColormap(image,pixel_mode == 1 ? 256 : 16) == MagickFalse)
+        image->columns=width;
+        image->rows=height;
+        if (AllocateImageColormap(image,pixel_mode == 1 ? 256UL : 16UL) == MagickFalse)
           ThrowReaderException(ResourceLimitError,"MemoryAllocationFailed");
         tim_colormap=(unsigned char *) AcquireMagickMemory(image->colors*2);
         if (tim_colormap == (unsigned char *) NULL)
@@ -205,12 +207,12 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
         {
           word=(*p++);
           word|=(unsigned short) (*p++ << 8);
-          image->colormap[i].blue=
-            ScaleCharToQuantum(ScaleColor5to8((word >> 10) & 0x1f));
-          image->colormap[i].green=
-            ScaleCharToQuantum(ScaleColor5to8((word >> 5) & 0x1f));
-          image->colormap[i].red=
-            ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
+          image->colormap[i].blue=ScaleCharToQuantum(
+            ScaleColor5to8(1UL*(word >> 10) & 0x1f));
+          image->colormap[i].green=ScaleCharToQuantum(
+            ScaleColor5to8(1UL*(word >> 5) & 0x1f));
+          image->colormap[i].red=ScaleCharToQuantum(
+            ScaleColor5to8(1UL*word & 0x1f));
         }
         tim_colormap=(unsigned char *) RelinquishMagickMemory(tim_colormap);
       }
@@ -259,13 +261,13 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           p=tim_pixels+y*bytes_per_line;
           for (x=0; x < ((long) image->columns-1); x+=2)
           {
-            indexes[x]=(*p) & 0xf;
-            indexes[x+1]=(*p >> 4) & 0xf;
+            indexes[x]=(IndexPacket) ((*p) & 0x0f);
+            indexes[x+1]=(IndexPacket) ((*p >> 4) & 0x0f);
             p++;
           }
           if ((image->columns % 2) != 0)
             {
-              indexes[x]=(*p >> 4) & 0xf;
+              indexes[x]=(IndexPacket) ((*p >> 4) & 0x0f);
               p++;
             }
           if (SyncImagePixels(image) == MagickFalse)
@@ -323,9 +325,9 @@ static Image *ReadTIMImage(const ImageInfo *image_info,ExceptionInfo *exception)
           {
             word=(*p++);
             word|=(*p++ << 8);
-            q->blue=ScaleCharToQuantum(ScaleColor5to8((word >> 10) & 0x1f));
-            q->green=ScaleCharToQuantum(ScaleColor5to8((word >> 5) & 0x1f));
-            q->red=ScaleCharToQuantum(ScaleColor5to8(word & 0x1f));
+            q->blue=ScaleCharToQuantum(ScaleColor5to8((1UL*word >> 10) & 0x1f));
+            q->green=ScaleCharToQuantum(ScaleColor5to8((1UL*word >> 5) & 0x1f));
+            q->red=ScaleCharToQuantum(ScaleColor5to8(1UL*word & 0x1f));
             q++;
           }
           if (SyncImagePixels(image) == MagickFalse)
