@@ -455,7 +455,7 @@ static Image *ReadTXTImage(const ImageInfo *image_info,ExceptionInfo *exception)
         *indexes=ScaleAnyToQuantum(pixel.index,max_value);
       }
     if (image->matte != MagickFalse)
-      q->opacity=(Quantum) QuantumRange-
+      q->opacity=QuantumRange-
         ScaleAnyToQuantum(pixel.opacity,max_value);
     (void) SyncImagePixels(image);
   }
