@@ -276,12 +276,12 @@ static Image *ReadXBMImage(const ImageInfo *image_info,ExceptionInfo *exception)
   /*
     Initialize colormap.
   */
-  image->colormap[0].red=(Quantum) QuantumRange;
-  image->colormap[0].green=(Quantum) QuantumRange;
-  image->colormap[0].blue=(Quantum) QuantumRange;
-  image->colormap[1].red=0;
-  image->colormap[1].green=0;
-  image->colormap[1].blue=0;
+  image->colormap[0].red=QuantumRange;
+  image->colormap[0].green=QuantumRange;
+  image->colormap[0].blue=QuantumRange;
+  image->colormap[1].red=(Quantum) 0;
+  image->colormap[1].green=(Quantum) 0;
+  image->colormap[1].blue=(Quantum) 0;
   if (image_info->ping != MagickFalse)
     {
       CloseBlob(image);
