@@ -17,7 +17,7 @@
 %                               November 2001                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -267,13 +267,23 @@ static CompositeOperator GIMPBlendModeToCompositeOperator( unsigned long blendMo
 %
 %    o string: The address of a character buffer.
 %
-%
 */
+
+static inline size_t MagickMin(const size_t x,const size_t y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
 static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
 {
   int
     c;
 
+  MagickOffsetType
+    offset;
+
   register long
     i;
 
@@ -285,8 +295,8 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
   assert(max != 0);
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
-  length = ReadBlobMSBLong(image);
-  for (i=0; i < (long) Min(length, max-1); i++)
+  length=ReadBlobMSBLong(image);
+  for (i=0; i < (long) MagickMin(length,max-1); i++)
   {
     c=ReadBlobByte(image);
     if (c == EOF)
@@ -294,7 +304,10 @@ static char *ReadBlobStringWithLongSize(Image *image,char *string,size_t max)
     string[i]=(char) c;
   }
   string[i]='\0';
-  (void) SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
+  offset=SeekBlob(image,(MagickOffsetType) (length-i),SEEK_CUR);
+  if (offset < 0)
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
   return(string);
 }
 
@@ -311,6 +324,8 @@ static int load_tile (Image* image, Image* tile_image, XCFDocInfo* inDocInfo,
   xcfdata = xcfodata = (XCFPixelPacket *) AcquireMagickMemory(data_length);
   graydata = (unsigned char *)xcfdata;  /* used by gray and indexed */
   nmemb_read_successfully = ReadBlob(image, data_length, (unsigned char *) xcfdata);
+  if (nmemb_read_successfully > (ssize_t) (tile_image->columns*tile_image->rows))
+    ThrowBinaryException(CorruptImageError,"NotEnoughPixelData",image->filename);
 
   q=SetImagePixels(tile_image,0,0,tile_image->columns,tile_image->rows);
 
@@ -558,7 +573,7 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
                          than we need to allow */
 
       /* seek to the tile offset */
-      (void) SeekBlob(image, offset, SEEK_SET);
+      offset=SeekBlob(image, offset, SEEK_SET);
 
       /* allocate the image for the tile
         NOTE: the last tile in a row or column may not be a full tile!
@@ -611,7 +626,7 @@ static int load_level (Image* image, XCFDocInfo* inDocInfo, XCFLayerInfo*
       /* restore the saved position so we'll be ready to
        *  read the next offset.
        */
-      (void) SeekBlob(image, saved_pos, SEEK_SET);
+      offset=SeekBlob(image, saved_pos, SEEK_SET);
 
       /* read in the offset of the next tile */
       offset = (MagickOffsetType) ReadBlobMSBLong(image);
@@ -661,7 +676,7 @@ static int load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLayerInfo*
   saved_pos = TellBlob(image);
 
   /* seek to the level offset */
-  (void) SeekBlob(image, offset, SEEK_SET);
+  offset=SeekBlob(image, offset, SEEK_SET);
 
   /* read in the level */
   if (load_level (image, inDocInfo, inLayer) == 0)
@@ -670,7 +685,7 @@ static int load_hierarchy (Image *image, XCFDocInfo* inDocInfo, XCFLayerInfo*
   /* restore the saved position so we'll be ready to
    *  read the next offset.
    */
-  (void) SeekBlob(image, saved_pos, SEEK_SET);
+  offset=SeekBlob(image, saved_pos, SEEK_SET);
 
   return 1;
 }
@@ -682,6 +697,9 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   long
     i;
 
+  MagickOffsetType
+    offset;
+
   unsigned int
     foundPropEnd = 0;
 
@@ -783,12 +801,12 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
       /* read over it... */
       while ((prop_size > 0) && (EOFBlob(image) == MagickFalse))
         {
-        amount = (ssize_t) Min (16, prop_size);
+        amount = (ssize_t) MagickMin(16, prop_size);
         amount = ReadBlob(image, (size_t) amount, (unsigned char *) &buf);
         if (!amount)
           ThrowBinaryException(CorruptImageError,"CorruptImage",
             image->filename);
-        prop_size -= Min (16, amount);
+        prop_size -= (unsigned long) MagickMin(16, (size_t) amount);
         }
       }
       break;
@@ -815,14 +833,17 @@ static MagickBooleanType ReadOneLayer(Image* image,XCFDocInfo* inDocInfo,
   layer_mask_offset = ReadBlobMSBLong(image);
 
   /* read in the hierarchy */
-  (void) SeekBlob(image, (MagickOffsetType) hierarchy_offset, SEEK_SET);
+  offset=SeekBlob(image, (MagickOffsetType) hierarchy_offset, SEEK_SET);
+  if (offset < 0)
+    (void) ThrowMagickException(&image->exception,GetMagickModule(),
+      CorruptImageError,"InvalidImageHeader","`%s'",image->filename);
   if (load_hierarchy (image, inDocInfo, outLayer) == 0)
     return(MagickFalse);
 
   /* read in the layer mask */
   if (layer_mask_offset != 0)
     {
-      (void) SeekBlob(image, (MagickOffsetType) layer_mask_offset, SEEK_SET);
+      offset=SeekBlob(image, (MagickOffsetType) layer_mask_offset, SEEK_SET);
 
 #if 0  /* BOGUS: support layer masks! */
       layer_mask = xcf_load_layer_mask (info, gimage);
@@ -896,6 +917,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   MagickBooleanType
     status;
 
+  MagickOffsetType
+    offset;
+
   register long
     i;
 
@@ -933,6 +957,8 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
   doc_info.exception=exception;
   doc_info.width=ReadBlobMSBLong(image);
   doc_info.height=ReadBlobMSBLong(image);
+  if ((doc_info.width > 262144) || (doc_info.height > 262144))
+    ThrowReaderException(CorruptImageError,"ImproperImageHeader");
   doc_info.image_type=ReadBlobMSBLong(image);
   /*
     Initialize image attributes.
@@ -1119,11 +1145,11 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /* read over it... */
       while ((prop_size > 0) && (EOFBlob(image) == MagickFalse))
       {
-        amount = (long) Min (16, prop_size);
+        amount = (long) MagickMin(16, prop_size);
         amount = (long) ReadBlob(image,(size_t) amount, (unsigned char *) &buf);
         if (!amount)
           ThrowReaderException(CorruptImageError,"CorruptImage");
-        prop_size -= Min (16, amount);
+        prop_size -= (unsigned long) MagickMin(16, (size_t) amount);
       }
     }
     break;
@@ -1156,7 +1182,9 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       else
         number_layers++;
     } while (foundAllLayers  == MagickFalse);
-    (void) SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
+    offset=SeekBlob(image, oldPos, SEEK_SET); /* restore the position! */
+    if (offset < 0)
+      ThrowReaderException(CorruptImageError,"ImproperImageHeader");
 
 
     /* allocate our array of layer info blocks */
@@ -1189,7 +1217,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       saved_pos = TellBlob(image);
 
       /* seek to the layer offset */
-      (void) SeekBlob(image, offset, SEEK_SET);
+      offset=SeekBlob(image, offset, SEEK_SET);
 
       /* read in the layer */
       layer_ok = ReadOneLayer( image, &doc_info, &layer_info[current_layer] );
@@ -1203,7 +1231,7 @@ static Image *ReadXCFImage(const ImageInfo *image_info,ExceptionInfo *exception)
       /* restore the saved position so we'll be ready to
       *  read the next offset.
       */
-      (void) SeekBlob(image, saved_pos, SEEK_SET);
+      offset=SeekBlob(image, saved_pos, SEEK_SET);
 
       current_layer++;
     }
