@@ -23,7 +23,7 @@
 %                               February 2000                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -55,6 +55,24 @@
 #include "magick/exception-private.h"
 #include "magick/string_.h"
 
+/*
+  Typedef declarations.
+*/
+struct _ViewInfo
+{
+  Image
+    *image;
+
+  VirtualPixelMethod
+    virtual_pixel_method;
+
+  unsigned long
+    id;
+
+  unsigned long
+    signature;
+};
+
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
@@ -85,7 +103,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
   const long x,const long y,const unsigned long columns,
@@ -100,8 +117,8 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
   if (view_info->image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
       view_info->image->filename);
-  pixels=AcquireCacheNexus(view_info->image,x,y,columns,rows,view_info->id,
-    exception);
+  pixels=AcquireCacheNexus(view_info->image,view_info->virtual_pixel_method,x,y,
+    columns,rows,view_info->id,exception);
   return(pixels);
 }
 
@@ -110,6 +127,47 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   A c q u i r e O n e C a c h e V i e w P i x e l                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  AcquireCacheView() returns a single pixel at the specified (x,y) location.
+%  The image background color is returned if an error occurs.  If you plan to
+%  modify the pixel, use GetOneCacheViewPixel() instead.
+%
+%  The format of the AcquireOneCacheViewPixel method is:
+%
+%      PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+%        const long x,const long y,ExceptionInfo *exception)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o x,y:  These values define the offset of the pixel.
+%
+%    o exception: Return any errors or warnings in this structure.
+%
+*/
+MagickExport PixelPacket AcquireOneCacheViewPixel(const ViewInfo *view_info,
+  const long x,const long y,ExceptionInfo *exception)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(AcquireOnePixel(view_info->image,x,y,exception));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   C l o s e C a c h e V i e w                                               %
 %                                                                             %
 %                                                                             %
@@ -121,14 +179,14 @@ MagickExport const PixelPacket *AcquireCacheView(const ViewInfo *view_info,
 %
 %  The format of the CloseCacheView method is:
 %
-%      void CloseCacheView(ViewInfo *view_info)
+%      ViewInfo *CloseCacheView(ViewInfo *view_info)
 %
 %  A description of each parameter follows:
 %
 %    o view_info: The address of a structure of type ViewInfo.
 %
 */
-MagickExport void CloseCacheView(ViewInfo *view_info)
+MagickExport ViewInfo *CloseCacheView(ViewInfo *view_info)
 {
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
@@ -141,6 +199,7 @@ MagickExport void CloseCacheView(ViewInfo *view_info)
   view_info->image=DestroyImage(view_info->image);
   view_info->signature=(~MagickSignature);
   view_info=(ViewInfo *) RelinquishMagickMemory(view_info);
+  return(view_info);
 }
 
 /*
@@ -173,10 +232,9 @@ MagickExport void CloseCacheView(ViewInfo *view_info)
 %    o x,y,columns,rows:  These values define the perimeter of a region of
 %      pixels.
 %
-%
 */
-MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,const long y,
-  const unsigned long columns,const unsigned long rows)
+MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,
+  const long y,const unsigned long columns,const unsigned long rows)
 {
   assert(view_info != (ViewInfo *) NULL);
   assert(view_info->signature == MagickSignature);
@@ -192,6 +250,74 @@ MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,const lo
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t C a c h e V i e w C o l o r s p a c e                               %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetCacheViewColorspace() returns the image colorspace associated with the
+%  specified view.
+%
+%  The format of the GetCacheViewColorspace method is:
+%
+%      ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+*/
+MagickExport ColorspaceType GetCacheViewColorspace(const ViewInfo *view_info)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(view_info->image->colorspace);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   G e t C a c h e V i e w E x c e p t i o n                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetCacheViewException() returns the image exception associated with the
+%  specified view.
+%
+%  The format of the GetCacheViewException method is:
+%
+%      ExceptionInfo GetCacheViewException(const ViewInfo *view_info)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+*/
+MagickExport ExceptionInfo *GetCacheViewException(const ViewInfo *view_info)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(&view_info->image->exception);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   G e t C a c h e V i e w I n d e x e s                                     %
 %                                                                             %
 %                                                                             %
@@ -209,7 +335,6 @@ MagickExport PixelPacket *GetCacheView(ViewInfo *view_info,const long x,const lo
 %
 %    o view_info: The address of a structure of type ViewInfo.
 %
-%
 */
 MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
 {
@@ -243,7 +368,6 @@ MagickExport IndexPacket *GetCacheViewIndexes(const ViewInfo *view_info)
 %
 %    o view_info: The address of a structure of type ViewInfo.
 %
-%
 */
 MagickExport PixelPacket *GetCacheViewPixels(const ViewInfo *view_info)
 {
@@ -261,6 +385,78 @@ MagickExport PixelPacket *GetCacheViewPixels(const ViewInfo *view_info)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   G e t C a c h e V i e w S t o r a g e C l a s s                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetCacheViewStorageClass() returns the image storage class  associated with
+%  the specified view.
+%
+%  The format of the GetCacheViewStorageClass method is:
+%
+%      ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+*/
+MagickExport ClassType GetCacheViewStorageClass(const ViewInfo *view_info)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(view_info->image->storage_class);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%   G e t O n e C a c h e V i e w P i x e l                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GetOneCacheViewPixel() returns a single pixel at the specified (x,y)
+%  location.  The image background color is returned if an error occurs.
+%
+%  The format of the GetOneCacheViewPixel method is:
+%
+%      PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+%        const long x,const long y)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o x,y:  These values define the offset of the pixel.
+%
+*/
+MagickExport PixelPacket GetOneCacheViewPixel(const ViewInfo *view_info,
+  const long x,const long y)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(GetOnePixel(view_info->image,x,y));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   O p e n C a c h e V i e w                                                 %
 %                                                                             %
 %                                                                             %
@@ -271,15 +467,14 @@ MagickExport PixelPacket *GetCacheViewPixels(const ViewInfo *view_info)
 %
 %  The format of the OpenCacheView method is:
 %
-%      ViewInfo *OpenCacheView(Image *image)
+%      ViewInfo *OpenCacheView(const Image *image)
 %
 %  A description of each parameter follows:
 %
 %    o image: The image.
 %
-%
 */
-MagickExport ViewInfo *OpenCacheView(Image *image)
+MagickExport ViewInfo *OpenCacheView(const Image *image)
 {
   ViewInfo
     *view_info;
@@ -292,8 +487,9 @@ MagickExport ViewInfo *OpenCacheView(Image *image)
   if (view_info == (ViewInfo *) NULL)
     ThrowMagickFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
       image->filename);
-  (void) ResetMagickMemory(view_info,0,sizeof(ViewInfo));
-  view_info->image=ReferenceImage(image);
+  (void) ResetMagickMemory(view_info,0,sizeof(*view_info));
+  view_info->image=ReferenceImage((Image *) image);
+  view_info->virtual_pixel_method=GetImageVirtualPixelMethod(image);
   view_info->id=GetNexus(view_info->image->cache);
   view_info->signature=MagickSignature;
   return(view_info);
@@ -304,6 +500,44 @@ MagickExport ViewInfo *OpenCacheView(Image *image)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   O p e n V i r t u a l C a c h e V i e w                                   %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  OpenVirtualCacheView() opens a view into the pixel cache.
+%
+%  The format of the OpenCacheView method is:
+%
+%      ViewInfo *OpenVirtualCacheView(const Image *image,
+%        const VirtualPixelMethod virtual_pixel_method)
+%
+%  A description of each parameter follows:
+%
+%    o image: The image.
+%
+%    o virtual_pixel_method: The virtual pixel method.
+%
+*/
+MagickExport ViewInfo *OpenVirtualCacheView(const Image *image,
+  const VirtualPixelMethod virtual_pixel_method)
+{
+  ViewInfo
+    *view_info;
+
+  view_info=OpenCacheView(image);
+  if (view_info == (ViewInfo *) NULL)
+    return(view_info);
+  view_info->virtual_pixel_method=virtual_pixel_method;
+  return(view_info);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S e t C a c h e V i e w                                                   %
 %                                                                             %
 %                                                                             %
@@ -326,7 +560,6 @@ MagickExport ViewInfo *OpenCacheView(Image *image)
 %    o x,y,columns,rows:  These values define the perimeter of a region of
 %      pixels.
 %
-%
 */
 MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
   const long y,const unsigned long columns,const unsigned long rows)
@@ -345,6 +578,44 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   S e t C a c h e V i e w S t o r a g e C l a s s                           %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  SetCacheViewStorageClass() sets the image storage class associated with
+%  the specified view.
+%
+%  The format of the SetCacheViewStorageClass method is:
+%
+%      MagickBooleanType SetCacheViewStorageClass(const ViewInfo *view_info,
+%        const ClassType storage_class)
+%
+%  A description of each parameter follows:
+%
+%    o view_info: The address of a structure of type ViewInfo.
+%
+%    o storage_class: The image storage class: PseudoClass or DirectClass.
+%
+*/
+MagickExport MagickBooleanType SetCacheViewStorageClass(ViewInfo *view_info,
+  const ClassType storage_class)
+{
+  assert(view_info != (ViewInfo *) NULL);
+  assert(view_info->signature == MagickSignature);
+  assert(view_info->image != (Image *) NULL);
+  if (view_info->image->debug != MagickFalse)
+    (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",
+      view_info->image->filename);
+  return(SetImageStorageClass(view_info->image,storage_class));
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   S y n c C a c h e V i e w                                                 %
 %                                                                             %
 %                                                                             %
@@ -363,7 +634,6 @@ MagickExport PixelPacket *SetCacheView(ViewInfo *view_info,const long x,
 %
 %    o view_info: The address of a structure of type ViewInfo.
 %
-%
 */
 MagickExport MagickBooleanType SyncCacheView(ViewInfo *view_info)
 {
