@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -13,10 +13,10 @@
   See the License for the specific language governing permissions and
   limitations under the License.
 
-  ImageMagick Cache public methods.
+  MagickCore cache methods.
 */
-#ifndef _MAGICK_CACHE_H
-#define _MAGICK_CACHE_H
+#ifndef _MAGICKCORE_CACHE_H
+#define _MAGICKCORE_CACHE_H
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -24,18 +24,10 @@ extern "C" {
 
 #include "magick/blob.h"
 
-typedef enum
-{
-  UndefinedVirtualPixelMethod,
-  ConstantVirtualPixelMethod,
-  EdgeVirtualPixelMethod,
-  MirrorVirtualPixelMethod,
-  TileVirtualPixelMethod
-} VirtualPixelMethod;
-
 extern MagickExport const PixelPacket
-  *AcquireCacheNexus(const Image *,const long,const long,const unsigned long,
-    const unsigned long,const unsigned long,ExceptionInfo *);
+  *AcquireCacheNexus(const Image *,const VirtualPixelMethod,const long,
+    const long,const unsigned long,const unsigned long,const unsigned long,
+    ExceptionInfo *);
 
 extern MagickExport MagickSizeType
   GetPixelCacheArea(const Image *);
@@ -43,8 +35,6 @@ extern MagickExport MagickSizeType
 extern MagickExport MagickBooleanType
   PersistCache(Image *,const char *,const MagickBooleanType,MagickOffsetType *,
     ExceptionInfo *),
-  SetImageVirtualPixelMethod(const Image *,const VirtualPixelMethod),
-  SyncCache(Image *),
   SyncCacheNexus(Image *,const unsigned long);
 
 extern MagickExport PixelPacket
@@ -54,7 +44,11 @@ extern MagickExport PixelPacket
     const unsigned long,const unsigned long);
 
 extern MagickExport VirtualPixelMethod
-  GetImageVirtualPixelMethod(const Image *);
+  GetImageVirtualPixelMethod(const Image *),
+  SetImageVirtualPixelMethod(const Image *,const VirtualPixelMethod);
+
+extern MagickExport void
+  DestroyCacheResources(void);
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
