@@ -189,37 +189,6 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       }
       return(MagickTrue);
     }
-    case GRAYColorspace:
-    {
-      /*
-        Convert RGB to GRAY colorspace.
-      */
-      if (IsGrayImage(image,&image->exception) != MagickFalse)
-        return(MagickTrue);
-      if (image->storage_class == PseudoClass)
-        for (i=0; i < (long) image->colors; i++)
-        {
-          image->colormap[i].red=PixelIntensityToQuantum(image->colormap+i);
-          image->colormap[i].green=image->colormap[i].red;
-          image->colormap[i].blue=image->colormap[i].red;
-        }
-      for (y=0; y < (long) image->rows; y++)
-      {
-        q=GetImagePixels(image,0,y,image->columns,1);
-        if (q == (PixelPacket *) NULL)
-          break;
-        for (x=0; x < (long) image->columns; x++)
-        {
-          q->red=PixelIntensityToQuantum(q);
-          q->green=q->red;
-          q->blue=q->red;
-          q++;
-        }
-        if (SyncImagePixels(image) == MagickFalse)
-          break;
-      }
-      return(MagickTrue);
-    }
     case HSBColorspace:
     {
       double
@@ -377,7 +346,7 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       black=pow(10.0,(reference_black-reference_white)*(gamma/density)*
         0.002/0.6);
       for (i=0; i <= (long) MaxMap; i++)
-        logmap[i]=ScaleMapToQuantum((unsigned long) (MaxMap*(reference_white+
+        logmap[i]=ScaleMapToQuantum((MagickRealType) (MaxMap*(reference_white+
           log10(black+((double) i/MaxMap)*(1.0-black))/((gamma/density)*
           0.002/0.6))/1024.0+0.5));
       for (y=0; y < (long) image->rows; y++)
@@ -586,21 +555,21 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
       /*
         Initialize CIE XYZ tables (ITU-R 709 RGB):
 
-          X = 0.412453*X+0.357580*Y+0.180423*Z
-          Y = 0.212671*X+0.715160*Y+0.072169*Z
-          Z = 0.019334*X+0.119193*Y+0.950227*Z
+          X = 0.497*X+0.339*Y+0.164*Z
+          Y = 0.256*X+0.678*Y+0.066*Z
+          Z = 0.023*X+0.113*Y+0.864*Z
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i].x=0.412453*i;
-        x_map[i].y=0.212671*i;
-        x_map[i].z=0.019334*i;
-        y_map[i].x=0.35758*i;
-        y_map[i].y=0.71516*i;
-        y_map[i].z=0.119193*i;
-        z_map[i].x=0.180423*i;
-        z_map[i].y=0.072169*i;
-        z_map[i].z=0.950227*i;
+        x_map[i].x=0.497*i;
+        x_map[i].y=0.339*i;
+        x_map[i].z=0.164*i;
+        y_map[i].x=0.256*i;
+        y_map[i].y=0.678*i;
+        y_map[i].z=0.066*i;
+        z_map[i].x=0.023*i;
+        z_map[i].y=0.113*i;
+        z_map[i].z=0.864*i;
       }
       break;
     }
@@ -760,9 +729,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
           pixel.blue=x_map[ScaleQuantumToMap(q->red)].z+
             y_map[ScaleQuantumToMap(q->green)].z+
             z_map[ScaleQuantumToMap(q->blue)].z+primary_info.z;
-          q->red=ScaleMapToQuantum(RoundToMap(pixel.red));
-          q->green=ScaleMapToQuantum(RoundToMap(pixel.green));
-          q->blue=ScaleMapToQuantum(RoundToMap(pixel.blue));
+          q->red=ScaleMapToQuantum(pixel.red);
+          q->green=ScaleMapToQuantum(pixel.green);
+          q->blue=ScaleMapToQuantum(pixel.blue);
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -794,9 +763,9 @@ MagickExport MagickBooleanType RGBTransformImage(Image *image,
         pixel.blue=x_map[ScaleQuantumToMap(image->colormap[i].red)].z+
           y_map[ScaleQuantumToMap(image->colormap[i].green)].z+
           z_map[ScaleQuantumToMap(image->colormap[i].blue)].z+primary_info.z;
-        image->colormap[i].red=ScaleMapToQuantum(RoundToMap(pixel.red));
-        image->colormap[i].green=ScaleMapToQuantum(RoundToMap(pixel.green));
-        image->colormap[i].blue=ScaleMapToQuantum(RoundToMap(pixel.blue));
+        image->colormap[i].red=ScaleMapToQuantum(pixel.red);
+        image->colormap[i].green=ScaleMapToQuantum(pixel.green);
+        image->colormap[i].blue=ScaleMapToQuantum(pixel.blue);
       }
       (void) SyncImage(image);
       break;
@@ -892,18 +861,37 @@ MagickExport MagickBooleanType SetImageColorspace(Image *image,
 %
 %    o colorspace: the colorspace to transform the image to.
 %
-%
 */
+
+static inline unsigned short RoundTosRGB(const MagickRealType value)
+{
+  if (value <= 0.0)
+    return(0);
+  if (value >= 351.0)
+    return(351);
+  return((unsigned short) (value+0.5));
+}
+
+static inline unsigned short RoundToYCC(const MagickRealType value)
+{
+  if (value <= 0.0)
+    return(0UL);
+  if (value >= 351.0)
+    return(351);
+  return((unsigned short) (value+0.5));
+}
+
 MagickExport MagickBooleanType TransformRGBImage(Image *image,
   const ColorspaceType colorspace)
 {
 #define D50X  (0.9642)
 #define D50Y  (1.0)
 #define D50Z  (0.8249)
-#define MaxYCC  ((MagickRealType) (1.3584*MaxMap+0.5))
+#define MaxsRGB  (1.3584*MaxMap)
 #define TransformRGBImageTag  "Transform/Image"
 
-  static const unsigned long
+#if !defined(UseHDRI)
+  static const unsigned char
     sRGBMap[351] =
     {
         0,   1,   2,   3,   4,   5,   6,   7,   8,   9,  10,  11,  12,  13,
@@ -962,13 +950,11 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255,
       255
     };
+#endif
 
   long
     y;
 
-  LongPixelPacket
-    quantum;
-
   MagickBooleanType
     status;
 
@@ -1030,12 +1016,12 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         indexes=GetIndexes(image);
         for (x=0; x < (long) image->columns; x++)
         {
-          q->red=RoundToQuantum((MagickRealType) (QuantumRange-
-            QuantumScale*q->red*(QuantumRange-indexes[x])+indexes[x]));
-          q->green=RoundToQuantum((MagickRealType) (QuantumRange-
-            QuantumScale*q->green*(QuantumRange-indexes[x])+indexes[x]));
-          q->blue=RoundToQuantum((MagickRealType) (QuantumRange-
-            QuantumScale*q->blue*(QuantumRange-indexes[x])+indexes[x]));
+          q->red=RoundToQuantum(QuantumScale*((MagickRealType) (QuantumRange-
+            q->red)*(QuantumRange-indexes[x])));
+          q->green=RoundToQuantum(QuantumScale*((MagickRealType) (QuantumRange-
+            q->green)*(QuantumRange-indexes[x])));
+          q->blue=RoundToQuantum(QuantumScale*((MagickRealType) (QuantumRange-
+            q->blue)*(QuantumRange-indexes[x])));
           q++;
         }
         if (SyncImagePixels(image) == MagickFalse)
@@ -1226,7 +1212,7 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           (pow(10.0,(1024.0*i/MaxMap-reference_white)*
           (gamma/density)*0.002/0.6)-black));
       for ( ; i <= (long) MaxMap; i++)
-        logmap[i]=(Quantum) QuantumRange;
+        logmap[i]=QuantumRange;
       if (SetImageStorageClass(image,DirectClass) == MagickFalse)
         return(MagickFalse);
       for (y=0; y < (long) image->rows; y++)
@@ -1359,14 +1345,14 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         x_map[i].y=1.40200*i;
         x_map[i].z=1.40200*i;
         y_map[i].x=0.0;
-        y_map[i].y=(-0.444066)*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        y_map[i].z=2.28900*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        z_map[i].x=1.88000*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        z_map[i].y=(-0.95692)*(i-(long)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        y_map[i].y=(-0.444066)*(i-(long) ScaleQuantumToMap(
+          ScaleCharToQuantum(156)));
+        y_map[i].z=2.28900*(i-(long) ScaleQuantumToMap(
+          ScaleCharToQuantum(156)));
+        z_map[i].x=1.88000*(i-(long) ScaleQuantumToMap(
+          ScaleCharToQuantum(137)));
+        z_map[i].y=(-0.95692)*(i-(long) ScaleQuantumToMap(
+          ScaleCharToQuantum(137)));
         z_map[i].z=0.0;
       }
       break;
@@ -1377,21 +1363,21 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
       /*
         Initialize CIE XYZ tables (ITU R-709 RGB):
 
-          R =  3.240479*R-1.537150*G-0.498535*B
-          G = -0.969256*R+1.875992*G+0.041556*B
-          B =  0.055648*R-0.204043*G+1.057311*B
+          R =  2.690*R-1.276*G-0.414*B
+          G = -1.022*R+1.978*G+0.044*B
+          B =  0.061*R-0.224*G+1.163*B
       */
       for (i=0; i <= (long) MaxMap; i++)
       {
-        x_map[i].x=3.240479*i;
-        x_map[i].y=(-0.969256)*i;
-        x_map[i].z=0.055648*i;
-        y_map[i].x=(-1.537150)*i;
-        y_map[i].y=1.875992*i;
-        y_map[i].z=(-0.204043)*i;
-        z_map[i].x=(-0.498535)*i;
-        z_map[i].y=0.041556*i;
-        z_map[i].z=1.057311*i;
+        x_map[i].x=2.690*i;
+        x_map[i].y=(-1.022)*i;
+        x_map[i].z=0.061*i;
+        y_map[i].x=(-1.276)*i;
+        y_map[i].y=1.978*i;
+        y_map[i].z=(-0.224)*i;
+        z_map[i].x=(-0.414)*i;
+        z_map[i].y=0.044*i;
+        z_map[i].z=1.163*i;
       }
       break;
     }
@@ -1412,14 +1398,14 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
         x_map[i].y=1.3584*i;
         x_map[i].z=1.3584*i;
         y_map[i].x=0.0;
-        y_map[i].y=(-0.4302726)*(i-(double)
-          ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        y_map[i].z=2.2179*(i-(double)
-          ScaleQuantumToMap(ScaleCharToQuantum(156)));
-        z_map[i].x=1.8215*(i-(double)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
-        z_map[i].y=(-0.9271435)*(i-(double)
-          ScaleQuantumToMap(ScaleCharToQuantum(137)));
+        y_map[i].y=(-0.4302726)*(i-(double) ScaleQuantumToMap(
+          ScaleCharToQuantum(156)));
+        y_map[i].z=2.2179*(i-(double) ScaleQuantumToMap(
+          ScaleCharToQuantum(156)));
+        z_map[i].x=1.8215*(i-(double) ScaleQuantumToMap(
+          ScaleCharToQuantum(137)));
+        z_map[i].y=(-0.9271435)*(i-(double) ScaleQuantumToMap(
+          ScaleCharToQuantum(137)));
         z_map[i].z=0.0;
       }
       break;
@@ -1537,41 +1523,36 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
             z_map[ScaleQuantumToMap(q->blue)].z;
           switch (colorspace)
           {
+#if !defined(UseHDRI)
             case sRGBColorspace:
-            case YCCColorspace:
             {
-              quantum.red=(unsigned long) ((pixel.red < 0.0) ? 0.0 :
-                (pixel.red > MaxYCC) ? MaxYCC : pixel.red+0.5);
-              quantum.green=(unsigned long) ((pixel.green < 0.0) ? 0.0 :
-                (pixel.green > MaxYCC) ?  MaxYCC : pixel.green+0.5);
-              quantum.blue=(unsigned long) ((pixel.blue < 0.0) ? 0.0 :
-                (pixel.blue > MaxYCC) ? MaxYCC : pixel.blue+0.5);
-              if (colorspace == sRGBColorspace)
-                {
-                  q->red=(Quantum) ScaleToQuantum(sRGBMap[
-                    ScaleQuantumToChar((Quantum) quantum.red)]);
-                  q->green=(Quantum) ScaleToQuantum(sRGBMap[
-                    ScaleQuantumToChar((Quantum) quantum.green)]);
-                  q->blue=(Quantum) ScaleToQuantum(sRGBMap[
-                    ScaleQuantumToChar((Quantum) quantum.blue)]);
-                  break;
-                }
-              q->red=(Quantum) ScaleToQuantum(YCCMap[
-                ScaleQuantumToChar((Quantum) quantum.red)]);
-              q->green=(Quantum) ScaleToQuantum(YCCMap[
-                ScaleQuantumToChar((Quantum) quantum.green)]);
-              q->blue=(Quantum) ScaleToQuantum(YCCMap[
-                ScaleQuantumToChar((Quantum) quantum.blue)]);
+              q->red=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+                255.0*QuantumScale*pixel.red)]);
+              q->green=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+                255.0*QuantumScale*pixel.green)]);
+              q->blue=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+                255.0*QuantumScale*pixel.blue)]);
               break;
             }
+            case YCCColorspace:
+            {
+              q->red=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.red)]);
+              q->green=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.green)]);
+              q->blue=ScaleCharToQuantum(YCCMap[RoundToYCC(
+                255.0*QuantumScale*pixel.blue)]);
+              break;
+            }
+#endif
             default:
             {
-              quantum.red=RoundToMap(pixel.red);
-              quantum.green=RoundToMap(pixel.green);
-              quantum.blue=RoundToMap(pixel.blue);
-              q->red=ScaleMapToQuantum(quantum.red);
-              q->green=ScaleMapToQuantum(quantum.green);
-              q->blue=ScaleMapToQuantum(quantum.blue);
+              q->red=ScaleMapToQuantum((MagickRealType) MaxMap*
+                QuantumScale*pixel.red);
+              q->green=ScaleMapToQuantum((MagickRealType) MaxMap*
+                QuantumScale*pixel.green);
+              q->blue=ScaleMapToQuantum((MagickRealType) MaxMap*
+                QuantumScale*pixel.blue);
               break;
             }
           }
@@ -1608,41 +1589,36 @@ MagickExport MagickBooleanType TransformRGBImage(Image *image,
           z_map[ScaleQuantumToMap(image->colormap[i].blue)].z;
         switch (colorspace)
         {
+#if !defined(UseHDRI)
           case sRGBColorspace:
-          case YCCColorspace:
           {
-            quantum.red=(unsigned long) ((pixel.red < 0.0) ? 0.0 :
-              (pixel.red > MaxYCC) ? MaxYCC : pixel.red+0.5);
-            quantum.green=(unsigned long) ((pixel.green < 0.0) ? 0.0 :
-              (pixel.green > MaxYCC) ? MaxYCC : pixel.green+0.5);
-            quantum.blue=(unsigned long) ((pixel.blue < 0.0) ? 0.0 :
-              (pixel.blue > MaxYCC) ? MaxYCC : pixel.blue+0.5);
-            if (colorspace == sRGBColorspace)
-              {
-                image->colormap[i].red=(Quantum) ScaleToQuantum(sRGBMap[
-                  ScaleQuantumToChar((Quantum) quantum.red)]);
-                image->colormap[i].green=(Quantum) ScaleToQuantum(sRGBMap[
-                  ScaleQuantumToChar((Quantum) quantum.green)]);
-                image->colormap[i].blue=(Quantum) ScaleToQuantum(sRGBMap[
-                  ScaleQuantumToChar((Quantum) quantum.blue)]);
-                break;
-              }
-            image->colormap[i].red=(Quantum) ScaleToQuantum(YCCMap[
-              ScaleQuantumToChar((Quantum) quantum.red)]);
-            image->colormap[i].green=(Quantum) ScaleToQuantum(YCCMap[
-              ScaleQuantumToChar((Quantum) quantum.green)]);
-            image->colormap[i].blue=(Quantum) ScaleToQuantum(YCCMap[
-              ScaleQuantumToChar((Quantum) quantum.blue)]);
+            image->colormap[i].red=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+              255.0*QuantumScale*pixel.red)]);
+            image->colormap[i].green=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+              255.0*QuantumScale*pixel.green)]);
+            image->colormap[i].blue=ScaleCharToQuantum(sRGBMap[RoundTosRGB(
+              255.0*QuantumScale*pixel.blue)]);
             break;
           }
+          case YCCColorspace:
+          {
+            image->colormap[i].red=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              255.0*QuantumScale*pixel.red)]);
+            image->colormap[i].green=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              255.0*QuantumScale*pixel.green)]);
+            image->colormap[i].blue=ScaleCharToQuantum(YCCMap[RoundToYCC(
+              255.0*QuantumScale*pixel.blue)]);
+            break;
+          }
+#endif
           default:
           {
-            quantum.red=RoundToMap(pixel.red);
-            quantum.green=RoundToMap(pixel.green);
-            quantum.blue=RoundToMap(pixel.blue);
-            image->colormap[i].red=ScaleMapToQuantum(quantum.red);
-            image->colormap[i].green=ScaleMapToQuantum(quantum.green);
-            image->colormap[i].blue=ScaleMapToQuantum(quantum.blue);
+            image->colormap[i].red=ScaleMapToQuantum((MagickRealType) MaxMap*
+              QuantumScale*pixel.red);
+            image->colormap[i].green=ScaleMapToQuantum((MagickRealType) MaxMap*
+              QuantumScale*pixel.green);
+            image->colormap[i].blue=ScaleMapToQuantum((MagickRealType) MaxMap*
+              QuantumScale*pixel.blue);
             break;
           }
         }
