@@ -17,7 +17,7 @@
 %                               December 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -97,7 +97,6 @@
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 
 MagickExport Image *CompareImages(Image *image,const Image *reconstruct_image,
@@ -223,14 +222,14 @@ MagickExport Image *CompareImageChannels(Image *image,
           (image->colorspace == CMYKColorspace))
         if (indexes[x] != reconstruct_indexes[x])
           difference=MagickTrue;
-      SetMagickPixelPacket(q,reconstruct_indexes+x,&source);
+      SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,&source);
       if (difference != MagickFalse)
         MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&red,
           (MagickRealType) red.opacity,&composite);
       else
         MagickPixelCompositeOver(&source,9.0*QuantumRange/10.0,&white,
           (MagickRealType) white.opacity,&composite);
-      SetPixelPacket(&composite,r,difference_indexes+x);
+      SetPixelPacket(difference_image,&composite,r,difference_indexes+x);
       p++;
       q++;
       r++;
@@ -341,8 +340,9 @@ static MagickRealType GetAbsoluteError(const Image *image,
     reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
     for (x=0; x < (long) image->columns; x++)
     {
-      SetMagickPixelPacket(p,indexes+x,&image_pixel);
-      SetMagickPixelPacket(q,reconstruct_indexes+x,&reconstruct_pixel);
+      SetMagickPixelPacket(image,p,indexes+x,&image_pixel);
+      SetMagickPixelPacket(reconstruct_image,q,reconstruct_indexes+x,
+        &reconstruct_pixel);
       if (IsMagickColorSimilar(&image_pixel,&reconstruct_pixel) == MagickFalse)
         distortion++;
       p++;
@@ -430,6 +430,110 @@ static MagickRealType GetMeanAbsoluteError(const Image *image,
   return(distortion/area);
 }
 
+static MagickRealType GetMeanErrorPerPixel(Image *image,
+  const Image *reconstruct_image,const ChannelType channel,
+  ExceptionInfo *exception)
+{
+  double
+    alpha,
+    area,
+    beta,
+    distance,
+    maximum_error,
+    mean_error,
+    mean_error_per_pixel;
+
+  IndexPacket
+    *indexes,
+    *reconstruct_indexes;
+
+  long
+    y;
+
+  register const PixelPacket
+    *p,
+    *q;
+
+  register long
+    x;
+
+  ViewInfo
+    *image_view,
+    *reconstruct_view;
+
+  alpha=1.0;
+  beta=1.0;
+  area=0.0;
+  maximum_error=0.0;
+  mean_error_per_pixel=0.0;
+  mean_error=0.0;
+  image_view=OpenCacheView(image);
+  reconstruct_view=OpenCacheView(reconstruct_image);
+  for (y=0; y < (long) image->rows; y++)
+  {
+    p=AcquireCacheView(image_view,0,y,image->columns,1,exception);
+    q=AcquireCacheView(reconstruct_view,0,y,reconstruct_image->columns,1,
+      exception);
+    if ((p == (const PixelPacket *) NULL) || (q == (const PixelPacket *) NULL))
+      break;
+    indexes=GetCacheViewIndexes(image_view);
+    reconstruct_indexes=GetCacheViewIndexes(reconstruct_view);
+    for (x=0; x < (long) image->columns; x++)
+    {
+      if (image->matte != MagickFalse)
+        {
+          alpha=QuantumScale*(QuantumRange-(double) p->opacity);
+          beta=QuantumScale*(QuantumRange-(double) q->opacity);
+        }
+      if ((channel & RedChannel) != 0)
+        {
+          distance=fabs(alpha*p->red-beta*q->red);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if ((channel & GreenChannel) != 0)
+        {
+          distance=fabs(alpha*p->green-beta*q->green);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if ((channel & BlueChannel) != 0)
+        {
+          distance=fabs(alpha*p->blue-beta*q->blue);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      if (((channel & IndexChannel) != 0) &&
+          (image->colorspace == CMYKColorspace))
+        {
+          distance=fabs(alpha*indexes[x]-beta*reconstruct_indexes[x]);
+          mean_error_per_pixel+=distance;
+          mean_error+=distance*distance;
+          if (distance > maximum_error)
+            maximum_error=distance;
+          area++;
+        }
+      p++;
+      q++;
+    }
+  }
+  reconstruct_view=CloseCacheView(reconstruct_view);
+  image_view=CloseCacheView(image_view);
+  image->error.mean_error_per_pixel=mean_error_per_pixel/area;
+  image->error.normalized_mean_error=QuantumScale*QuantumScale*mean_error/area;
+  image->error.normalized_maximum_error=QuantumScale*maximum_error;
+  return((MagickRealType) image->error.mean_error_per_pixel);
+}
+
 static MagickRealType GetMeanSquaredError(const Image *image,
   const Image *reconstruct_image,const ChannelType channel,
   ExceptionInfo *exception)
@@ -600,7 +704,7 @@ static MagickRealType GetPeakSignalToNoiseRatio(const Image *image,
     distortion;
 
   distortion=GetMeanSquaredError(image,reconstruct_image,channel,exception);
-  return(20.0*log10(QuantumRange/sqrt((double) distortion)));
+  return(20.0*log10((double) QuantumRange/sqrt((double) distortion)));
 }
 
 static MagickRealType GetRootMeanSquaredError(const Image *image,
@@ -651,6 +755,12 @@ MagickExport MagickBooleanType GetImageChannelDistortion(Image *image,
         exception);
       break;
     }
+    case MeanErrorPerPixelMetric:
+    {
+      *distortion=(double) GetMeanErrorPerPixel(image,reconstruct_image,channel,
+        exception);
+      break;
+    }
     case MeanSquaredErrorMetric:
     {
       *distortion=(double) GetMeanSquaredError(image,reconstruct_image,channel,
@@ -829,8 +939,8 @@ MagickExport MagickBooleanType IsImagesEqual(Image *image,
   reconstruct_view=CloseCacheView(reconstruct_view);
   image_view=CloseCacheView(image_view);
   image->error.mean_error_per_pixel=(double) (mean_error_per_pixel/area);
-  image->error.normalized_mean_error=(double)
-    (QuantumScale*QuantumScale*mean_error/area);
+  image->error.normalized_mean_error=(double) (QuantumScale*QuantumScale*
+    mean_error/area);
   image->error.normalized_maximum_error=(double) (QuantumScale*maximum_error);
   status=image->error.mean_error_per_pixel == 0.0 ? MagickTrue : MagickFalse;
   return(status);
