@@ -833,7 +833,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
     *magick_info;
 
   ExceptionInfo
-    sans_exception;
+    *sans_exception;
 
   ImageInfo
     *write_info;
@@ -852,12 +852,12 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       image_info->filename);
   assert(image != (Image *) NULL);
   assert(image->signature == MagickSignature);
-  GetExceptionInfo(&sans_exception);
+  sans_exception=AcquireExceptionInfo();
   write_info=CloneImageInfo(image_info);
   (void) CopyMagickString(write_info->filename,image->filename,MaxTextExtent);
   if (*write_info->magick == '\0')
     (void) CopyMagickString(write_info->magick,image->magick,MaxTextExtent);
-  (void) SetImageInfo(write_info,MagickTrue,&sans_exception);
+  (void) SetImageInfo(write_info,MagickTrue,sans_exception);
   if (LocaleCompare(write_info->magick,"clipmask") == 0)
     {
       if (image->clip_mask == (Image *) NULL)
@@ -867,10 +867,10 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
           return(MagickFalse);
         }
       image=image->clip_mask;
-      (void) SetImageInfo(write_info,MagickTrue,&sans_exception);
+      (void) SetImageInfo(write_info,MagickTrue,sans_exception);
     }
   (void) CopyMagickString(filename,image->filename,MaxTextExtent);
-  SyncImageInfo(write_info,image,&sans_exception);
+  SyncImageInfo(write_info,image,sans_exception);
   (void) SyncImageProfiles(image);
   if ((GetPreviousImageInList(image) == (Image *) NULL) &&
       (GetNextImageInList(image) == (Image *) NULL) &&
@@ -892,13 +892,13 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
             write_info->magick,&image->exception);
           write_info=DestroyImageInfo(write_info);
           (void) CopyMagickString(image->filename,filename,MaxTextExtent);
-          (void) DestroyExceptionInfo(&sans_exception);
+          sans_exception=DestroyExceptionInfo(sans_exception);
           return(status);
         }
     }
   status=MagickFalse;
   temporary=MagickFalse;
-  magick_info=GetMagickInfo(write_info->magick,&sans_exception);
+  magick_info=GetMagickInfo(write_info->magick,sans_exception);
   if ((magick_info != (const MagickInfo *) NULL) &&
       (GetMagickSeekableStream(magick_info) != MagickFalse))
     {
@@ -955,7 +955,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
         }
       else
         {
-          magick_info=GetMagickInfo(write_info->magick,&sans_exception);
+          magick_info=GetMagickInfo(write_info->magick,sans_exception);
           if ((write_info->affirm == MagickFalse) &&
               (magick_info == (const MagickInfo *) NULL))
             {
@@ -1009,7 +1009,7 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
       (write_info->verbose != MagickFalse))
     (void) IdentifyImage(image,stdout,MagickFalse);
   write_info=DestroyImageInfo(write_info);
-  (void) DestroyExceptionInfo(&sans_exception);
+  sans_exception=DestroyExceptionInfo(sans_exception);
   return(status);
 }
 
@@ -1041,11 +1041,13 @@ MagickExport MagickBooleanType WriteImage(const ImageInfo *image_info,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   Image *images,const char *filename,ExceptionInfo *exception)
 {
+  ExceptionInfo
+    *sans_exception;
+
   ImageInfo
     *write_info;
 
@@ -1073,7 +1075,9 @@ MagickExport MagickBooleanType WriteImages(const ImageInfo *image_info,
   (void) CopyMagickString(write_info->filename,images->filename,MaxTextExtent);
   if (*write_info->magick == '\0')
     (void) CopyMagickString(write_info->magick,images->magick,MaxTextExtent);
-  (void) SetImageInfo(write_info,MagickTrue,exception);
+  sans_exception=AcquireExceptionInfo();
+  (void) SetImageInfo(write_info,MagickTrue,sans_exception);
+  sans_exception=DestroyExceptionInfo(sans_exception);
   p=images;
   for ( ; GetNextImageInList(p) != (Image *) NULL; p=GetNextImageInList(p))
     if (p->scene >= GetNextImageInList(p)->scene)
