@@ -26,6 +26,7 @@ extern "C" {
 
 #include <stdarg.h>
 #include "magick/blob.h"
+#include "magick/draw.h"
 #include "magick/constitute.h"
 #include "magick/magick-config.h"
 #include "magick/quantum.h"
@@ -129,6 +130,8 @@ extern MagickExport long
 
 extern MagickExport MagickBooleanType
   CloneImageAttributes(Image *,const Image *),
+  ColorFloodfillImage(Image *,const DrawInfo *,const PixelPacket,const long,
+    const long,const PaintMethod),
   DeleteImageAttribute(Image *,const char *),
   DescribeImage(Image *,FILE *,const MagickBooleanType),
   FormatImageAttribute(Image *,const char *,const char *,...)
@@ -139,6 +142,8 @@ extern MagickExport MagickBooleanType
   FuzzyOpacityCompare(const Image *,const PixelPacket *,const PixelPacket *),
   MagickMonitor(const char *,const MagickOffsetType,const MagickSizeType,
     void *),
+  MatteFloodfillImage(Image *,const PixelPacket,const Quantum,const long,
+    const long,const PaintMethod),
   OpaqueImage(Image *,const PixelPacket,const PixelPacket),
   PopImagePixels(Image *,const QuantumType,unsigned char *),
   PushImagePixels(Image *,const QuantumType,const unsigned char *),
