@@ -444,7 +444,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.red != white.red)
               normalize_map[i].red=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.red)/(white.red-black.red)));
+                (MagickRealType) (MaxMap*(i-black.red)/(white.red-black.red)));
           }
     if ((channel & GreenChannel) != 0)
       {
@@ -456,7 +456,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.green != white.green)
               normalize_map[i].green=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.green)/(white.green-
+                (MagickRealType) (MaxMap*(i-black.green)/(white.green-
                 black.green)));
       }
     if ((channel & BlueChannel) != 0)
@@ -469,7 +469,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.blue != white.blue)
               normalize_map[i].blue=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.blue)/(white.blue-
+                (MagickRealType) (MaxMap*(i-black.blue)/(white.blue-
                 black.blue)));
       }
     if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
@@ -482,7 +482,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.opacity != white.opacity)
               normalize_map[i].opacity=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.opacity)/(white.opacity-
+                (MagickRealType) (MaxMap*(i-black.opacity)/(white.opacity-
                 black.opacity)));
       }
     if (((channel & IndexChannel) != 0) &&
@@ -496,7 +496,7 @@ MagickExport MagickBooleanType ContrastStretchImageChannel(Image *image,
           else
             if (black.index != white.index)
               normalize_map[i].index=(MagickRealType) ScaleMapToQuantum(
-                (unsigned long) (MaxMap*(i-black.index)/(white.index-
+                (MagickRealType) (MaxMap*(i-black.index)/(white.index-
                 black.index)));
       }
   }
@@ -866,22 +866,22 @@ MagickExport MagickBooleanType EqualizeImage(Image *image)
     map[i]=intensity;
   }
   black=map[0];
-  white=map[MaxMap];
+  white=map[(int) MaxMap];
   (void) ResetMagickMemory(equalize_map,0,(MaxMap+1)*sizeof(*equalize_map));
   for (i=0; i <= (long) MaxMap; i++)
   {
     if (white.red != black.red)
-      equalize_map[i].red=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].red-black.red))/(white.red-black.red)));
+      equalize_map[i].red=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].red-black.red))/(white.red-black.red)));
     if (white.green != black.green)
-      equalize_map[i].green=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].green-black.green))/(white.green-black.green)));
+      equalize_map[i].green=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].green-black.green))/(white.green-black.green)));
     if (white.blue != black.blue)
-      equalize_map[i].blue=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].blue-black.blue))/(white.blue-black.blue)));
+      equalize_map[i].blue=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].blue-black.blue))/(white.blue-black.blue)));
     if (white.opacity != black.opacity)
-      equalize_map[i].opacity=ScaleMapToQuantum((unsigned long) (
-        (MaxMap*(map[i].opacity-black.opacity))/(white.opacity-black.opacity)));
+      equalize_map[i].opacity=ScaleMapToQuantum((MagickRealType) ((MaxMap*
+        (map[i].opacity-black.opacity))/(white.opacity-black.opacity)));
   }
   histogram=(MagickPixelPacket *) RelinquishMagickMemory(histogram);
   map=(MagickPixelPacket *) RelinquishMagickMemory(map);
@@ -1049,8 +1049,8 @@ MagickExport MagickBooleanType GammaImageChannel(Image *image,
   (void) ResetMagickMemory(gamma_map,0,(MaxMap+1)*sizeof(*gamma_map));
   if (gamma != 0.0)
     for (i=0; i <= (long) MaxMap; i++)
-      gamma_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
-        (MaxMap*pow((double) i/MaxMap,1.0/gamma)+0.5));
+      gamma_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
+        (MaxMap*pow((double) i/MaxMap,1.0/gamma)));
   if (image->storage_class == PseudoClass)
     {
       /*
@@ -1264,14 +1264,14 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
       for (i=0; i < (long) image->colors; i++)
       {
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].red)]);
+          image->colormap[i].red=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].red)]);
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].green)]);
+          image->colormap[i].green=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].green)]);
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=ScaleMapToQuantum((unsigned long)
-            levels_map[ScaleQuantumToMap(image->colormap[i].blue)]);
+          image->colormap[i].blue=ScaleMapToQuantum(levels_map[
+            ScaleQuantumToMap(image->colormap[i].blue)]);
       }
     }
   /*
@@ -1286,22 +1286,17 @@ MagickExport MagickBooleanType LevelImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->red)]);
+        q->red=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->red)]);
       if ((channel & GreenChannel) != 0)
-        q->green=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->green)]);
+        q->green=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->green)]);
       if ((channel & BlueChannel) != 0)
-        q->blue=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->blue)]);
+        q->blue=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->blue)]);
       if (((channel & OpacityChannel) != 0) & (image->matte != MagickFalse))
-        q->opacity=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(q->opacity)]);
+        q->opacity=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(q->opacity)]);
       if (((channel & IndexChannel) != 0) &&
           ((image->storage_class == PseudoClass) ||
            (image->colorspace == CMYKColorspace)))
-        indexes[x]=ScaleMapToQuantum((unsigned long)
-          levels_map[ScaleQuantumToMap(indexes[x])]);
+        indexes[x]=ScaleMapToQuantum(levels_map[ScaleQuantumToMap(indexes[x])]);
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -1658,12 +1653,12 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               (image->colormap[i].green != image->colormap[i].blue))
             continue;
         if ((channel & RedChannel) != 0)
-          image->colormap[i].red=(Quantum) QuantumRange-image->colormap[i].red;
+          image->colormap[i].red=QuantumRange-image->colormap[i].red;
         if ((channel & GreenChannel) != 0)
-          image->colormap[i].green=(Quantum) QuantumRange-
+          image->colormap[i].green=QuantumRange-
             image->colormap[i].green;
         if ((channel & BlueChannel) != 0)
-          image->colormap[i].blue=(Quantum) QuantumRange-
+          image->colormap[i].blue=QuantumRange-
             image->colormap[i].blue;
       }
     }
@@ -1686,14 +1681,14 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
               continue;
             }
           if ((channel & RedChannel) != 0)
-            q->red=(Quantum) QuantumRange-q->red;
+            q->red=QuantumRange-q->red;
           if ((channel & GreenChannel) != 0)
-            q->green=(Quantum) QuantumRange-q->green;
+            q->green=QuantumRange-q->green;
           if ((channel & BlueChannel) != 0)
-            q->blue=(Quantum) QuantumRange-q->blue;
+            q->blue=QuantumRange-q->blue;
           if (((channel & OpacityChannel) != 0) &&
               (image->matte != MagickFalse))
-            q->opacity=(Quantum) QuantumRange-q->opacity;
+            q->opacity=QuantumRange-q->opacity;
           if (((channel & IndexChannel) != 0) &&
               (image->colorspace == CMYKColorspace))
             indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1724,13 +1719,13 @@ MagickExport MagickBooleanType NegateImageChannel(Image *image,
     for (x=0; x < (long) image->columns; x++)
     {
       if ((channel & RedChannel) != 0)
-        q->red=(Quantum) QuantumRange-q->red;
+        q->red=QuantumRange-q->red;
       if ((channel & GreenChannel) != 0)
-        q->green=(Quantum) QuantumRange-q->green;
+        q->green=QuantumRange-q->green;
       if ((channel & BlueChannel) != 0)
-        q->blue=(Quantum) QuantumRange-q->blue;
+        q->blue=QuantumRange-q->blue;
       if (((channel & OpacityChannel) != 0) && (image->matte != MagickFalse))
-        q->opacity=(Quantum) QuantumRange-q->opacity;
+        q->opacity=QuantumRange-q->opacity;
       if (((channel & IndexChannel) != 0) &&
           (image->colorspace == CMYKColorspace))
         indexes[x]=(IndexPacket) QuantumRange-indexes[x];
@@ -1905,7 +1900,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
   {
     if (sharpen != MagickFalse)
       {
-        sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
+        sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
           (MaxMap*((1.0/(1.0+exp(contrast*(midpoint/(double) QuantumRange-
           (double) i/MaxMap))))-(1.0/(1.0+exp(contrast*(midpoint/
           (double) QuantumRange)))))/((1.0/(1.0+exp(contrast*(midpoint/
@@ -1913,7 +1908,7 @@ MagickExport MagickBooleanType SigmoidalContrastImageChannel(Image *image,
           (double) QuantumRange)))))+0.5));
         continue;
       }
-    sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((unsigned long)
+    sigmoidal_map[i]=(MagickRealType) ScaleMapToQuantum((MagickRealType)
       (MaxMap*(QuantumScale*midpoint-log((1.0-(1.0/(1.0+exp(midpoint/
       (double) QuantumRange*contrast))+((double) i/MaxMap)*((1.0/
       (1.0+exp(contrast*(midpoint/(double) QuantumRange-1.0))))-(1.0/
