@@ -200,9 +200,10 @@ MagickExport unsigned long GetOptimalKernelWidth1D(const double radius,
     u;
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
-  assert(sigma != 0.0);
   if (radius > 0.0)
     return((unsigned long) (MagickMax(2.0*radius+1.0,3.0)+0.5));
+  if (fabs(sigma) <= MagickEpsilon)
+    return(1);
   for (width=5; ;)
   {
     normalize=0.0;
@@ -233,10 +234,11 @@ MagickExport unsigned long GetOptimalKernelWidth2D(const double radius,
     u,
     v;
 
-  assert(sigma != 0.0);
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   if (radius > 0.0)
     return((unsigned long) (MagickMax(2.0*radius+1.0,3.0)+0.5));
+  if (fabs(sigma) <= MagickEpsilon)
+    return(1);
   for (width=5; ;)
   {
     normalize=0.0;
