@@ -79,7 +79,6 @@
 %    o width,height:  The width and height as determined by the geometry
 %      specification.
 %
-%
 */
 MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
   unsigned long *width,unsigned long *height)
@@ -159,7 +158,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       case '7':
       case '8':
       case '9':
-      case '':
+      case -41:
       case 'x':
       case 'X':
       {
@@ -180,7 +179,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == '') || (*q == 'x') || (*q == 'X') || (*q == '\0'))
+  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == '\0'))
     {
       /*
         Parse width.
@@ -193,7 +192,7 @@ MagickExport MagickStatusType GetGeometry(const char *geometry,long *x,long *y,
       if (p != q)
         flags|=WidthValue;
     }
-  if ((*p == '') || (*p == 'x') || (*p == 'X'))
+  if ((*p == -41) || (*p == 'x') || (*p == 'X'))
     {
       p++;
       if ((*p != '+') && (*p != '-'))
@@ -379,6 +378,92 @@ MagickExport char *GetPageGeometry(const char *page_geometry)
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %                                                                             %
 %                                                                             %
+%                                                                             %
+%   G r a v i t y A d j u s t G e o m e t r y                                 %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  GravityAdjustGeometry() adjusts the offset of a region with regard to the
+%  given: width, height and gravity; against which it is positioned.
+%
+%  The region should also have an appropriate width and height to correctly
+%  set the right offset of the top left corner of the region.
+%
+%  The format of the GravityAdjustGeometry method is:
+%
+%      void ParseGravityGeometry(const unsigned long width,
+%        const unsigned long height,const GravityType gravity,
+%        RectangleInfo *region);
+%
+%  A description of each parameter follows:
+%
+%    o width, height:  the larger area the region is relative to
+%
+%    o gravity: the edge/corner the current offset is relative to
+%
+%    o region:  The region requiring a offset adjustment relative to gravity
+%
+*/
+MagickExport void GravityAdjustGeometry(const unsigned long width,
+  const unsigned long height,const GravityType gravity,RectangleInfo *region)
+{
+  switch (gravity)
+  {
+    case NorthEastGravity:
+    case EastGravity:
+    case SouthEastGravity:
+    {
+      region->x = (long) (width - region->width - region->x);
+      break;
+    }
+    case NorthGravity:
+    case SouthGravity:
+    case CenterGravity:
+    case StaticGravity:
+    {
+      region->x += (long) (width/2 - region->width/2);
+      break;
+    }
+    case ForgetGravity:
+    case NorthWestGravity:
+    case WestGravity:
+    case SouthWestGravity:
+    default:
+      break;
+  }
+  switch (gravity)
+  {
+    case SouthWestGravity:
+    case SouthGravity:
+    case SouthEastGravity:
+    {
+      region->y = (long) (height - region->height - region->y);
+      break;
+    }
+    case EastGravity:
+    case WestGravity:
+    case CenterGravity:
+    case StaticGravity:
+    {
+      region->y += (long) (height/2 - region->height/2);
+      break;
+    }
+    case ForgetGravity:
+    case NorthWestGravity:
+    case NorthGravity:
+    case NorthEastGravity:
+    default:
+      break;
+  }
+  return;
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
 +     I s G e o m e t r y                                                     %
 %                                                                             %
 %                                                                             %
@@ -396,7 +481,6 @@ MagickExport char *GetPageGeometry(const char *page_geometry)
 %
 %    o geometry: This string is the geometry specification.
 %
-%
 */
 MagickExport MagickBooleanType IsGeometry(const char *geometry)
 {
@@ -437,7 +521,6 @@ MagickExport MagickBooleanType IsGeometry(const char *geometry)
 %    o pedantic: A value other than 0 invokes a more restrictive set of
 %      conditions for a valid specification (e.g. [1], [1-4], [4-1]).
 %
-%
 */
 MagickExport MagickBooleanType IsSceneGeometry(const char *geometry,
   const MagickBooleanType pedantic)
@@ -451,9 +534,7 @@ MagickExport MagickBooleanType IsSceneGeometry(const char *geometry,
   (void) strtod(geometry,&p);
   if (p == geometry)
     return(MagickFalse);
-  if ((strchr(geometry,'') != (char *) NULL) ||
-      (strchr(geometry,'x') != (char *) NULL) ||
-      (strchr(geometry,'X') != (char *) NULL))
+  if (strspn(geometry,"0123456789-, ") != strlen(geometry))
     return(MagickFalse);
   if ((pedantic != MagickFalse) && (strchr(geometry,',') != (char *) NULL))
     return(MagickFalse);
@@ -484,7 +565,6 @@ MagickExport MagickBooleanType IsSceneGeometry(const char *geometry,
 %
 %    o region_info: The region as defined by the geometry string.
 %
-%
 */
 MagickExport MagickStatusType ParseAbsoluteGeometry(const char *geometry,
   RectangleInfo *region_info)
@@ -588,7 +668,6 @@ MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
 %
 %    o geometry_info:  returns the parsed width/height/x/y in this structure.
 %
-%
 */
 MagickExport MagickStatusType ParseGeometry(const char *geometry,
   GeometryInfo *geometry_info)
@@ -671,7 +750,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       case '7':
       case '8':
       case '9':
-      case '':
+      case -41:
       case 'x':
       case 'X':
       case ',':
@@ -701,8 +780,8 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
   (void) strtod(p,&q);
   if (LocaleNCompare(p,"0x",2) == 0)
     (void) strtol(p,&q,10);
-  if ((*q == '') || (*q == 'x') || (*q == 'X') || (*q == ',') || (*q == '/') ||
-      (*q == ':') || (*q =='\0'))
+  if ((*q == -41) || (*q == 'x') || (*q == 'X') || (*q == ',') ||
+      (*q == '/') || (*q == ':') || (*q =='\0'))
     {
       /*
         Parse rho.
@@ -719,7 +798,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
         }
     }
   q=p;
-  if ((*p == '') || (*p == 'x') || (*p == 'X') || (*p == ',') ||
+  if ((*p == -41) || (*p == 'x') || (*p == 'X') || (*p == ',') ||
       (*p == '/') || (*p == ':'))
     {
       /*
@@ -728,7 +807,7 @@ MagickExport MagickStatusType ParseGeometry(const char *geometry,
       p++;
       while (isspace((int) ((unsigned char) *p)) != 0)
         p++;
-      if (((*q != '') && (*q != 'x') && (*q != 'X')) ||
+      if (((*q != -41) && (*q != 'x') && (*q != 'X')) ||
           ((*p != '+') && (*p != '-')))
         {
           q=p;
@@ -885,76 +964,25 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
       if ((status & SigmaValue) == 0)
         scale.y=scale.x;
       region_info->width=(unsigned long) ((scale.x*image->columns/100.0)+0.5);
+      if (region_info->width == 0)
+        region_info->width=1;
       region_info->height=(unsigned long) ((scale.y*image->rows/100.0)+0.5);
+      if (region_info->height == 0)
+        region_info->height=1;
     }
+  /*
+    If a region width of 0 is given by the user, use the images virtual canvas
+    size for the gravity offset adjustments, then restore afterward.
+  */
   width=region_info->width;
   height=region_info->height;
   if (width == 0)
-    {
-      if (image->page.width != 0)
-        width=image->page.width;
-      else
-        width=image->columns;
-    }
+    region_info->width  = image->page.width  | image->columns;
   if (height == 0)
-    {
-      if (image->page.height != 0)
-        height=image->page.height;
-      else
-        height=image->rows;
-    }
-  switch (image->gravity)
-  {
-    case ForgetGravity:
-    case NorthWestGravity:
-      break;
-    case NorthGravity:
-    {
-      region_info->x+=(long) (image->columns/2-width/2);
-      break;
-    }
-    case NorthEastGravity:
-    {
-      region_info->x=(long) (image->columns-width-region_info->x);
-      break;
-    }
-    case WestGravity:
-    {
-      region_info->y+=(long) (image->rows/2-height/2);
-      break;
-    }
-    case StaticGravity:
-    case CenterGravity:
-    default:
-    {
-      region_info->x+=(long) (image->columns/2-width/2);
-      region_info->y+=(long) (image->rows/2-height/2);
-      break;
-    }
-    case EastGravity:
-    {
-      region_info->x=(long) (image->columns-width-region_info->x);
-      region_info->y+=(long) (image->rows/2-height/2);
-      break;
-    }
-    case SouthWestGravity:
-    {
-      region_info->y=(long) (image->rows-height-region_info->y);
-      break;
-    }
-    case SouthGravity:
-    {
-      region_info->x+=(long) (image->columns/2-width/2);
-      region_info->y=(long) (image->rows-height-region_info->y);
-      break;
-    }
-    case SouthEastGravity:
-    {
-      region_info->x=(long) (image->columns-width-region_info->x);
-      region_info->y=(long) (image->rows-height-region_info->y);
-      break;
-    }
-  }
+    region_info->height = image->page.height | image->rows;
+  GravityAdjustGeometry(image->columns,image->rows,image->gravity,region_info);
+  region_info->width=width;
+  region_info->height=height;
   return(flags);
 }
 
@@ -988,6 +1016,15 @@ MagickExport MagickStatusType ParseGravityGeometry(Image *image,
 %      specification.
 %
 */
+
+static inline unsigned long MagickMax(const unsigned long x,
+  const unsigned long y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
 MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
   long *y,unsigned long *width,unsigned long *height)
 {
@@ -1036,8 +1073,12 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,long *x,
       scale.y=geometry_info.sigma;
       if ((flags & SigmaValue) == 0)
         scale.y=scale.x;
-      *width=(unsigned long) ((scale.x*former_width/100.0)+0.5);
-      *height=(unsigned long) ((scale.y*former_height/100.0)+0.5);
+      *width=(unsigned long) (scale.x*former_width/100.0+0.5);
+      if (*width == 0)
+        *width=1;
+      *height=(unsigned long) (scale.y*former_height/100.0+0.5);
+      if (*height == 0)
+        *height=1;
       former_width=(*width);
       former_height=(*height);
     }
@@ -1232,7 +1273,6 @@ MagickExport MagickStatusType ParseSizeGeometry(Image *image,
 %
 %    o geometry: The geometry.
 %
-%
 */
 MagickExport void SetGeometry(const Image *image,RectangleInfo *geometry)
 {
@@ -1267,7 +1307,6 @@ MagickExport void SetGeometry(const Image *image,RectangleInfo *geometry)
 %
 %    o geometry_info: The geometry info structure.
 %
-%
 */
 MagickExport void SetGeometryInfo(GeometryInfo *geometry_info)
 {
