@@ -329,8 +329,8 @@ MagickExport MagickBooleanType IdentifyImage(Image *image,FILE *file,
           break;
         }
       }
-      scale=QuantumRange/(QuantumRange >> (QuantumDepth-
-        channel_statistics[AllChannels].depth));
+      scale=QuantumRange/((unsigned long) QuantumRange >> ((unsigned long)
+        QuantumDepth-channel_statistics[AllChannels].depth));
       (void) fprintf(file,"  Channel statistics:\n");
       switch (colorspace)
       {
