@@ -25,7 +25,7 @@ extern "C" {
 #include <magick/color.h>
 
 #define OpaqueOpacity  ((Quantum) 0UL)
-#define TransparentOpacity  ((Quantum) QuantumRange)
+#define TransparentOpacity  (QuantumRange)
 
 typedef enum
 {
@@ -99,6 +99,9 @@ extern MagickExport MagickBooleanType
   SyncImagePixels(Image *),
   TextureImage(Image *,const Image *);
 
+extern MagickExport MagickPixelPacket
+  AcquireOneMagickPixel(const Image *,const long,const long,ExceptionInfo *);
+
 extern MagickExport PixelPacket
   AcquireOnePixel(const Image *,const long,const long,ExceptionInfo *),
   AcquireOneVirtualPixel(const Image *,const VirtualPixelMethod,const long,
