@@ -288,7 +288,7 @@ MagickExport const LocaleInfo **GetLocaleInfoList(const char *pattern,
   for (i=0; p != (const LocaleInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->tag,pattern,MagickFalse) != MagickFalse))
+        (GlobExpression(p->tag,pattern,MagickTrue) != MagickFalse))
       messages[i++]=p;
     p=(const LocaleInfo *) GetNextValueInSplayTree(locale_list);
   }
@@ -381,7 +381,7 @@ MagickExport char **GetLocaleList(const char *pattern,
   for (i=0; p != (const LocaleInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->tag,pattern,MagickFalse) != MagickFalse))
+        (GlobExpression(p->tag,pattern,MagickTrue) != MagickFalse))
       messages[i++]=ConstantString(p->tag);
     p=(const LocaleInfo *) GetNextValueInSplayTree(locale_list);
   }
@@ -424,14 +424,14 @@ MagickExport const char *GetLocaleMessage(const char *tag)
     *locale_info;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   if ((tag == (const char *) NULL) || (*tag == '\0'))
     return(tag);
-  GetExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
   (void) FormatMagickString(name,MaxTextExtent,"%s/",tag);
-  locale_info=GetLocaleInfo_(name,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  locale_info=GetLocaleInfo_(name,exception);
+  exception=DestroyExceptionInfo(exception);
   if (locale_info != (const LocaleInfo *) NULL)
     return(locale_info->message);
   return(tag);
@@ -730,7 +730,7 @@ static void *DestroyLocaleNode(void *locale_info)
 }
 
 static MagickBooleanType TraverseLocaleMap(const char *filename,
-  XMLTreeInfo **nodes,XMLTreeInfo *node,const unsigned long depth,
+  XMLTreeInfo **components,XMLTreeInfo *node,const unsigned long depth,
   ExceptionInfo *exception)
 {
   MagickBooleanType
@@ -747,12 +747,12 @@ static MagickBooleanType TraverseLocaleMap(const char *filename,
           *child,
           *sibling;
 
-        nodes[depth]=node;
+        components[depth]=node;
         if (strcmp(GetXMLTreeTag(node),"message") == 0)
           {
             char
-              message[MaxTextExtent],
-              tag[MaxTextExtent];
+              *message,
+              *tag;
 
             const char
               *attribute,
@@ -764,19 +764,6 @@ static MagickBooleanType TraverseLocaleMap(const char *filename,
             register long
               i;
 
-            *tag='\0';
-            for (i=1; i < (long) depth; i++)
-            {
-              (void) ConcatenateMagickString(tag,GetXMLTreeTag(nodes[i]),
-                MaxTextExtent);
-              (void) ConcatenateMagickString(tag,"/",MaxTextExtent);
-            }
-            attribute=GetXMLTreeAttribute(node,"name");
-            if (attribute != (const char *) NULL)
-              {
-                (void) ConcatenateMagickString(tag,attribute,MaxTextExtent);
-                (void) ConcatenateMagickString(tag,"/",MaxTextExtent);
-              }
             locale_info=(LocaleInfo *) AcquireMagickMemory(
               sizeof(*locale_info));
             if (locale_info == (LocaleInfo *) NULL)
@@ -785,27 +772,41 @@ static MagickBooleanType TraverseLocaleMap(const char *filename,
             (void) ResetMagickMemory(locale_info,0,sizeof(*locale_info));
             locale_info->path=ConstantString(filename);
             locale_info->signature=MagickSignature;
+            tag=(char *) NULL;
+            for (i=1; i < (long) depth; i++)
+            {
+              (void) ConcatenateString(&tag,GetXMLTreeTag(components[i]));
+              (void) ConcatenateString(&tag,"/");
+            }
+            attribute=GetXMLTreeAttribute(node,"name");
+            if (attribute != (const char *) NULL)
+              {
+                (void) ConcatenateString(&tag,attribute);
+                (void) ConcatenateString(&tag,"/");
+              }
             locale_info->tag=ConstantString(tag);
-            *message='\0';
+            tag=DestroyString(tag);
+            message=(char *) NULL;
             content=GetXMLTreeContent(node);
             if (content != (const char *) NULL)
               {
-                (void) CopyMagickString(message,content,MaxTextExtent);
+                (void) ConcatenateString(&message,content);
                 StripString(message);
               }
             locale_info->message=ConstantString(message);
-            status=AddValueToSplayTree(locale_list,ConstantString(
-              locale_info->tag),locale_info);
+            message=DestroyString(message);
+            status=AddValueToSplayTree(locale_list,locale_info->tag,
+              locale_info);
             if (status == MagickFalse)
               (void) ThrowMagickException(exception,GetMagickModule(),
                 ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
           }
         child=GetXMLTreeChild(node,(const char *) NULL);
         if (child != (XMLTreeInfo *) NULL)
-          status=TraverseLocaleMap(filename,nodes,child,depth+1,exception);
+          status=TraverseLocaleMap(filename,components,child,depth+1,exception);
         sibling=GetXMLTreeOrdered(node);
         if (sibling != (XMLTreeInfo *) NULL)
-          status=TraverseLocaleMap(filename,nodes,sibling,depth,exception);
+          status=TraverseLocaleMap(filename,components,sibling,depth,exception);
       }
   return(status);
 }
@@ -821,7 +822,7 @@ static MagickBooleanType LoadLocaleList(const char *xml,const char *filename,
 
   XMLTreeInfo
     *include,
-    **nodes,
+    **components,
     *locale_map;
 
   /*
@@ -833,7 +834,7 @@ static MagickBooleanType LoadLocaleList(const char *xml,const char *filename,
     return(MagickFalse);
   if (locale_list == (SplayTreeInfo *) NULL)
     {
-      locale_list=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
+      locale_list=NewSplayTree(CompareSplayTreeString,(void *(*)(void *)) NULL,
         DestroyLocaleNode);
       if (locale_list == (SplayTreeInfo *) NULL)
         {
@@ -885,16 +886,17 @@ static MagickBooleanType LoadLocaleList(const char *xml,const char *filename,
       }
     include=GetNextXMLTreeTag(include);
   }
-  nodes=(XMLTreeInfo **) AcquireMagickMemory(MaxRecursionDepth*sizeof(*nodes));
-  if (nodes == (XMLTreeInfo **) NULL)
+  components=(XMLTreeInfo **) AcquireMagickMemory(MaxRecursionDepth*
+    sizeof(*components));
+  if (components == (XMLTreeInfo **) NULL)
     {
       locale_map=DestroyXMLTree(locale_map);
       ThrowFileException(exception,ResourceLimitError,
         "MemoryAllocationFailed",filename);
       return(MagickFalse);
     }
-  status=TraverseLocaleMap(filename,nodes,locale_map,0,exception);
-  nodes=(XMLTreeInfo **) RelinquishMagickMemory(nodes);
+  status=TraverseLocaleMap(filename,components,locale_map,0,exception);
+  components=(XMLTreeInfo **) RelinquishMagickMemory(components);
   locale_map=DestroyXMLTree(locale_map);
   return(status);
 }
