@@ -179,16 +179,16 @@ MagickExport const char *GetImageMagick(const unsigned char *magick,
   const size_t length)
 {
   ExceptionInfo
-    exception;
+    *exception;
 
   register const MagickInfo
     *p;
 
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(magick != (const unsigned char *) NULL);
-  GetExceptionInfo(&exception);
-  p=GetMagickInfo("*",&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  p=GetMagickInfo("*",exception);
+  exception=DestroyExceptionInfo(exception);
   if (p == (const MagickInfo *) NULL)
     return((const char *) NULL);
   AcquireSemaphoreInfo(&magick_semaphore);
@@ -773,7 +773,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             *magick_info;
 
           magick_list=NewSplayTree(CompareSplayTreeString,
-            RelinquishMagickMemory,DestroyMagickNode);
+            (void *(*)(void *)) NULL,DestroyMagickNode);
           if (magick_list == (SplayTreeInfo *) NULL)
             {
               char
@@ -786,8 +786,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             }
           magick_info=SetMagickInfo("tmp");
           magick_info->stealth=MagickTrue;
-          status=AddValueToSplayTree(magick_list,ConstantString(
-            magick_info->name),magick_info);
+          status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
           if (status == MagickFalse)
             {
               char
@@ -800,8 +799,7 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
             }
           magick_info=SetMagickInfo("clipmask");
           magick_info->stealth=MagickTrue;
-          status=AddValueToSplayTree(magick_list,ConstantString(
-            magick_info->name),magick_info);
+          status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
           if (status == MagickFalse)
             {
               char
@@ -836,8 +834,8 @@ static MagickBooleanType InitializeMagickList(ExceptionInfo *exception)
 %                                                                             %
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 %
-%  IsMagickConflict() returns true if the image format is not a valid image
-%  format or conflicts with a logical drive (.e.g. X:).
+%  IsMagickConflict() returns MagickTrue if the image format is not a valid
+%  image format or conflicts with a logical drive (.e.g. X:).
 %
 %  The format of the IsMagickConflict method is:
 %
@@ -857,15 +855,15 @@ MagickExport MagickBooleanType IsMagickConflict(const char *magick)
     *magick_info;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   assert(magick != (char *) NULL);
-  GetExceptionInfo(&exception);
-  magick_info=GetMagickInfo(magick,&exception);
-  delegate_info=GetDelegateInfo(magick,(char *) NULL,&exception);
+  exception=AcquireExceptionInfo();
+  magick_info=GetMagickInfo(magick,exception);
+  delegate_info=GetDelegateInfo(magick,(char *) NULL,exception);
   if (delegate_info == (const DelegateInfo *) NULL)
-    delegate_info=GetDelegateInfo((char *) NULL,magick,&exception);
-  (void) DestroyExceptionInfo(&exception);
+    delegate_info=GetDelegateInfo((char *) NULL,magick,exception);
+  exception=DestroyExceptionInfo(exception);
   if ((magick_info == (const MagickInfo *) NULL) &&
       (delegate_info == (const DelegateInfo *) NULL))
     return(MagickTrue);
@@ -1301,8 +1299,7 @@ MagickExport MagickInfo *RegisterMagickInfo(MagickInfo *magick_info)
   (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",magick_info->name);
   if (magick_list == (SplayTreeInfo *) NULL)
     return((MagickInfo *) NULL);
-  status=AddValueToSplayTree(magick_list,ConstantString(magick_info->name),
-    magick_info);
+  status=AddValueToSplayTree(magick_list,magick_info->name,magick_info);
   if (status == MagickFalse)
     ThrowMagickFatalException(ResourceLimitFatalError,
       "UnableToAllocateMagickInfo",magick_info->name);
