@@ -134,23 +134,21 @@ BOOL WINAPI DllMain(HINSTANCE handle,DWORD reason,LPVOID lpvReserved)
     case DLL_PROCESS_ATTACH:
     {
       char
-        *module_path,
-        *new_path,
-        *path;
+        *module_path;
 
       ssize_t
         count;
 
       module_path=(char *) AcquireMagickMemory(MaxTextExtent*
         sizeof(*module_path));
-      new_path=(char *) AcquireMagickMemory(16*MaxTextExtent*sizeof(*new_path));
-      path=(char *) AcquireMagickMemory(16*MaxTextExtent*sizeof(*path));
-      if ((module_path == (char *) NULL) || (new_path == (char *) NULL) ||
-         (path == (char *) NULL))
+      if (module_path == (char *) NULL)
         return(FALSE);
       count=(ssize_t) GetModuleFileName(handle,module_path,MaxTextExtent);
       if (count != 0)
         {
+          char
+            *path;
+
           for ( ; count > 0; count--)
             if (module_path[count] == '\\')
               {
@@ -158,20 +156,36 @@ BOOL WINAPI DllMain(HINSTANCE handle,DWORD reason,LPVOID lpvReserved)
                 break;
               }
           MagickCoreGenesis(module_path,MagickFalse);
-          count=GetEnvironmentVariable("PATH",path,16*MaxTextExtent);
+          path=(char *) AcquireMagickMemory(16*MaxTextExtent*sizeof(*path));
+          if (path == (char *) NULL)
+            {
+              module_path=DestroyString(module_path);
+              return(FALSE);
+            }
+          count=(ssize_t) GetEnvironmentVariable("PATH",path,16*MaxTextExtent);
           if ((count != 0) && (strstr(path,module_path) == (char *) NULL))
             {
               if ((strlen(module_path)+count+1) < (16*MaxTextExtent-1))
                 {
-                  (void) FormatMagickString(new_path,16*MaxTextExtent,
+                  char
+                    *variable;
+
+                  variable=(char *) AcquireMagickMemory(16*MaxTextExtent*
+                    sizeof(*variable));
+                  if (variable == (char *) NULL)
+                    {
+                      path=DestroyString(path);
+                      module_path=DestroyString(module_path);
+                      return(FALSE);
+                    }
+                  (void) FormatMagickString(variable,16*MaxTextExtent,
                     "%s;%s",module_path,path);
-                  SetEnvironmentVariable("PATH",new_path);
+                  SetEnvironmentVariable("PATH",variable);
+                  variable=DestroyString(variable);
                 }
-              path=DestroyString(path);
             }
+          path=DestroyString(path);
         }
-      path=DestroyString(path);
-      new_path=DestroyString(new_path);
       module_path=DestroyString(module_path);
       break;
     }
@@ -1545,7 +1559,7 @@ MagickExport char *NTRegistryKeyLookup(const char *subkey)
     Look-up sub key.
   */
   size=32;
-  value=(char *) AcquireMagickMemory(size);
+  value=(char *) AcquireMagickMemory(size*sizeof(*value));
   if (value == (char *) NULL)
     {
       RegCloseKey(registry_key);
@@ -1555,7 +1569,7 @@ MagickExport char *NTRegistryKeyLookup(const char *subkey)
   status=RegQueryValueExA(registry_key,subkey,0,&type,value,&size);
   if ((status == ERROR_MORE_DATA) && (type == REG_SZ))
     {
-      value=(char *) ResizeMagickMemory(value,size);
+      value=(char *) ResizeMagickMemory(value,size*sizeof(*value));
       if (value == (char *) NULL)
         {
           RegCloseKey(registry_key);
