@@ -829,6 +829,9 @@ static const OptionInfo
     { "None", (long) NoInterlace },
     { "Plane", (long) PlaneInterlace },
     { "Partition", (long) PartitionInterlace },
+    { "GIF", (long) GIFInterlace },
+    { "JPEG", (long) JPEGInterlace },
+    { "PNG", (long) PNGInterlace },
     { (char *) NULL, (long) UndefinedInterlace }
   },
   InterpolateOptions[] =
@@ -962,6 +965,7 @@ static const OptionInfo
     { "Undefined", (long) UndefinedMetric },
     { "AE", (long) AbsoluteErrorMetric },
     { "MAE", (long) MeanAbsoluteErrorMetric },
+    { "MEPP", (long) MeanErrorPerPixelMetric },
     { "MSE", (long) MeanSquaredErrorMetric },
     { "PAE", (long) PeakAbsoluteErrorMetric },
     { "PSNR", (long) PeakSignalToNoiseRatioMetric },
