@@ -115,6 +115,9 @@ MagickExport MagickBooleanType CloneImageProperties(Image *image,
       clone_image->filename);
   assert(clone_image != (const Image *) NULL);
   assert(clone_image->signature == MagickSignature);
+  (void) CopyMagickString(image->filename,clone_image->filename,MaxTextExtent);
+  (void) CopyMagickString(image->magick_filename,clone_image->magick_filename,
+    MaxTextExtent);
   image->compression=clone_image->compression;
   image->quality=clone_image->quality;
   image->depth=clone_image->depth;
@@ -668,7 +671,7 @@ static MagickBooleanType Get8BIMProperty(const Image *image,const char *key)
   return(status);
 }
 
-static inline short ReadPropertyShort(const EndianType endian,
+static inline unsigned short ReadPropertyShort(const EndianType endian,
   unsigned char *buffer)
 {
   unsigned short
@@ -2854,18 +2857,6 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
     ConstantString(property),ConstantString(value));
   switch (*property)
   {
-    case 'C':
-    case 'c':
-    {
-      if (LocaleCompare(property,"comment") == 0)
-        {
-          status=AddValueToSplayTree((SplayTreeInfo *) image->properties,
-            ConstantString(property),InterpretImageProperties((ImageInfo *)
-            NULL,image,value));
-          break;
-        }
-      break;
-    }
     case 'D':
     case 'd':
     {
@@ -2933,18 +2924,6 @@ MagickExport MagickBooleanType SetImageProperty(Image *image,
         }
       break;
     }
-    case 'L':
-    case 'l':
-    {
-      if (LocaleCompare(property,"label") == 0)
-        {
-          status=AddValueToSplayTree((SplayTreeInfo *) image->properties,
-            ConstantString(property),InterpretImageProperties((ImageInfo *)
-            NULL,image,value));
-          break;
-        }
-      break;
-    }
     case 'O':
     case 'o':
     {
