@@ -57,6 +57,9 @@ typedef enum
 
 typedef struct _QuantumInfo
 {
+  unsigned long
+    quantum;
+
   QuantumFormatType
     format;
 
@@ -88,15 +91,6 @@ static inline MagickRealType ClipToQuantum(const MagickRealType value)
   return(value);
 }
 
-static inline unsigned short RoundToMap(const MagickRealType value)
-{
-  if (value <= 0.0)
-    return(0UL);
-  if (value >= MaxMap)
-    return((unsigned short) MaxMap);
-  return((unsigned short) (value+0.5));
-}
-
 static inline Quantum RoundToQuantum(const MagickRealType value)
 {
 #if defined(UseHDRI)
@@ -105,7 +99,7 @@ static inline Quantum RoundToQuantum(const MagickRealType value)
   if (value <= 0.0)
     return((Quantum) 0);
   if (value >= QuantumRange)
-    return((Quantum) QuantumRange);
+    return(QuantumRange);
   return((Quantum) (value+0.5));
 #endif 
 }
@@ -141,9 +135,17 @@ static inline Quantum ScaleLongToQuantum(const unsigned long value)
 #endif
 }
 
-static inline Quantum ScaleMapToQuantum(const unsigned long value)
+static inline Quantum ScaleMapToQuantum(const MagickRealType value)
 {
+#if defined(UseHDRI)
   return((Quantum) value);
+#else
+  if (value <= 0.0)
+    return(0);
+  if (value >= MaxMap)
+    return(QuantumRange);
+  return((Quantum) (value+0.5));
+#endif
 }
 
 static inline unsigned char ScaleQuantumToChar(const Quantum quantum)
@@ -180,7 +182,7 @@ static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
   if (quantum <= 0.0)
     return(0UL);
   if (quantum >= MaxMap)
-    return(MaxMap);
+    return((unsigned long) MaxMap);
   return((unsigned long) (quantum+0.5));
 #endif
 }
@@ -206,11 +208,6 @@ static inline Quantum ScaleShortToQuantum(const unsigned short value)
   return((Quantum) (value/257.0));
 #endif
 }
-
-static inline unsigned long ScaleToQuantum(const unsigned long value)
-{
-  return((unsigned long) value);
-}
 #elif (QuantumDepth == 16)
 static inline Quantum ScaleCharToQuantum(const unsigned char value)
 {
@@ -230,9 +227,17 @@ static inline Quantum ScaleLongToQuantum(const unsigned long value)
 #endif
 }
 
-static inline Quantum ScaleMapToQuantum(const unsigned long value)
+static inline Quantum ScaleMapToQuantum(const MagickRealType value)
 {
+#if defined(UseHDRI)
   return((Quantum) value);
+#else
+  if (value <= 0.0)
+    return(0);
+  if (value >= MaxMap)
+    return(QuantumRange);
+  return((Quantum) (value+0.5));
+#endif
 }
 
 static inline unsigned char ScaleQuantumToChar(const Quantum quantum)
@@ -269,7 +274,7 @@ static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
   if (quantum <= 0.0)
     return(0);
   if (quantum >= MaxMap)
-    return(MaxMap);
+    return((unsigned long) MaxMap);
   return((unsigned long) (quantum+0.5));
 #endif
 }
@@ -291,15 +296,6 @@ static inline Quantum ScaleShortToQuantum(const unsigned short value)
 {
   return((Quantum) value);
 }
-
-static inline unsigned long ScaleToQuantum(const unsigned long value)
-{
-#if !defined(UseHDRI)
-  return(257UL*value);
-#else
-  return((unsigned long) (257.0*value));
-#endif
-}
 #elif (QuantumDepth == 32)
 static inline Quantum ScaleCharToQuantum(const unsigned char value)
 {
@@ -315,12 +311,16 @@ static inline Quantum ScaleLongToQuantum(const unsigned long value)
   return((Quantum) value);
 }
 
-static inline Quantum ScaleMapToQuantum(const unsigned long value)
+static inline Quantum ScaleMapToQuantum(const MagickRealType value)
 {
-#if !defined(UseHDRI)
-  return((Quantum) (65537UL*value));
-#else
+#if defined(UseHDRI)
   return((Quantum) (65537.0*value));
+#else
+  if (value <= 0.0)
+    return(0);
+  if (value >= MaxMap)
+    return(QuantumRange);
+  return((Quantum) (65537UL*value));
 #endif
 }
 
@@ -360,7 +360,7 @@ static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
   if (quantum <= 0.0)
     return(0);
   if ((quantum/65537.0) >= (MagickRealType) MaxMap)
-    return(MaxMap);
+    return((unsigned long) MaxMap);
   return((unsigned long) (quantum/65537.0));
 #endif
 }
@@ -391,15 +391,6 @@ static inline Quantum ScaleShortToQuantum(const unsigned short value)
   return((Quantum) (65537.0*value));
 #endif
 }
-
-static inline unsigned long ScaleToQuantum(const unsigned long value)
-{
-#if !defined(UseHDRI)
-  return((unsigned long) (16843009UL*value));
-#else
-  return((unsigned long) (16843009.0*value));
-#endif
-}
 #elif (QuantumDepth == 64)
 static inline Quantum ScaleCharToQuantum(const unsigned char value)
 {
@@ -419,12 +410,16 @@ static inline Quantum ScaleLongToQuantum(const unsigned long value)
 #endif
 }
 
-static inline Quantum ScaleMapToQuantum(const unsigned long value)
+static inline Quantum ScaleMapToQuantum(const MagickRealType value)
 {
-#if !defined(UseHDRI)
-  return((Quantum) (MagickULLConstant(281479271612415)*value));
-#else
+#if defined(UseHDRI)
   return((Quantum) (281479271612415.0*value));
+#else
+  if (value <= 0.0)
+    return(0);
+  if (value >= MaxMap)
+    return(QuantumRange);
+  return((Quantum) (MagickULLConstant(281479271612415)*value));
 #endif
 }
 
@@ -454,7 +449,7 @@ static inline unsigned long ScaleQuantumToMap(const Quantum quantum)
   if (quantum <= 0.0)
     return(0);
   if ((quantum/281479271612415.0) >= (MagickRealType) MaxMap)
-    return(MaxMap);
+    return((unsigned long) MaxMap);
   return((unsigned long) (quantum/281479271612415.0));
 #endif
 }
@@ -476,15 +471,6 @@ static inline Quantum ScaleShortToQuantum(const unsigned short value)
   return((Quantum) (281479271612415.0*value));
 #endif
 }
-
-static inline unsigned long long ScaleToQuantum(const unsigned long value)
-{
-#if !defined(UseHDRI)
-  return(MagickULLConstant(71777214294589695)*value);
-#else
-  return((unsigned long long) (71777214294589695.0*value));
-#endif
-}
 #endif
 
 extern MagickExport MagickBooleanType
