@@ -16,7 +16,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -171,13 +171,13 @@ MagickExport Image *AdaptiveResizeImage(const Image *image,
     if (q == (PixelPacket *) NULL)
       break;
     resize_indexes=GetIndexes(resize_image);
-    offset.y=(MagickRealType) y*image->rows/resize_image->rows;
+    offset.y=(MagickRealType) (y*image->rows/resize_image->rows);
     for (x=0; x < (long) resize_image->columns; x++)
     {
-      offset.x=(MagickRealType) x*image->columns/resize_image->columns;
-      pixel=InterpolatePixelColor(image,image_view,MeshInterpolatePixel,
+      offset.x=(MagickRealType) (x*image->columns/resize_image->columns);
+      pixel=InterpolatePixelColor(image,image_view,image->interpolate,
         offset.x-0.5,offset.y-0.5,exception);
-      SetPixelPacket(&pixel,q,resize_indexes+x);
+      SetPixelPacket(resize_image,&pixel,q,resize_indexes+x);
       q++;
     }
     if (SyncCacheView(resize_view) == MagickFalse)
@@ -626,6 +626,21 @@ static MagickRealType Lanczos(const MagickRealType x,
   return(0.0);
 }
 
+static inline double MagickMax(const double x,const double y)
+{
+  if (x > y)
+    return(x);
+  return(y);
+}
+
+static inline double MagickMin(const double x,const double y)
+{
+  if (x < y)
+    return(x);
+  return(y);
+}
+
+
 static MagickRealType Mitchell(const MagickRealType x,
   const MagickRealType magick_unused(support))
 {
@@ -725,7 +740,7 @@ static MagickBooleanType HorizontalFilter(const Image *source,
   /*
     Apply filter to resize horizontally from source to destination.
   */
-  scale=blur*Max(1.0/x_factor,1.0);
+  scale=blur*MagickMax(1.0/x_factor,1.0);
   support=scale*filter_info->support;
   destination->storage_class=source->storage_class;
   if (support > 0.5)
@@ -749,8 +764,8 @@ static MagickBooleanType HorizontalFilter(const Image *source,
   for (x=0; x < (long) destination->columns; x++)
   {
     center=(MagickRealType) (x+0.5)/x_factor;
-    start=(long) Max(center-support+0.5,0);
-    stop=(long) Min(center+support+0.5,(MagickRealType) source->columns);
+    start=(long) (MagickMax(center-support,0.0)+0.5);
+    stop=(long) (MagickMin(center+support,(double) source->columns)+0.5);
     density=0.0;
     for (n=0; n < (stop-start); n++)
     {
@@ -855,7 +870,8 @@ static MagickBooleanType HorizontalFilter(const Image *source,
       if ((destination->storage_class == PseudoClass) &&
           (source->storage_class == PseudoClass))
         {
-          i=Min(Max((long) (center+0.5),start),stop-1);
+          i=(long) (MagickMin(MagickMax(center,(double) start),(double) stop-
+            1.0)+0.5);
           j=y*(contribution[n-1].pixel-contribution[0].pixel+1)+
             (contribution[i-start].pixel-contribution[0].pixel);
           indexes[y]=source_indexes[j];
@@ -921,7 +937,7 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
   /*
     Apply filter to resize vertically from source to destination.
   */
-  scale=blur*Max(1.0/y_factor,1.0);
+  scale=blur*MagickMax(1.0/y_factor,1.0);
   support=scale*filter_info->support;
   destination->storage_class=source->storage_class;
   if (support > 0.5)
@@ -945,8 +961,8 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
   for (y=0; y < (long) destination->rows; y++)
   {
     center=(MagickRealType) (y+0.5)/y_factor;
-    start=(long) Max(center-support+0.5,0);
-    stop=(long) Min(center+support+0.5,(MagickRealType) source->rows);
+    start=(long) (MagickMax(center-support,0.0)+0.5);
+    stop=(long) (MagickMin(center+support,(double) source->rows)+0.5);
     density=0.0;
     for (n=0; n < (stop-start); n++)
     {
@@ -1052,7 +1068,8 @@ static MagickBooleanType VerticalFilter(const Image *source,Image *destination,
       if ((destination->storage_class == PseudoClass) &&
           (source->storage_class == PseudoClass))
         {
-          i=Min(Max((long) (center+0.5),start),stop-1);
+          i=(long) (MagickMin(MagickMax(center,(double) start),(double) stop-
+            1.0)+0.5);
           j=(long) ((contribution[i-start].pixel-contribution[0].pixel)*
             source->columns+x);
           indexes[x]=source_indexes[j];
@@ -1159,13 +1176,13 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
       if ((image->storage_class == PseudoClass) ||
           (image->matte != MagickFalse) || ((x_factor*y_factor) > 1.0))
         i=(long) MitchellFilter;
-  x_support=blur*Max(1.0/x_factor,1.0)*filters[i].support;
-  y_support=blur*Max(1.0/y_factor,1.0)*filters[i].support;
-  support=Max(x_support,y_support);
+  x_support=blur*MagickMax(1.0/x_factor,1.0)*filters[i].support;
+  y_support=blur*MagickMax(1.0/y_factor,1.0)*filters[i].support;
+  support=MagickMax(x_support,y_support);
   if (support < filters[i].support)
     support=filters[i].support;
   contribution=(ContributionInfo *) AcquireMagickMemory((size_t)
-    (2.0*Max(support,0.5)+3)*sizeof(*contribution));
+    (2.0*MagickMax(support,0.5)+3)*sizeof(*contribution));
   if (contribution == (ContributionInfo *) NULL)
     {
       resize_image=DestroyImage(resize_image);
@@ -1251,7 +1268,6 @@ MagickExport Image *ResizeImage(const Image *image,const unsigned long columns,
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport Image *SampleImage(const Image *image,const unsigned long columns,
   const unsigned long rows,ExceptionInfo *exception)
