@@ -17,7 +17,7 @@
 %                               September 2002                                %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -124,7 +124,6 @@ static SplayTreeInfo
 %
 %    o size: The number of bytes needed from for this resource.
 %
-%
 */
 MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
   const MagickSizeType size)
@@ -238,7 +237,6 @@ MagickExport MagickBooleanType AcquireMagickResource(const ResourceType type,
 %
 %      DestroyMagickResources(void)
 %
-%
 */
 MagickExport void AsynchronousDestroyMagickResources(void)
 {
@@ -282,7 +280,6 @@ MagickExport void AsynchronousDestroyMagickResources(void)
 %   o  path:  Specifies a pointer to an array of characters.  The unique path
 %      name is returned in this array.
 %
-%
 */
 
 static void *DestroyTemporaryResources(void *temporary_resource)
@@ -327,13 +324,13 @@ static MagickBooleanType GetPathTemplate(char *path)
     return(MagickTrue);
   if (strlen(directory) > (MaxTextExtent-15))
     {
-      directory=(char *) RelinquishMagickMemory(directory);
+      directory=DestroyString(directory);
       return(MagickTrue);
     }
   status=stat(directory,&file_info);
   if ((status != 0) || !S_ISDIR(file_info.st_mode))
     {
-      directory=(char *) RelinquishMagickMemory(directory);
+      directory=DestroyString(directory);
       return(MagickTrue);
     }
   if (directory[strlen(directory)-1] == *DirectorySeparator)
@@ -341,7 +338,7 @@ static MagickBooleanType GetPathTemplate(char *path)
   else
     (void) FormatMagickString(path,MaxTextExtent,"%s%smagick-XXXXXXXX",
       directory,DirectorySeparator);
-  directory=(char *) RelinquishMagickMemory(directory);
+  directory=DestroyString(directory);
   if (*DirectorySeparator != '/')
     for (p=path; *p != '\0'; p++)
       if (*p == *DirectorySeparator)
@@ -433,7 +430,6 @@ MagickExport int AcquireUniqueFileResource(char *path)
 %
 %      DestroyMagickResources(void)
 %
-%
 */
 MagickExport void DestroyMagickResources(void)
 {
@@ -465,7 +461,6 @@ MagickExport void DestroyMagickResources(void)
 %
 %    o type: The type of resource.
 %
-%
 */
 MagickExport unsigned long GetMagickResource(const ResourceType type)
 {
@@ -588,7 +583,6 @@ MagickExport unsigned long GetMagickResourceLimit(const ResourceType type)
 %
 %      InitializeMagickResources(void)
 %
-%
 */
 
 static inline long MagickMax(const long x,const long y)
@@ -634,30 +628,30 @@ MagickExport void InitializeMagickResources(void)
 #endif
   (void) SetMagickResourceLimit(AreaResource,2*memory);
   (void) SetMagickResourceLimit(MemoryResource,3*memory/2);
-  (void) SetMagickResourceLimit(MapResource,8*memory);
+  (void) SetMagickResourceLimit(MapResource,memory/4);
   limit=GetEnvironmentValue("MAGICK_AREA_LIMIT");
   if (limit != (char *) NULL)
     {
       (void) SetMagickResourceLimit(AreaResource,(unsigned long) atol(limit));
-      limit=(char *) RelinquishMagickMemory(limit);
+      limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_MEMORY_LIMIT");
   if (limit != (char *) NULL)
     {
       (void) SetMagickResourceLimit(MemoryResource,(unsigned long) atol(limit));
-      limit=(char *) RelinquishMagickMemory(limit);
+      limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_MAP_LIMIT");
   if (limit != (char *) NULL)
     {
       (void) SetMagickResourceLimit(MapResource,(unsigned long) atol(limit));
-      limit=(char *) RelinquishMagickMemory(limit);
+      limit=DestroyString(limit);
     }
   limit=GetEnvironmentValue("MAGICK_DISK_LIMIT");
   if (limit != (char *) NULL)
     {
       (void) SetMagickResourceLimit(DiskResource,(unsigned long) atol(limit));
-      limit=(char *) RelinquishMagickMemory(limit);
+      limit=DestroyString(limit);
     }
   files=(-1);
 #if defined(HAVE_SYSCONF) && defined(_SC_OPEN_MAX)
@@ -671,7 +665,7 @@ MagickExport void InitializeMagickResources(void)
   if (limit != (char *) NULL)
     {
       (void) SetMagickResourceLimit(FileResource,(unsigned long) atol(limit));
-      limit=(char *) RelinquishMagickMemory(limit);
+      limit=DestroyString(limit);
     }
 }
 
@@ -699,7 +693,6 @@ MagickExport void InitializeMagickResources(void)
 %
 %    o exception: Return any errors or warnings in this structure.
 %
-%
 */
 MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
   ExceptionInfo *magick_unused(exception))
@@ -753,7 +746,6 @@ MagickExport MagickBooleanType ListMagickResourceInfo(FILE *file,
 %
 %    o size: The size of the resource.
 %
-%
 */
 MagickExport void RelinquishMagickResource(const ResourceType type,
   const MagickSizeType size)
@@ -842,7 +834,6 @@ MagickExport void RelinquishMagickResource(const ResourceType type,
 %
 %    o name: the name of the temporary resource.
 %
-%
 */
 MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
 {
@@ -898,7 +889,6 @@ MagickExport MagickBooleanType RelinquishUniqueFileResource(const char *path)
 %
 %    o limit: The maximum limit for the resource.
 %
-%
 */
 MagickExport MagickBooleanType SetMagickResourceLimit(const ResourceType type,
   const unsigned long limit)
