@@ -17,7 +17,7 @@
 %                                April 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -520,7 +520,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
     indexes=GetIndexes(image);
     for (x=0; x < (long) image->columns; x++)
     {
-      index=0;
+      index=(IndexPacket) 0;
       cluster=head;
       for (i=0; i < (long) number_clusters; i++)
       {
@@ -585,7 +585,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
           }
         }
       indexes[x]=index;
-      *q=image->colormap[index];
+      *q=image->colormap[(long) index];
       q++;
     }
     if (SyncImagePixels(image) == MagickFalse)
@@ -644,7 +644,7 @@ static MagickBooleanType Classify(Image *image,short **extrema,
 
 static inline long MagickAbsoluteValue(const long x)
 {
-  if (x < 0.0)
+  if (x < 0)
     return(-x);
   return(x);
 }
