@@ -90,9 +90,6 @@ struct _SplayTreeInfo
     *(*relinquish_key)(void *),
     *(*relinquish_value)(void *);
 
-  unsigned long
-    depth;
-
   MagickBooleanType
     balance;
 
@@ -171,15 +168,15 @@ MagickExport MagickBooleanType AddValueToSplayTree(SplayTreeInfo *splay_info,
           ((splay_info->root->key < key) ? -1 : 0);
       if (compare == 0)
         {
-          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-              (splay_info->root->value != (void *) NULL))
-            splay_info->root->value=splay_info->relinquish_value(
-              splay_info->root->value);
           if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
               (splay_info->root->key != (void *) NULL))
             splay_info->root->key=splay_info->relinquish_key(
               splay_info->root->key);
           splay_info->root->key=(void *) key;
+          if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+              (splay_info->root->value != (void *) NULL))
+            splay_info->root->value=splay_info->relinquish_value(
+              splay_info->root->value);
           splay_info->root->value=(void *) value;
           RelinquishSemaphoreInfo(splay_info->semaphore);
           return(MagickTrue);
@@ -240,8 +237,8 @@ MagickExport MagickBooleanType AddValueToSplayTree(SplayTreeInfo *splay_info,
 %
 */
 
-static NodeInfo *LinkSplayTreeNodes(NodeInfo **nodes,unsigned long low,
-  unsigned long high)
+static NodeInfo *LinkSplayTreeNodes(NodeInfo **nodes,const unsigned long low,
+  const unsigned long high)
 {
   register NodeInfo
     *node;
@@ -411,14 +408,14 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
   AcquireSemaphoreInfo(&splay_info->semaphore);
   if (splay_info->root != (NodeInfo *) NULL)
     {
-      if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-          (splay_info->root->value != (void *) NULL))
-        splay_info->root->value=splay_info->relinquish_value(
-          splay_info->root->value);
       if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
           (splay_info->root->key != (void *) NULL))
         splay_info->root->key=splay_info->relinquish_key(splay_info->root->key);
       splay_info->root->key=(void *) NULL;
+      if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+          (splay_info->root->value != (void *) NULL))
+        splay_info->root->value=splay_info->relinquish_value(
+          splay_info->root->value);
       for (pend=splay_info->root; pend != (NodeInfo *) NULL; )
       {
         active=pend;
@@ -426,27 +423,27 @@ MagickExport SplayTreeInfo *DestroySplayTree(SplayTreeInfo *splay_info)
         {
           if (active->left != (NodeInfo *) NULL)
             {
-              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-                  (active->left->value != (void *) NULL))
-                active->left->value=splay_info->relinquish_value(
-                  active->left->value);
               if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
                   (active->left->key != (void *) NULL))
                 active->left->key=splay_info->relinquish_key(active->left->key);
               active->left->key=(void *) pend;
+              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+                  (active->left->value != (void *) NULL))
+                active->left->value=splay_info->relinquish_value(
+                  active->left->value);
               pend=active->left;
             }
           if (active->right != (NodeInfo *) NULL)
             {
-              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-                  (active->right->value != (void *) NULL))
-                active->right->value=splay_info->relinquish_value(
-                  active->right->value);
               if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
                   (active->right->key != (void *) NULL))
                 active->right->key=splay_info->relinquish_key(
                   active->right->key);
               active->right->key=(void *) pend;
+              if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+                  (active->right->value != (void *) NULL))
+                active->right->value=splay_info->relinquish_value(
+                  active->right->value);
               pend=active->right;
             }
           node=active;
@@ -845,7 +842,6 @@ MagickExport SplayTreeInfo *NewSplayTree(
   splay_info->compare=compare;
   splay_info->relinquish_key=relinquish_key;
   splay_info->relinquish_value=relinquish_value;
-  splay_info->depth=0;
   splay_info->balance=MagickFalse;
   splay_info->key=(void *) NULL;
   splay_info->next=(void *) NULL;
@@ -951,14 +947,14 @@ MagickExport MagickBooleanType RemoveNodeByValueFromSplayTree(
           }
         left=splay_info->root->left;
         right=splay_info->root->right;
-        if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
-            (splay_info->root->value != (void *) NULL))
-          splay_info->root->value=splay_info->relinquish_value(
-            splay_info->root->value);
         if ((splay_info->relinquish_key != (void *(*)(void *)) NULL) &&
             (splay_info->root->key != (void *) NULL))
           splay_info->root->key=splay_info->relinquish_key(
             splay_info->root->key);
+        if ((splay_info->relinquish_value != (void *(*)(void *)) NULL) &&
+            (splay_info->root->value != (void *) NULL))
+          splay_info->root->value=splay_info->relinquish_value(
+            splay_info->root->value);
         splay_info->root=(NodeInfo *) RelinquishMagickMemory(splay_info->root);
         splay_info->nodes--;
         if (left == (NodeInfo *) NULL)
@@ -1131,8 +1127,8 @@ MagickExport void ResetSplayTreeIterator(SplayTreeInfo *splay_info)
 %
 */
 
-static NodeInfo *Splay(SplayTreeInfo *splay_info,const void *key,
-  NodeInfo **node,NodeInfo **parent,NodeInfo **grandparent)
+static NodeInfo *Splay(SplayTreeInfo *splay_info,const unsigned long depth,
+  const void *key,NodeInfo **node,NodeInfo **parent,NodeInfo **grandparent)
 {
   int
     compare;
@@ -1159,15 +1155,13 @@ static NodeInfo *Splay(SplayTreeInfo *splay_info,const void *key,
       next=(&n->right);
   if (next != (NodeInfo **) NULL)
     {
-      if (splay_info->depth >= MaxSplayTreeDepth)
+      if (depth >= MaxSplayTreeDepth)
         {
           splay_info->balance=MagickTrue;
           return(n);
         }
-      splay_info->depth++;
-      n=Splay(splay_info,key,next,node,parent);
-      splay_info->depth--;
-      if ((*node != n) || (splay_info->balance != MagickFalse))
+      n=Splay(splay_info,depth+1,key,next,node,parent);
+      if ((n != *node) || (splay_info->balance != MagickFalse))
         return(n);
     }
   if (parent == (NodeInfo **) NULL)
@@ -1241,14 +1235,12 @@ static void SplaySplayTree(SplayTreeInfo *splay_info,const void *key)
       if (compare == 0)
         return;
     }
-  splay_info->depth=0;
-  (void) Splay(splay_info,key,&splay_info->root,(NodeInfo **) NULL,
+  (void) Splay(splay_info,0UL,key,&splay_info->root,(NodeInfo **) NULL,
     (NodeInfo **) NULL);
   if (splay_info->balance != MagickFalse)
     {
       BalanceSplayTree(splay_info);
-      splay_info->depth=0;
-      (void) Splay(splay_info,key,&splay_info->root,(NodeInfo **) NULL,
+      (void) Splay(splay_info,0UL,key,&splay_info->root,(NodeInfo **) NULL,
         (NodeInfo **) NULL);
       if (splay_info->balance != MagickFalse)
         {
