@@ -255,7 +255,7 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
   if (image->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   depth=1;
-  scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
+  scale=QuantumRange/((unsigned long) QuantumRange >> (QuantumDepth-depth));
   if ((image->storage_class == PseudoClass) && (image->matte == MagickFalse))
     {
       p=image->colormap;
@@ -282,7 +282,8 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
             depth++;
             if (depth == QuantumDepth)
               return(depth);
-            scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
+            scale=QuantumRange/((unsigned long) QuantumRange >>
+               (QuantumDepth-depth));
             continue;
           }
         x++;
@@ -330,7 +331,8 @@ MagickExport unsigned long GetImageChannelDepth(const Image *image,
             depth++;
             if (depth == QuantumDepth)
               return(depth);
-            scale=QuantumRange/(QuantumRange >> (QuantumDepth-depth));
+            scale=QuantumRange/((unsigned long) QuantumRange >>
+              (QuantumDepth-depth));
             continue;
           }
         x++;
@@ -772,7 +774,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
   {
     channel_statistics[i].depth=1;
     channel_statistics[i].scale=(unsigned long)
-      (QuantumRange/(QuantumRange >> (QuantumDepth-1)));
+      (QuantumRange/((unsigned long) QuantumRange >> (QuantumDepth-1)));
     channel_statistics[i].maxima=(-1.0E-37);
     channel_statistics[i].minima=1.0E+37;
     channel_statistics[i].mean=0.0;
@@ -797,7 +799,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
             {
               channel_statistics[RedChannel].depth++;
               channel_statistics[RedChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
+                ((unsigned long) QuantumRange >> (QuantumDepth-
                 channel_statistics[RedChannel].depth));
               continue;
             }
@@ -810,7 +812,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
             {
               channel_statistics[GreenChannel].depth++;
               channel_statistics[GreenChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
+                ((unsigned long) QuantumRange >> (QuantumDepth-
                 channel_statistics[GreenChannel].depth));
               continue;
             }
@@ -823,7 +825,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
             {
               channel_statistics[BlueChannel].depth++;
               channel_statistics[BlueChannel].scale=QuantumRange/
-                (QuantumRange >> (QuantumDepth-
+                ((unsigned long) QuantumRange >> (QuantumDepth-
                 channel_statistics[BlueChannel].depth));
               continue;
             }
@@ -838,7 +840,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
                 {
                   channel_statistics[OpacityChannel].depth++;
                   channel_statistics[OpacityChannel].scale=QuantumRange/
-                    (QuantumRange >> (QuantumDepth-
+                    ((unsigned long) QuantumRange >> (QuantumDepth-
                     channel_statistics[OpacityChannel].depth));
                   continue;
                 }
@@ -854,7 +856,7 @@ MagickExport ChannelStatistics *GetImageChannelStatistics(const Image *image,
                 {
                   channel_statistics[BlackChannel].depth++;
                   channel_statistics[BlackChannel].scale=QuantumRange/
-                    (QuantumRange >> (QuantumDepth-
+                    ((unsigned long) QuantumRange >> (QuantumDepth-
                     channel_statistics[BlackChannel].depth));
                   continue;
                 }
@@ -1044,9 +1046,9 @@ MagickExport MagickBooleanType SetImageChannelDepth(Image *image,
       /*
         Scale pixels to desired depth.
       */
-      scale=(MagickRealType) QuantumRange/(MagickRealType) (QuantumRange >>
-        (QuantumDepth-(unsigned long) MagickMin((double) depth,(double)
-        QuantumDepth)));
+      scale=(MagickRealType) QuantumRange/(MagickRealType) ((unsigned long)
+        QuantumRange >> (QuantumDepth-(unsigned long) MagickMin((double) depth,
+        (double) QuantumDepth)));
       for (y=0; y < (long) image->rows; y++)
       {
         q=GetImagePixels(image,0,y,image->columns,1);
