@@ -224,7 +224,7 @@ static inline void AcquireStreamPixels(CacheInfo *cache_info)
 {
   assert(cache_info != (CacheInfo *) NULL);
   assert(cache_info->length == (MagickSizeType) ((size_t) cache_info->length));
-  if (cache_info->length > MinBlobExtent)
+  if (cache_info->length < MaxBlobExtent)
     {
       cache_info->pixels=(PixelPacket *) MapBlob(-1,IOMode,0,(size_t)
         cache_info->length);
@@ -1352,7 +1352,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToChar(p->blue);
             *q++=ScaleQuantumToChar(p->green);
             *q++=ScaleQuantumToChar(p->red);
-            *q++=ScaleQuantumToChar(0);
+            *q++=ScaleQuantumToChar((Quantum) 0);
             p++;
           }
           break;
@@ -1420,7 +1420,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=ScaleQuantumToChar(p->red);
             *q++=ScaleQuantumToChar(p->green);
             *q++=ScaleQuantumToChar(p->blue);
-            *q++=ScaleQuantumToChar(0);
+            *q++=ScaleQuantumToChar((Quantum) 0);
             p++;
           }
           break;
@@ -2384,7 +2384,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
             *q++=p->blue;
             *q++=p->green;
             *q++=p->red;
-            *q++=0U;
+            *q++=0;
             p++;
           }
           break;
@@ -2465,7 +2465,7 @@ static MagickBooleanType StreamImagePixels(const StreamInfo *stream_info,
       {
         for (i=0; i < (long) length; i++)
         {
-          *q=0;
+          *q=(Quantum) 0;
           switch (quantum_map[i])
           {
             case RedQuantum:
