@@ -17,7 +17,7 @@
 %                              January 1993                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -102,7 +102,7 @@ MagickExport TokenInfo *AcquireTokenInfo(void)
       message=GetExceptionMessage(errno);
       ThrowMagickFatalException(ResourceLimitFatalError,
         "MemoryAllocationFailed",message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   token_info->signature=MagickSignature;
   return(token_info);
@@ -303,7 +303,7 @@ MagickExport void GetMagickToken(const char *start,char **end,char *token)
 %  The format of the GlobExpression function is:
 %
 %      MagickBooleanType GlobExpression(const char *expression,
-%        const char *pattern)
+%        const char *pattern,const MagickBooleanType case_insensitive)
 %
 %  A description of each parameter follows:
 %
@@ -311,13 +311,16 @@ MagickExport void GetMagickToken(const char *start,char **end,char *token)
 %
 %    o pattern: Specifies a pointer to a text string containing a pattern.
 %
+%    o case_insensitive: set to MagickTrue to ignore the case when matching
+%      an expression.
 %
 */
 MagickExport MagickBooleanType GlobExpression(const char *expression,
-  const char *pattern)
+  const char *pattern,const MagickBooleanType case_insensitive)
 {
   MagickBooleanType
-    done;
+    done,
+    match;
 
   register const char
     *p;
@@ -335,7 +338,7 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
   if ((*p == ']') && (strchr(pattern,'[') != (char *) NULL))
     {
       ExceptionInfo
-        exception;
+        *exception;
 
       ImageInfo
         *image_info;
@@ -345,9 +348,9 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
       */
       image_info=AcquireImageInfo();
       (void) CopyMagickString(image_info->filename,pattern,MaxTextExtent);
-      GetExceptionInfo(&exception);
-      (void) SetImageInfo(image_info,MagickTrue,&exception);
-      (void) DestroyExceptionInfo(&exception);
+      exception=AcquireExceptionInfo();
+      (void) SetImageInfo(image_info,MagickTrue,exception);
+      exception=DestroyExceptionInfo(exception);
       if (LocaleCompare(image_info->filename,pattern) != 0)
         {
           image_info=DestroyImageInfo(image_info);
@@ -381,7 +384,7 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
         pattern++;
         status=MagickFalse;
         while ((*expression != '\0') && (status == MagickFalse))
-          status=GlobExpression(expression++,pattern);
+          status=GlobExpression(expression++,pattern,case_insensitive);
         if (status != MagickFalse)
           {
             while (*expression != '\0')
@@ -467,9 +470,6 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
       }
       case '{':
       {
-        MagickBooleanType
-          match;
-
         register const char
           *p;
 
@@ -530,19 +530,30 @@ MagickExport MagickBooleanType GlobExpression(const char *expression,
       }
       default:
       {
-        if (*expression != *pattern)
-          done=MagickTrue;
-        else
+        if (case_insensitive != MagickFalse)
           {
-            expression++;
-            pattern++;
+            if (tolower((int) ((unsigned char) *expression)) !=
+                tolower((int) ((unsigned char) *pattern)))
+              {
+                done=MagickTrue;
+                break;
+              }
           }
+        else
+          if (*expression != *pattern)
+            {
+              done=MagickTrue;
+              break;
+            }
+        expression++;
+        pattern++;
       }
     }
   }
-  while (*pattern == '*')
+  while (*pattern == '*') 
     pattern++;
-  return((*expression == '\0') && (*pattern == '\0') ? MagickTrue : MagickFalse);
+  match=(*expression == '\0') && (*pattern == '\0') ? MagickTrue : MagickFalse;
+  return(match);
 }
 
 /*
