@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -133,7 +133,7 @@ MagickExport Image *ChopImage(const Image *image,const RectangleInfo *chop_info,
       ((chop_info->y+(long) chop_info->height) < 0) ||
       (chop_info->x > (long) image->columns) ||
       (chop_info->y > (long) image->rows))
-    ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+    ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   extent=(*chop_info);
   if ((extent.x+(long) extent.width) > (long) image->columns)
     extent.width=(unsigned long) ((long) image->columns-extent.x);
@@ -305,7 +305,7 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
         break;
       for (x=0; x < (long) images->columns; x++)
       {
-        q->red=QuantumRange-PixelIntensityToQuantum(p);
+        q->red=(Quantum) (QuantumRange-PixelIntensityToQuantum(p));
         p++;
         q++;
       }
@@ -323,7 +323,7 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
         break;
       for (x=0; x < (long) images->columns; x++)
       {
-        q->green=QuantumRange-PixelIntensityToQuantum(p);
+        q->green=(Quantum) (QuantumRange-PixelIntensityToQuantum(p));
         p++;
         q++;
       }
@@ -341,7 +341,7 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
         break;
       for (x=0; x < (long) images->columns; x++)
       {
-        q->blue=QuantumRange-PixelIntensityToQuantum(p);
+        q->blue=(Quantum) (QuantumRange-PixelIntensityToQuantum(p));
         p++;
         q++;
       }
@@ -360,7 +360,7 @@ MagickExport Image *ConsolidateCMYKImages(const Image *images,
       indexes=GetIndexes(cmyk_image);
       for (x=0; x < (long) images->columns; x++)
       {
-        indexes[x]=QuantumRange-PixelIntensityToQuantum(p);
+        indexes[x]=(IndexPacket) (QuantumRange-PixelIntensityToQuantum(p));
         p++;
       }
       if (SyncImagePixels(cmyk_image) == MagickFalse)
@@ -461,6 +461,11 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       ((page.x-bounding_box.x) > (long) image->columns) ||
       ((page.y-bounding_box.y) > (long) image->rows))
     {
+      /*
+        Crop missed the image on the virtual canvas
+        Give warnign and return a 'missed image'
+        Special case, for 'background' disposed GIF animation frames.
+      */
       (void) ThrowMagickException(exception,GetMagickModule(),OptionWarning,
         "GeometryDoesNotContainImage","`%s'",image->filename);
       crop_image=CloneImage(image,1,1,MagickTrue,exception);
@@ -471,6 +476,8 @@ MagickExport Image *CropImage(const Image *image,const RectangleInfo *geometry,
       crop_image->page=bounding_box;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
+      if ( crop_image->dispose == BackgroundDispose )
+        crop_image->dispose = NoneDispose;
       return(crop_image);
     }
   if ((page.x < 0) && (bounding_box.x >= 0))
@@ -1172,7 +1179,7 @@ MagickExport Image *ShaveImage(const Image *image,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   if (((2*shave_info->width) >= image->columns) ||
       ((2*shave_info->height) >= image->rows))
-    ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+    ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   SetGeometry(image,&geometry);
   geometry.width-=2*shave_info->width;
   geometry.height-=2*shave_info->height;
@@ -1260,7 +1267,7 @@ MagickExport Image *SpliceImage(const Image *image,
   assert(exception->signature == MagickSignature);
   if ((geometry->x < 0) || (geometry->x > (long) image->columns) ||
       (geometry->y < 0) || (geometry->y > (long) image->rows))
-     ThrowImageException(OptionError,"GeometryDoesNotContainImage");
+     ThrowImageException(OptionWarning,"GeometryDoesNotContainImage");
   splice_geometry=(*geometry);
   splice_image=CloneImage(image,image->columns+splice_geometry.width,
     image->rows+splice_geometry.height,MagickTrue,exception);
@@ -1351,7 +1358,7 @@ MagickExport Image *SpliceImage(const Image *image,
     {
       *q++=image->background_color;
       if (splice_image->colorspace == CMYKColorspace)
-        splice_indexes[x]=0;
+        splice_indexes[x]=(IndexPacket) 0;
     }
     for ( ; x < (long) splice_image->columns; x++)
     {
@@ -1380,7 +1387,7 @@ MagickExport Image *SpliceImage(const Image *image,
     {
       *q++=image->background_color;
       if (splice_image->colorspace == CMYKColorspace)
-        splice_indexes[x]=0;
+        splice_indexes[x]=(IndexPacket) 0;
     }
     if (SyncImagePixels(splice_image) == MagickFalse)
       break;
@@ -1411,7 +1418,7 @@ MagickExport Image *SpliceImage(const Image *image,
     {
       *q++=image->background_color;
       if (splice_image->colorspace == CMYKColorspace)
-        splice_indexes[x]=0;
+        splice_indexes[x]=(IndexPacket) 0;
     }
     for ( ; x < (long) splice_image->columns; x++)
     {
@@ -1891,6 +1898,7 @@ MagickExport Image *TrimImage(const Image *image,ExceptionInfo *exception)
         return((Image *) NULL);
       crop_image->background_color.opacity=TransparentOpacity;
       (void) SetImageBackgroundColor(crop_image);
+      crop_image->page=image->page;
       crop_image->page.x=(-1);
       crop_image->page.y=(-1);
       return(crop_image);
