@@ -17,7 +17,7 @@
 %                                 May 2001                                    %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -59,6 +59,35 @@
 #include "magick/xml-tree.h"
 #if defined(HasFONTCONFIG)
 # include "fontconfig/fontconfig.h"
+#if (FC_VERSION < 20209)
+#undef FC_WEIGHT_LIGHT
+#define FC_WIDTH                  "width"    /* Int */
+#define FC_WIDTH_ULTRACONDENSED    50
+#define FC_WIDTH_EXTRACONDENSED    63
+#define FC_WIDTH_CONDENSED         75
+#define FC_WIDTH_SEMICONDENSED     87
+#define FC_WIDTH_NORMAL            100
+#define FC_WIDTH_SEMIEXPANDED      113
+#define FC_WIDTH_EXPANDED          125
+#define FC_WIDTH_EXTRAEXPANDED     150
+#define FC_WIDTH_ULTRAEXPANDED     200
+
+#define FC_WEIGHT_THIN             0
+#define FC_WEIGHT_EXTRALIGHT       40
+#define FC_WEIGHT_ULTRALIGHT       FC_WEIGHT_EXTRALIGHT
+#define FC_WEIGHT_LIGHT            50
+#define FC_WEIGHT_BOOK             75
+#define FC_WEIGHT_REGULAR          80
+#define FC_WEIGHT_NORMAL           FC_WEIGHT_REGULAR
+#define FC_WEIGHT_MEDIUM           100
+#define FC_WEIGHT_DEMIBOLD         180
+#define FC_WEIGHT_SEMIBOLD         FC_WEIGHT_DEMIBOLD
+#define FC_WEIGHT_BOLD             200
+#define FC_WEIGHT_EXTRABOLD        205
+#define FC_WEIGHT_ULTRABOLD        FC_WEIGHT_EXTRABOLD
+#define FC_WEIGHT_BLACK            210
+#define FC_WEIGHT_HEAVY            FC_WEIGHT_BLACK
+#endif
 #endif
 #if defined(__WINDOWS__)
 # include "magick/nt-feature.h"
@@ -490,7 +519,7 @@ MagickExport const TypeInfo **GetTypeInfoList(const char *pattern,
   for (i=0; p != (const TypeInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       fonts[i++]=p;
     p=(const TypeInfo *) GetNextValueInSplayTree(type_list);
   }
@@ -583,7 +612,7 @@ MagickExport char **GetTypeList(const char *pattern,unsigned long *number_fonts,
   for (i=0; p != (const TypeInfo *) NULL; )
   {
     if ((p->stealth == MagickFalse) &&
-        (GlobExpression(p->name,pattern) != MagickFalse))
+        (GlobExpression(p->name,pattern,MagickFalse) != MagickFalse))
       fonts[i++]=ConstantString(p->name);
     p=(const TypeInfo *) GetNextValueInSplayTree(type_list);
   }
@@ -899,23 +928,23 @@ static void *DestroyTypeNode(void *type_info)
 
   p=(TypeInfo *) type_info;
   if (p->path != (char *) NULL)
-    p->path=(char *) RelinquishMagickMemory(p->path);
+    p->path=DestroyString(p->path);
   if (p->name != (char *) NULL)
-    p->name=(char *) RelinquishMagickMemory(p->name);
+    p->name=DestroyString(p->name);
   if (p->description != (char *) NULL)
-    p->description=(char *) RelinquishMagickMemory(p->description);
+    p->description=DestroyString(p->description);
   if (p->family != (char *) NULL)
-    p->family=(char *) RelinquishMagickMemory(p->family);
+    p->family=DestroyString(p->family);
   if (p->encoding != (char *) NULL)
-    p->encoding=(char *) RelinquishMagickMemory(p->encoding);
+    p->encoding=DestroyString(p->encoding);
   if (p->foundry != (char *) NULL)
-    p->foundry=(char *) RelinquishMagickMemory(p->foundry);
+    p->foundry=DestroyString(p->foundry);
   if (p->format != (char *) NULL)
-    p->format=(char *) RelinquishMagickMemory(p->format);
+    p->format=DestroyString(p->format);
   if (p->metrics != (char *) NULL)
-    p->metrics=(char *) RelinquishMagickMemory(p->metrics);
+    p->metrics=DestroyString(p->metrics);
   if (p->glyphs != (char *) NULL)
-    p->glyphs=(char *) RelinquishMagickMemory(p->glyphs);
+    p->glyphs=DestroyString(p->glyphs);
   return(RelinquishMagickMemory(p));
 }
 
@@ -948,7 +977,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
     return(MagickFalse);
   if (type_list == (SplayTreeInfo *) NULL)
     {
-      type_list=NewSplayTree(CompareSplayTreeString,RelinquishMagickMemory,
+      type_list=NewSplayTree(CompareSplayTreeString,(void *(*)(void *)) NULL,
         DestroyTypeNode);
       if (type_list == (SplayTreeInfo *) NULL)
         {
@@ -990,8 +1019,11 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
             sans_exception=AcquireExceptionInfo();
             xml=FileToString(path,~0,sans_exception);
             sans_exception=DestroyExceptionInfo(sans_exception);
-            status=LoadTypeList(xml,path,depth+1,exception);
-            xml=(char *) RelinquishMagickMemory(xml);
+            if (xml != (char *) NULL)
+              {
+                status=LoadTypeList(xml,path,depth+1,exception);
+                xml=DestroyString(xml);
+              }
           }
       }
     include=GetNextXMLTreeTag(include);
@@ -1081,8 +1113,7 @@ static MagickBooleanType LoadTypeList(const char *xml,const char *filename,
         if (LocaleCompare(attribute,"normal") == 0)
           type_info->weight=400;
       }
-    status=AddValueToSplayTree(type_list,ConstantString(type_info->name),
-      type_info);
+    status=AddValueToSplayTree(type_list,type_info->name,type_info);
     if (status == MagickFalse)
       (void) ThrowMagickException(exception,GetMagickModule(),
         ResourceLimitError,"MemoryAllocationFailed","`%s'",filename);
@@ -1164,9 +1195,9 @@ static MagickBooleanType LoadTypeLists(const char *filename,
       if (option != (void *) NULL)
         {
           status|=LoadTypeList(option,path,0,exception);
-          option=(char *) RelinquishMagickMemory(option);
+          option=DestroyString(option);
         }
-      font_path=(char *) RelinquishMagickMemory(font_path);
+      font_path=DestroyString(font_path);
     }
   if ((type_list == (SplayTreeInfo *) NULL) ||
       (GetNumberOfNodesInSplayTree(type_list) == 0))
