@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -64,6 +64,7 @@ extern "C" {
 #define MaxNumberPens  11
 #define MaxNumberFonts  11
 #define MaxXWindows  12
+#undef index
 
 typedef enum
 {
@@ -250,7 +251,8 @@ typedef struct _XResourceInfo
 
   MagickBooleanType
     color_recovery,
-    confirm_exit;
+    confirm_exit,
+    confirm_edit;
 
   char
     *display_gamma;
@@ -494,12 +496,11 @@ extern MagickExport int
   XError(Display *,XErrorEvent *);
 
 extern MagickExport MagickBooleanType
-  IsTrue(const char *),
   XAnnotateImage(Display *,const XPixelInfo *,XAnnotateInfo *,Image *),
   XDrawImage(Display *,const XPixelInfo *,XDrawInfo *,Image *),
   XGetWindowColor(Display *,XWindows *,char *),
   XMagickProgressMonitor(const char *,const MagickOffsetType,
-	  const MagickSizeType,void *),
+    const MagickSizeType,void *),
   XMakeImage(Display *,const XResourceInfo *,XWindowInfo *,Image *,unsigned int,
     unsigned int),
   XQueryColorDatabase(const char *,XColor *),
