@@ -1,5 +1,5 @@
 #
-# Package name and versioning information for Magick
+# Package name and versioning information for ImageMagick.
 #
 # This file is sourced by a Bourne shell (/bin/sh) script so it must
 # observe Bourne shell syntax.
@@ -12,18 +12,12 @@ PACKAGE_NAME='ImageMagick'
 # PACKAGE_NAME (e.g. "1.0.0").
 PACKAGE_VERSION='6.3.4'
 PACKAGE_LIB_VERSION="0x634"
-PACKAGE_LIB_VERSION_NUMBER="6,3,4,1"
+PACKAGE_LIB_VERSION_NUMBER="6,3,4,6"
 PACKAGE_RELEASE_DATE=`date +%x`
 
 #
-# CVS branch that this release is on.
-#
-CVS_BRANCH_TAG=HEAD
-
-#
-# Package version addendum.  This is an arbitrary suffix (if any)
-# appended to the package version. (e.g. "beta1")
-# `echo -snapshot-``date '+%g%m%d'`
+# Package version addendum.  This is an arbitrary suffix (if any) appended
+# to the package version. (e.g. "beta1") `echo -snapshot-``date '+%g%m%d'`
 CHANGE_DATE=`find ${srcdir}/ChangeLog -printf '%Ty%Tm%Td%\n' 2> /dev/null`
 if test -n "$CHANGE_DATE"
 then
@@ -33,9 +27,9 @@ else
 fi
 
 #
-# Libtool library revision control info
-# See the libtool documentation under the heading "Libtool's versioning
-# system" in order to understand the meaning of these fields
+# Libtool library revision control info: See the libtool documentation under
+# the heading "Libtool's versioning system" in order to understand the meaning
+# of these fields.
 #
 # Here are a set of rules to help you update your library version
 # information:
