@@ -17,7 +17,7 @@
 %                                 July 1992                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -287,12 +287,13 @@ static void CompositeUsage(void)
       "-monitor             monitor progress",
       "-page geometry       size and location of an image canvas (setting)",
       "-quality value       JPEG/MIFF/PNG compression level",
-      "-quiet               suppress all error or warning messages",
+      "-quiet               suppress all warning messages",
       "-red-primary point   chromaticity red primary point",
       "-regard-warnings     pay attention to warning messages",
       "-sampling-factor geometry",
       "                     horizontal and vertical sampling factor",
       "-scene value         image scene number",
+      "-seed value          seed a new sequence of pseudo-random numbers",
       "-size geometry       width and height of image",
       "-support factor      resize support: > 1.0 is blurry, < 1.0 is sharp",
       "-transparent-color color",
@@ -362,7 +363,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   for ( ; k >= 0; k--) \
     image_stack[k]=DestroyImageList(image_stack[k]); \
   for (i=0; i < (long) argc; i++) \
-    argv[i]=(char *) RelinquishMagickMemory(argv[i]); \
+    argv[i]=DestroyString(argv[i]); \
   argv=(char **) RelinquishMagickMemory(argv); \
 }
 #define ThrowCompositeException(asperity,tag,option) \
@@ -418,6 +419,18 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
   if (image_info->debug != MagickFalse)
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"...");
   assert(exception != (ExceptionInfo *) NULL);
+  if (argc == 2)
+    {
+      option=argv[1];
+      if ((LocaleCompare("version",option+1) == 0) ||
+          (LocaleCompare("-version",option+1) == 0))
+        {
+          (void) fprintf(stdout,"Version: %s\n",
+            GetMagickVersion((unsigned long *) NULL));
+          (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+          return(MagickTrue);
+        }
+    }
   if (argc < 4)
     CompositeUsage();
   (void) ResetMagickMemory(&option_info,0,sizeof(CompositeOptions));
@@ -446,7 +459,7 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
       message=GetExceptionMessage(errno);
       ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   for (i=1; i < (long) (argc-1); i++)
   {
@@ -1157,6 +1170,26 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
               ThrowCompositeInvalidArgumentException(option,argv[i]);
             break;
           }
+        if (LocaleCompare("seed",option+1) == 0)
+          {
+            unsigned long
+              seed;
+
+            if (*option == '+')
+              {
+                seed=(unsigned long) time((time_t *) NULL);
+                SeedRandomReservoir(seed);
+                break;
+              }
+            i++;
+            if (i == (long) (argc-1))
+              ThrowCompositeException(OptionError,"MissingArgument",option);
+            if (IsGeometry(argv[i]) == MagickFalse)
+              ThrowCompositeInvalidArgumentException(option,argv[i]);
+            seed=(unsigned long) atol(argv[i]);
+            SeedRandomReservoir(seed);
+            break;
+          }
         if (LocaleCompare("sharpen",option+1) == 0)
           {
             i++;
@@ -1310,7 +1343,12 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           break;
         if ((LocaleCompare("version",option+1) == 0) ||
             (LocaleCompare("-version",option+1) == 0))
-          break;
+          {
+            (void) fprintf(stdout,"Version: %s\n",
+              GetMagickVersion((unsigned long *) NULL));
+            (void) fprintf(stdout,"Copyright: %s\n\n",GetMagickCopyright());
+            break;
+          }
         if (LocaleCompare("virtual-pixel",option+1) == 0)
           {
             long
@@ -1418,11 +1456,11 @@ WandExport MagickBooleanType CompositeImageCommand(ImageInfo *image_info,
           message=GetExceptionMessage(errno);
           ThrowCompositeException(ResourceLimitError,"MemoryAllocationFailed",
             message);
-          message=(char *) RelinquishMagickMemory(message);
+          message=DestroyString(message);
         }
       (void) ConcatenateString(&(*metadata),text);
       (void) ConcatenateString(&(*metadata),"\n");
-      text=(char *) RelinquishMagickMemory(text);
+      text=DestroyString(text);
     }
   image=DestroyImage(image);
   RelinquishCompositeOptions(&option_info);
