@@ -261,6 +261,80 @@ WandExport void DrawSetStrokeAlpha(DrawingWand *wand,const double stroke_alpha)
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k C o l o r F l o o d f i l l I m a g e                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickColorFloodfillImage() changes the color value of any pixel that matches
+%  target and is an immediate neighbor.  If the method FillToBorderMethod is
+%  specified, the color value is changed for any neighbor pixel that does not
+%  match the bordercolor member of image.
+%
+%  The format of the MagickColorFloodfillImage method is:
+%
+%      MagickBooleanType MagickColorFloodfillImage(MagickWand *wand,
+%        const PixelWand *fill,const double fuzz,const PixelWand *bordercolor,
+%        const long x,const long y)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o fill: The floodfill color pixel wand.
+%
+%    o fuzz: By default target must match a particular pixel color
+%      exactly.  However, in many cases two colors may differ by a small amount.
+%      The fuzz member of image defines how much tolerance is acceptable to
+%      consider two colors as the same.  For example, set fuzz to 10 and the
+%      color red at intensities of 100 and 102 respectively are now interpreted
+%      as the same color for the purposes of the floodfill.
+%
+%    o bordercolor: The border color pixel wand.
+%
+%    o x,y: The starting location of the operation.
+%
+*/
+WandExport MagickBooleanType MagickColorFloodfillImage(MagickWand *wand,
+  const PixelWand *fill,const double fuzz,const PixelWand *bordercolor,
+  const long x,const long y)
+{
+  DrawInfo
+    *draw_info;
+
+  MagickBooleanType
+    status;
+
+  PixelPacket
+    target;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->images == (Image *) NULL)
+    ThrowWandException(WandError,"ContainsNoImages",wand->name);
+  draw_info=CloneDrawInfo(wand->image_info,(DrawInfo *) NULL);
+  PixelGetQuantumColor(fill,&draw_info->fill);
+  target=AcquireOnePixel(wand->images,x % wand->images->columns,
+    y % wand->images->rows,&wand->exception);
+  if (bordercolor != (PixelWand *) NULL)
+    PixelGetQuantumColor(bordercolor,&target);
+  wand->images->fuzz=fuzz;
+  status=ColorFloodfillImage(wand->images,draw_info,target,x,y,
+    bordercolor != (PixelWand *) NULL ? FillToBorderMethod : FloodfillMethod);
+  if (status == MagickFalse)
+    InheritException(&wand->exception,&wand->images->exception);
+  draw_info=DestroyDrawInfo(draw_info);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k D e s c r i b e I m a g e                                     %
 %                                                                             %
 %                                                                             %
@@ -437,6 +511,81 @@ WandExport MagickBooleanType MagickGetImageExtrema(MagickWand *wand,
 %                                                                             %
 %                                                                             %
 %                                                                             %
+%   M a g i c k M a t t e F l o o d f i l l I m a g e                         %
+%                                                                             %
+%                                                                             %
+%                                                                             %
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%
+%  MagickMatteFloodfillImage() changes the transparency value of any pixel that
+%  matches target and is an immediate neighbor.  If the method
+%  FillToBorderMethod is specified, the transparency value is changed for any
+%  neighbor pixel that does not match the bordercolor member of image.
+%
+%  The format of the MagickMatteFloodfillImage method is:
+%
+%      MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
+%        const double alpha,const double fuzz,const PixelWand *bordercolor,
+%        const long x,const long y)
+%
+%  A description of each parameter follows:
+%
+%    o wand: The magick wand.
+%
+%    o alpha: The level of transparency: 1.0 is fully opaque and 0.0 is fully
+%      transparent.
+%
+%    o fuzz: By default target must match a particular pixel color
+%      exactly.  However, in many cases two colors may differ by a small amount.
+%      The fuzz member of image defines how much tolerance is acceptable to
+%      consider two colors as the same.  For example, set fuzz to 10 and the
+%      color red at intensities of 100 and 102 respectively are now interpreted
+%      as the same color for the purposes of the floodfill.
+%
+%    o bordercolor: The border color pixel wand.
+%
+%    o x,y: The starting location of the operation.
+%
+*/
+WandExport MagickBooleanType MagickMatteFloodfillImage(MagickWand *wand,
+  const double alpha,const double fuzz,const PixelWand *bordercolor,
+  const long x,const long y)
+{
+  DrawInfo
+    *draw_info;
+
+  MagickBooleanType
+    status;
+
+  PixelPacket
+    target;
+
+  assert(wand != (MagickWand *) NULL);
+  assert(wand->signature == WandSignature);
+  if (wand->debug != MagickFalse)
+    (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",wand->name);
+  if (wand->images == (Image *) NULL)
+    ThrowWandException(WandError,"ContainsNoImages",wand->name);
+  draw_info=CloneDrawInfo(wand->image_info,(DrawInfo *) NULL);
+  target=AcquireOnePixel(wand->images,x % wand->images->columns,
+    y % wand->images->rows,&wand->exception);
+  if (bordercolor != (PixelWand *) NULL)
+    PixelGetQuantumColor(bordercolor,&target);
+  wand->images->fuzz=fuzz;
+  status=MatteFloodfillImage(wand->images,target,RoundToQuantum(
+    (MagickRealType) QuantumRange-QuantumRange*alpha),x,y,bordercolor !=
+    (PixelWand *) NULL ? FillToBorderMethod : FloodfillMethod);
+  if (status == MagickFalse)
+    InheritException(&wand->exception,&wand->images->exception);
+  draw_info=DestroyDrawInfo(draw_info);
+  return(status);
+}
+
+/*
+%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
+%                                                                             %
+%                                                                             %
+%                                                                             %
 %   M a g i c k O p a q u e I m a g e                                         %
 %                                                                             %
 %                                                                             %
