@@ -381,7 +381,7 @@ int main ( int argc, char **argv )
   int rows, columns = 0;
   char size[MaxTextExtent];
   ImageInfo *image_info;
-  ExceptionInfo exception;
+  ExceptionInfo *exception;
 
   if ( argc != 2 )
     {
@@ -402,13 +402,13 @@ int main ( int argc, char **argv )
   columns=596;
   rows=842;
   image_info=CloneImageInfo((ImageInfo*)NULL);
-  GetExceptionInfo( &exception );
+  exception=AcquireExceptionInfo();
   (void) FormatMagickString(size, MaxTextExtent, "%dx%d", columns, rows);
   (void) CloneString(&image_info->size,size);
   (void) CopyMagickString(image_info->filename,"xc:white",MaxTextExtent);
-  canvas=ReadImage ( image_info, &exception );
-  if (exception.severity >= ErrorException)
-    CatchException(&exception);
+  canvas=ReadImage(image_info,exception );
+  if (exception->severity >= ErrorException)
+    CatchException(exception);
   if ( canvas == (Image *)NULL )
     {
       (void) printf ( "Failed to read canvas image %s\n",image_info->filename);
@@ -427,7 +427,7 @@ int main ( int argc, char **argv )
     sizeof(image_info->filename));
   (void) WriteImage ( image_info, canvas );
 
-  (void) DestroyExceptionInfo( &exception );
+  exception=DestroyExceptionInfo(exception);
    canvas =DestroyImage( canvas );
    image_info =DestroyImageInfo( image_info );
   MagickCoreTerminus();
