@@ -1,5 +1,5 @@
 /*
-  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization
+  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
   You may not use this file except in compliance with the License.
@@ -27,9 +27,9 @@ extern WandExport ChannelStatistics
   *MagickGetImageChannelStatistics(MagickWand *);
 
 extern WandExport char
-  *MagickGetImageAttribute(MagickWand *,const char *),
   *MagickGetImageFilename(MagickWand *),
   *MagickGetImageFormat(MagickWand *),
+  *MagickGetImageProperty(MagickWand *,const char *),
   *MagickGetImageSignature(MagickWand *),
   *MagickIdentifyImage(MagickWand *);
 
@@ -59,6 +59,9 @@ extern WandExport ImageType
 extern WandExport InterlaceType
   MagickGetImageInterlaceScheme(MagickWand *);
 
+extern WandExport InterpolatePixelMethod
+  MagickGetImageInterpolateMethod(MagickWand *);
+
 extern WandExport MagickBooleanType
   MagickAdaptiveBlurImage(MagickWand *,const double,const double),
   MagickAdaptiveBlurImageChannel(MagickWand *,const ChannelType,const double,
@@ -88,8 +91,6 @@ extern WandExport MagickBooleanType
     const long,const long),
   MagickClipImage(MagickWand *),
   MagickClipPathImage(MagickWand *,const char *,const MagickBooleanType),
-  MagickColorFloodfillImage(MagickWand *,const PixelWand *,const double,
-    const PixelWand *,const long,const long),
   MagickColorizeImage(MagickWand *,const PixelWand *,const PixelWand *),
   MagickCommentImage(MagickWand *,const char *),
   MagickCompositeImage(MagickWand *,const MagickWand *,const CompositeOperator,
@@ -118,6 +119,8 @@ extern WandExport MagickBooleanType
   MagickEvaluateImage(MagickWand *,const MagickEvaluateOperator,const double),
   MagickEvaluateImageChannel(MagickWand *,const ChannelType,
     const MagickEvaluateOperator,const double),
+  MagickExtentImage(MagickWand *,const unsigned long,const unsigned long,
+    const long,const long),
   MagickFlipImage(MagickWand *),
   MagickFlopImage(MagickWand *),
   MagickFrameImage(MagickWand *,const PixelWand *,const unsigned long,
@@ -134,19 +137,19 @@ extern WandExport MagickBooleanType
     const ChannelType, const MetricType,double *),
   MagickGetImageDistortion(MagickWand *,const MagickWand *,const MetricType,
     double *),
-  MagickGetImageChannelExtrema(MagickWand *,const ChannelType,unsigned long *,
-    unsigned long *),
   MagickGetImageChannelMean(MagickWand *,const ChannelType,double *,double *),
+  MagickGetImageChannelRange(MagickWand *,const ChannelType,double *,double *),
   MagickGetImageColormapColor(MagickWand *,const unsigned long,PixelWand *),
-  MagickGetImageExtrema(MagickWand *,unsigned long *,unsigned long *),
   MagickGetImageGreenPrimary(MagickWand *,double *,double *),
   MagickGetImageMatte(MagickWand *),
   MagickGetImageMatteColor(MagickWand *,PixelWand *),
+  MagickGetImageLength(MagickWand *,MagickSizeType *),
   MagickGetImagePage(MagickWand *,unsigned long *,unsigned long *,long *,
     long *),
   MagickGetImagePixelColor(MagickWand *,const long,const long,PixelWand *),
   MagickGetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,void *),
+  MagickGetImageRange(MagickWand *,double *,double *),
   MagickGetImageRedPrimary(MagickWand *,double *,double *),
   MagickGetImageResolution(MagickWand *,double *,double *),
   MagickGetImageWhitePoint(MagickWand *,double *,double *),
@@ -157,10 +160,9 @@ extern WandExport MagickBooleanType
   MagickLevelImage(MagickWand *,const double,const double,const double),
   MagickLevelImageChannel(MagickWand *,const ChannelType,const double,
     const double,const double),
+  MagickLinearStretchImage(MagickWand *,const double,const double),
   MagickMagnifyImage(MagickWand *),
   MagickMapImage(MagickWand *,const MagickWand *,const MagickBooleanType),
-  MagickMatteFloodfillImage(MagickWand *,const Quantum,const double,
-    const PixelWand *,const long,const long),
   MagickMedianFilterImage(MagickWand *,const double),
   MagickMinifyImage(MagickWand *),
   MagickModulateImage(MagickWand *,const double,const double,const double),
@@ -174,15 +176,21 @@ extern WandExport MagickBooleanType
   MagickNormalizeImage(MagickWand *),
   MagickNormalizeImageChannel(MagickWand *,const ChannelType),
   MagickOilPaintImage(MagickWand *,const double),
+  MagickOrderedPosterizeImage(MagickWand *,const char *),
+  MagickOrderedPosterizeImageChannel(MagickWand *,const ChannelType,
+    const char *),
+  MagickPaintFloodfillImage(MagickWand *,const ChannelType,const PixelWand *,
+    const double,const PixelWand *,const long,const long),
   MagickPaintOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
     const double),
   MagickPaintOpaqueImageChannel(MagickWand *,const ChannelType,
     const PixelWand *,const PixelWand *,const double),
-  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const Quantum,
+  MagickPaintTransparentImage(MagickWand *,const PixelWand *,const double,
     const double),
   MagickPingImage(MagickWand *,const char *),
   MagickPingImageBlob(MagickWand *,const void *,const size_t),
   MagickPingImageFile(MagickWand *,FILE *),
+  MagickPolaroidImage(MagickWand *,const DrawingWand *,const double),
   MagickPosterizeImage(MagickWand *,const unsigned long,
     const MagickBooleanType),
   MagickPreviousImage(MagickWand *),
@@ -201,6 +209,7 @@ extern WandExport MagickBooleanType
   MagickReadImage(MagickWand *,const char *),
   MagickReadImageBlob(MagickWand *,const void *,const size_t),
   MagickReadImageFile(MagickWand *,FILE *),
+  MagickRecolorImage(MagickWand *,const unsigned long,const double *),
   MagickReduceNoiseImage(MagickWand *,const double),
   MagickRemoveImage(MagickWand *),
   MagickResampleImage(MagickWand *,const double,const double,const FilterTypes,
@@ -216,13 +225,13 @@ extern WandExport MagickBooleanType
   MagickSeparateImageChannel(MagickWand *,const ChannelType),
   MagickSepiaToneImage(MagickWand *,const double),
   MagickSetImage(MagickWand *,const MagickWand *),
-  MagickSetImageAttribute(MagickWand *,const char *,const char *),
   MagickSetImageBackgroundColor(MagickWand *,const PixelWand *),
   MagickSetImageBias(MagickWand *,const double),
   MagickSetImageBluePrimary(MagickWand *,const double,const double),
   MagickSetImageBorderColor(MagickWand *,const PixelWand *),
   MagickSetImageChannelDepth(MagickWand *,const ChannelType,
     const unsigned long),
+  MagickSetImageClipMask(MagickWand *,const MagickWand *),
   MagickSetImageColormapColor(MagickWand *,const unsigned long,
     const PixelWand *),
   MagickSetImageCompose(MagickWand *,const CompositeOperator),
@@ -238,22 +247,27 @@ extern WandExport MagickBooleanType
   MagickSetImageFilename(MagickWand *,const char *),
   MagickSetImageFormat(MagickWand *,const char *),
   MagickSetImageInterlaceScheme(MagickWand *,const InterlaceType),
+  MagickSetImageInterpolateMethod(MagickWand *,
+    const InterpolatePixelMethod),
   MagickSetImageIterations(MagickWand *,const unsigned long),
   MagickSetImageMatte(MagickWand *,const MagickBooleanType),
   MagickSetImageMatteColor(MagickWand *,const PixelWand *),
+  MagickSetImageOpacity(MagickWand *,const double),
+  MagickSetImageOrientation(MagickWand *,const OrientationType),
   MagickSetImagePage(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
+  MagickResetImagePage(MagickWand *,const char *),
   MagickSetImagePixels(MagickWand *,const long,const long,const unsigned long,
     const unsigned long,const char *,const StorageType,const void *),
   MagickSetImageProfile(MagickWand *,const char *,const void *,const size_t),
+  MagickSetImageProperty(MagickWand *,const char *,const char *),
   MagickSetImageRedPrimary(MagickWand *,const double,const double),
   MagickSetImageRenderingIntent(MagickWand *,const RenderingIntent),
   MagickSetImageResolution(MagickWand *,const double,const double),
   MagickSetImageScene(MagickWand *,const unsigned long),
-  MagickSetImageTicksPerSecond(MagickWand *,const unsigned long),
+  MagickSetImageTicksPerSecond(MagickWand *,const long),
   MagickSetImageType(MagickWand *,const ImageType),
   MagickSetImageUnits(MagickWand *,const ResolutionType),
-  MagickSetImageVirtualPixelMethod(MagickWand *,const VirtualPixelMethod),
   MagickSetImageWhitePoint(MagickWand *,const double,const double),
   MagickShadeImage(MagickWand *,const MagickBooleanType,const double,const 
     double),
@@ -300,9 +314,6 @@ WandExport MagickProgressMonitor
   MagickSetImageProgressMonitor(MagickWand *,const MagickProgressMonitor,
     void *);
 
-extern WandExport MagickSizeType
-  MagickGetImageSize(MagickWand *);
-
 extern WandExport MagickWand
   *MagickAppendImages(MagickWand *,const MagickBooleanType),
   *MagickAverageImages(MagickWand *),
@@ -318,6 +329,7 @@ extern WandExport MagickWand
   *MagickFxImage(MagickWand *,const char *),
   *MagickFxImageChannel(MagickWand *,const ChannelType,const char *),
   *MagickGetImage(MagickWand *),
+  *MagickGetImageClipMask(MagickWand *),
   *MagickGetImageRegion(MagickWand *,const unsigned long,const unsigned long,
     const long,const long),
   *MagickMorphImages(MagickWand *,const unsigned long),
@@ -332,6 +344,9 @@ extern WandExport MagickWand
   *MagickTransformImage(MagickWand *,const char *,const char *),
   *NewMagickWandFromImage(const Image *);
 
+extern WandExport OrientationType
+  MagickGetImageOrientation(MagickWand *);
+
 extern WandExport PixelWand
   **MagickGetImageHistogram(MagickWand *,unsigned long *);
 
@@ -363,30 +378,6 @@ extern WandExport unsigned long
 extern WandExport VirtualPixelMethod
   MagickGetImageVirtualPixelMethod(MagickWand *);
 
-/*
-  Deprecated methods.
-*/
-extern WandExport char
-  *MagickDescribeImage(MagickWand *);
-
-extern WandExport long
-  MagickGetImageIndex(MagickWand *);
-
-extern WandExport MagickBooleanType
-  MagickOpaqueImage(MagickWand *,const PixelWand *,const PixelWand *,
-    const double),
-  MagickSetImageIndex(MagickWand *,const long),
-  MagickSetImageOption(MagickWand *,const char *,const char *,const char *),
-  MagickTransparentImage(MagickWand *,const PixelWand *,const Quantum,
-    const double);
-
-extern WandExport MagickWand
-  *MagickRegionOfInterestImage(MagickWand *,const unsigned long,
-	  const unsigned long,const long,const long);
-
-extern WandExport unsigned char
-  *MagickWriteImageBlob(MagickWand *,size_t *);
-
 #if defined(__cplusplus) || defined(c_plusplus)
 }
 #endif
