@@ -23,7 +23,7 @@
 %                                 August 2003                                 %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2006 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -148,7 +148,7 @@ WandExport MagickWand *CloneMagickWand(const MagickWand *wand)
       message=GetExceptionMessage(errno);
       ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   (void) ResetMagickMemory(clone_wand,0,sizeof(*clone_wand));
   clone_wand->id=AcquireWandId();
@@ -340,14 +340,14 @@ WandExport char *MagickQueryConfigureOption(const char *option)
     **configure_info;
 
   ExceptionInfo
-    exception;
+    *exception;
 
   unsigned long
     number_options;
 
-  GetExceptionInfo(&exception);
-  configure_info=GetConfigureInfoList(option,&number_options,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  configure_info=GetConfigureInfoList(option,&number_options,exception);
+  exception=DestroyExceptionInfo(exception);
   if (configure_info == (const ConfigureInfo **) NULL)
     return((char *) NULL);
   value=AcquireString(configure_info[0]->value);
@@ -391,11 +391,11 @@ WandExport char **MagickQueryConfigureOptions(const char *pattern,
     **options;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  options=GetConfigureList(pattern,number_options,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  options=GetConfigureList(pattern,number_options,exception);
+  exception=DestroyExceptionInfo(exception);
   return(options);
 }
 
@@ -645,11 +645,11 @@ WandExport char **MagickQueryFonts(const char *pattern,
     **fonts;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  fonts=GetTypeList(pattern,number_fonts,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  fonts=GetTypeList(pattern,number_fonts,exception);
+  exception=DestroyExceptionInfo(exception);
   return(fonts);
 }
 
@@ -679,7 +679,6 @@ WandExport char **MagickQueryFonts(const char *pattern,
 %    o number_formats:  This integer returns the number of image formats in the
 %      list.
 %
-%
 */
 WandExport char **MagickQueryFormats(const char *pattern,
   unsigned long *number_formats)
@@ -688,11 +687,11 @@ WandExport char **MagickQueryFormats(const char *pattern,
     **formats;
 
   ExceptionInfo
-    exception;
+    *exception;
 
-  GetExceptionInfo(&exception);
-  formats=GetMagickList(pattern,number_formats,&exception);
-  (void) DestroyExceptionInfo(&exception);
+  exception=AcquireExceptionInfo();
+  formats=GetMagickList(pattern,number_formats,exception);
+  exception=DestroyExceptionInfo(exception);
   return(formats);
 }
 
@@ -964,7 +963,7 @@ WandExport MagickWand *NewMagickWand(void)
       message=GetExceptionMessage(errno);
       ThrowWandFatalException(ResourceLimitFatalError,"MemoryAllocationFailed",
         message);
-      message=(char *) RelinquishMagickMemory(message);
+      message=DestroyString(message);
     }
   (void) ResetMagickMemory(wand,0,sizeof(*wand));
   wand->id=AcquireWandId();
