@@ -70,7 +70,7 @@ struct _PixelIterator
     name[MaxTextExtent];
 
   ExceptionInfo
-    exception;
+    *exception;
 
   ViewInfo
     *view;
@@ -124,8 +124,7 @@ WandExport void ClearPixelIterator(PixelIterator *iterator)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   iterator->pixel_wand=DestroyPixelWands(iterator->pixel_wand,
     iterator->region.width);
-  (void) DestroyExceptionInfo(&iterator->exception);
-  GetExceptionInfo(&iterator->exception);
+  ClearMagickException(iterator->exception);
   iterator->pixel_wand=NewPixelWands(iterator->region.width);
   iterator->active=MagickFalse;
   iterator->y=0;
@@ -163,7 +162,7 @@ WandExport PixelIterator *DestroyPixelIterator(PixelIterator *iterator)
   iterator->view=CloseCacheView(iterator->view);
   iterator->pixel_wand=DestroyPixelWands(iterator->pixel_wand,
     iterator->region.width);
-  (void) DestroyExceptionInfo(&iterator->exception);
+  iterator->exception=DestroyExceptionInfo(iterator->exception);
   iterator->signature=(~WandSignature);
   RelinquishWandId(iterator->id);
   iterator=(PixelIterator *) RelinquishMagickMemory(iterator);
@@ -273,7 +272,7 @@ WandExport PixelIterator *NewPixelIterator(MagickWand *wand)
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
-  GetExceptionInfo(&iterator->exception);
+  iterator->exception=AcquireExceptionInfo();
   iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->region.width=image->columns;
@@ -319,7 +318,7 @@ WandExport MagickBooleanType PixelClearIteratorException(
   assert(iterator->signature == WandSignature);
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
-  ClearMagickException(&iterator->exception);
+  ClearMagickException(iterator->exception);
   return(MagickTrue);
 }
 
@@ -396,7 +395,7 @@ WandExport PixelIterator *NewPixelRegionIterator(MagickWand *wand,const long x,
   iterator->id=AcquireWandId();
   (void) FormatMagickString(iterator->name,MaxTextExtent,"%s-%lu",
     PixelIteratorId,iterator->id);
-  GetExceptionInfo(&iterator->exception);
+  iterator->exception=AcquireExceptionInfo();
   iterator->view=view;
   SetGeometry(image,&iterator->region);
   iterator->region.width=columns;
@@ -457,7 +456,7 @@ WandExport PixelWand **PixelGetCurrentIteratorRow(PixelIterator *iterator,
   *number_wands=0;
   iterator->active=MagickTrue;
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
   indexes=GetCacheViewIndexes(iterator->view);
@@ -512,7 +511,7 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
   if (iterator->debug != MagickFalse)
     (void) LogMagickEvent(WandEvent,GetMagickModule(),"%s",iterator->name);
   assert(severity != (ExceptionType *) NULL);
-  *severity=iterator->exception.severity;
+  *severity=iterator->exception->severity;
   description=(char *) AcquireMagickMemory(2*MaxTextExtent);
   if (description == (char *) NULL)
     {
@@ -525,14 +524,14 @@ WandExport char *PixelGetIteratorException(const PixelIterator *iterator,
       message=DestroyString(message);
     }
   *description='\0';
-  if (iterator->exception.reason != (char *) NULL)
+  if (iterator->exception->reason != (char *) NULL)
     (void) CopyMagickString(description,GetLocaleExceptionMessage(
-      iterator->exception.severity,iterator->exception.reason),MaxTextExtent);
-  if (iterator->exception.description != (char *) NULL)
+      iterator->exception->severity,iterator->exception->reason),MaxTextExtent);
+  if (iterator->exception->description != (char *) NULL)
     {
       (void) ConcatenateMagickString(description," (",MaxTextExtent);
       (void) ConcatenateMagickString(description,GetLocaleExceptionMessage(
-        iterator->exception.severity,iterator->exception.description),
+        iterator->exception->severity,iterator->exception->description),
         MaxTextExtent);
       (void) ConcatenateMagickString(description,")",MaxTextExtent);
     }
@@ -618,7 +617,7 @@ WandExport PixelWand **PixelGetNextIteratorRow(PixelIterator *iterator,
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
   indexes=GetCacheViewIndexes(iterator->view);
@@ -693,7 +692,7 @@ WandExport PixelWand **PixelGetPreviousIteratorRow(PixelIterator *iterator,
   if (PixelSetIteratorRow(iterator,iterator->y) == MagickFalse)
     return((PixelWand **) NULL);
   p=AcquireCacheView(iterator->view,iterator->region.x,iterator->region.y+
-    iterator->y,iterator->region.width,1,&iterator->exception);
+    iterator->y,iterator->region.width,1,iterator->exception);
   if (p == (const PixelPacket *) NULL)
     return((PixelWand **) NULL);
   indexes=GetCacheViewIndexes(iterator->view);
@@ -889,8 +888,8 @@ WandExport MagickBooleanType PixelSyncIterator(PixelIterator *iterator)
     iterator->y,iterator->region.width,1);
   if (p == (PixelPacket *) NULL)
     {
-      InheritException(&iterator->exception,
-        GetCacheViewException(iterator->view));
+      InheritException(iterator->exception,GetCacheViewException(
+        iterator->view));
       return(MagickFalse);
     }
   indexes=GetCacheViewIndexes(iterator->view);
@@ -906,8 +905,8 @@ WandExport MagickBooleanType PixelSyncIterator(PixelIterator *iterator)
   }
   if (SyncCacheView(iterator->view) == MagickFalse)
     {
-      InheritException(&iterator->exception,
-        GetCacheViewException(iterator->view));
+      InheritException(iterator->exception,GetCacheViewException(
+        iterator->view));
       return(MagickFalse);
     }
   return(MagickTrue);
