@@ -17,7 +17,7 @@
 %                                 May  2004                                   %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2005 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
@@ -39,24 +39,16 @@
 /*
   Include declarations.
 */
-#include "magick/studio.h"
-#include "magick/exception.h"
-#include "magick/exception-private.h"
-#include "magick/log.h"
-#include "magick/magick.h"
-#include "magick/memory_.h"
-#include "magick/semaphore.h"
-#include "magick/splay-tree.h"
-#include "magick/string_.h"
-#include "magick/utility.h"
-#include "wand/magick-wand.h"
+#include "wand/studio.h"
+#include "wand/MagickWand.h"
+#include "wand/magick-wand-private.h"
 #include "wand/wand.h"
 
 static SplayTreeInfo
   *wand_ids = (SplayTreeInfo *) NULL;
 
 static MagickBooleanType
-  instantiate_magick = MagickFalse;
+  instantiate_wand = MagickFalse;
 
 static SemaphoreInfo
   *wand_semaphore = (SemaphoreInfo *) NULL;
@@ -85,19 +77,22 @@ WandExport unsigned long AcquireWandId(void)
   static unsigned long
     id = 0;
 
-  if (wand_ids == (SplayTreeInfo *) NULL)
+  if ((wand_ids == (SplayTreeInfo *) NULL) &&
+      (instantiate_wand == MagickFalse))
     {
-      wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
-      if (wand_ids == (SplayTreeInfo *) NULL)
-        wand_ids=NewSplayTree((int (*)(const void *,const void *)) NULL,
-          (void *(*)(void *)) NULL,(void *(*)(void *)) NULL);
-      instantiate_magick=IsMagickInstantiated();
+      AcquireSemaphoreInfo(&wand_semaphore);
+      if ((wand_ids == (SplayTreeInfo *) NULL) &&
+          (instantiate_wand == MagickFalse))
+        {
+          wand_ids=NewSplayTree((int (*)(const void *,const void *)) NULL,
+            (void *(*)(void *)) NULL,(void *(*)(void *)) NULL);
+          if (IsMagickInstantiated() == MagickFalse)
+            MagickCoreGenesis((char *) NULL,MagickFalse);
+          instantiate_wand=MagickTrue;
+        }
       RelinquishSemaphoreInfo(wand_semaphore);
     }
-  if ((instantiate_magick == MagickFalse) &&
-      (GetNumberOfNodesInSplayTree(wand_ids) == 0))
-    InitializeMagick((char *) NULL);
-  wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
+  AcquireSemaphoreInfo(&wand_semaphore);
   id++;
   RelinquishSemaphoreInfo(wand_semaphore);
   (void) AddValueToSplayTree(wand_ids,(const void *) id,(const void *) id);
@@ -125,7 +120,6 @@ WandExport unsigned long AcquireWandId(void)
 %
 %    o id: a unique wand id.
 %
-%
 */
 WandExport void RelinquishWandId(const unsigned long id)
 {
@@ -133,13 +127,13 @@ WandExport void RelinquishWandId(const unsigned long id)
   if (wand_ids == (SplayTreeInfo *) NULL)
     return;
   (void) RemoveNodeByValueFromSplayTree(wand_ids,(const void *) id);
-  if ((instantiate_magick != MagickFalse) ||
+  if ((instantiate_wand == MagickFalse) ||
       (GetNumberOfNodesInSplayTree(wand_ids) != 0))
     return;
-  wand_semaphore=AcquireSemaphoreInfo(wand_semaphore);
-  DestroyMagick();
+  AcquireSemaphoreInfo(&wand_semaphore);
+  MagickCoreTerminus();
   wand_ids=DestroySplayTree(wand_ids);
-  instantiate_magick=MagickFalse;
+  instantiate_wand=MagickFalse;
   RelinquishSemaphoreInfo(wand_semaphore);
   wand_semaphore=DestroySemaphoreInfo(wand_semaphore);
 }
